---
title: wls cluster
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

Allows you to manage a WebLogic cluster in a WebLogic domain.

Here is an example on how you should use this:

    wls_cluster { 'WlsCluster':
      ensure           => 'present',
      messagingmode    => 'unicast',
      migrationbasis   => 'consensus',
      servers          => ['wlsServer3','wlsServer4'],
      multicastaddress => '239.192.0.0',
      multicastport    => '7001',
    }

In this example you are managing a server in the default domain. When you want to
manage a cluster in a specific domain, you can use:

    wls_cluster { 'MuDomain/WlsCluster':
      ensure           => 'present',
      messagingmode    => 'unicast',
      migrationbasis   => 'consensus',
      servers          => ['wlsServer3','wlsServer4'],
      multicastaddress => '239.192.0.0',
      multicastport    => '7001',
    }

Check [the Oracle Weblogic documentation](http://docs.oracle.com/middleware/1221/wls/INTRO/clustering.htm#INTRO185)
for more documentation about setting up and managing a WebLogic cluster.

## Attributes



Attribute Name                                                                                                          | Short Description                                                                                                                                                                                                     |
----------------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[additional_auto_migration_attempts](#wls_cluster_additional_auto_migration_attempts)                                   | A migratable server could fail to come up on every possible configured machine.                                                                                                                                       |
[async_session_queue_timeout](#wls_cluster_async_session_queue_timeout)                                                 | Interval in seconds until the producer thread will wait for the AsyncSessionQueue to become unblocked.                                                                                                                |
[auto_migration_table_name](#wls_cluster_auto_migration_table_name)                                                     | Return the name of the table to be used for server migration.                                                                                                                                                         |
[candidate_machines_for_migratable_servers](#wls_cluster_candidate_machines_for_migratable_servers)                     | The set of machines (and order of preference) on which Node Manager will restart failed servers.                                                                                                                      |
[client_cert_proxy_enabled](#wls_cluster_client_cert_proxy_enabled)                                                     | Specifies whether to honor the WL-Proxy-Client-Cert header coming with the request or not.                                                                                                                            |
[cluster_address](#wls_cluster_cluster_address)                                                                         | The address that forms a portion of the URL a client uses to connect to this cluster, and that is used for generating EJB handles and entity EJB failover addresses.                                                  |
[cluster_broadcast_channel](#wls_cluster_cluster_broadcast_channel)                                                     | Specifies the channel used to handle communications within a cluster.                                                                                                                                                 |
[cluster_messaging_mode](#wls_cluster_cluster_messaging_mode)                                                           | Specifies the messaging type used in the cluster.                                                                                                                                                                     |
[cluster_name](#wls_cluster_cluster_name)                                                                               | The cluster name.                                                                                                                                                                                                     |
[cluster_type](#wls_cluster_cluster_type)                                                                               | Optimizes cross-cluster replication for the type of network that servers in the clusters use for administrative communication.                                                                                        |
[clusteraddress](#wls_cluster_clusteraddress)                                                                           | The address that forms a portion of the URL a client uses to connect to this cluster, and that is used for generating EJB handles and entity EJB failover addresses.                                                  |
[data_source_for_automatic_migration](#wls_cluster_data_source_for_automatic_migration)                                 | The data source used by servers in the cluster during migration.                                                                                                                                                      |
[data_source_for_job_scheduler](#wls_cluster_data_source_for_job_scheduler)                                             | Data source required to support persistence of jobs scheduled with the job scheduler
                                                                                                                                 |
[data_source_for_session_persistence](#wls_cluster_data_source_for_session_persistence)                                 | To support HTTP Session failover across data centers, a datasource is required to dump session state on disk.                                                                                                         |
[database_leasing_basis_connection_retry_count](#wls_cluster_database_leasing_basis_connection_retry_count)             | The maximum number of times Database Leasing will try to obtain a valid connection from the Data Source.                                                                                                              |
[database_leasing_basis_connection_retry_delay](#wls_cluster_database_leasing_basis_connection_retry_delay)             | The length of time, in milliseconds,Database Leasing will wait before attempting to obtain a new connection from the Data Source when a connection has failed.                                                        |
[datasourceforjobscheduler](#wls_cluster_datasourceforjobscheduler)                                                     | Data source required to support persistence of jobs scheduled with the job scheduler
                                                                                                                                 |
[default_load_algorithm](#wls_cluster_default_load_algorithm)                                                           | Defines the algorithm to be used for load-balancing between replicated services if none is specified for a particular service.                                                                                        |
[disable_corrective_change](#wls_cluster_disable_corrective_change)                                                     | Disable the modification of a resource when Puppet decides it is a corrective change.                                                                                                                                 |
[disable_corrective_ensure](#wls_cluster_disable_corrective_ensure)                                                     | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                                                                                                             |
[domain](#wls_cluster_domain)                                                                                           | With this parameter, you identify the domain, where your objects is in.                                                                                                                                               |
[ensure](#wls_cluster_ensure)                                                                                           | The basic property that the resource should be in.                                                                                                                                                                    |
[fencing_grace_period_millis](#wls_cluster_fencing_grace_period_millis)                                                 | During automatic migration, if the Cluster Master determines a server to be dead, it waits for this period of time (in milliseconds) before the Cluster Master migrates the service to another server in the cluster. |
[frontend_host](#wls_cluster_frontend_host)                                                                             | The name of the host to which all redirected URLs will be sent.                                                                                                                                                       |
[frontend_http_port](#wls_cluster_frontend_http_port)                                                                   | The name of the HTTP port to which all redirected URLs will be sent.                                                                                                                                                  |
[frontend_https_port](#wls_cluster_frontend_https_port)                                                                 | The name of the secure HTTP port to which all redirected URLs will be sent.                                                                                                                                           |
[frontendhost](#wls_cluster_frontendhost)                                                                               | The name of the host to which all redirected URLs will be sent.                                                                                                                                                       |
[frontendhttpport](#wls_cluster_frontendhttpport)                                                                       | The name of the HTTP port to which all redirected URLs will be sent.                                                                                                                                                  |
[frontendhttpsport](#wls_cluster_frontendhttpsport)                                                                     | The name of the secure HTTP port to which all redirected URLs will be sent.                                                                                                                                           |
[greedy_session_flush_interval](#wls_cluster_greedy_session_flush_interval)                                             | Interval in seconds until HTTP Sessions are periodically flushed to secondary server.                                                                                                                                 |
[health_check_interval_millis](#wls_cluster_health_check_interval_millis)                                               | Interval in milliseconds at which Migratable Servers and Cluster Masters prove their liveness via the database.                                                                                                       |
[health_check_periods_until_fencing](#wls_cluster_health_check_periods_until_fencing)                                   | Maximum number of periods that a cluster member will wait before timing out a Cluster Master and also the maximum number of periods the Cluster Master will wait before timing out a Migratable Server.               |
[http_trace_support_enabled](#wls_cluster_http_trace_support_enabled)                                                   |  Returns the value of HttpTraceSupportEnabled.                                                                                                                                                                        |
[idle_periods_until_timeout](#wls_cluster_idle_periods_until_timeout)                                                   | Maximum number of periods that a cluster member will wait before timing out a member of a cluster.                                                                                                                    |
[inter_cluster_comm_link_health_check_interval](#wls_cluster_inter_cluster_comm_link_health_check_interval)             | If the cluster link between two clusters goes down, a trigger will run periodically to see if the link is restored.                                                                                                   |
[job_scheduler_table_name](#wls_cluster_job_scheduler_table_name)                                                       | The table name to use for storing timers active with the job scheduler
                                                                                                                                               |
[jta_abandon_timeout_seconds](#wls_cluster_jta_abandon_timeout_seconds)                                                 | Specifies the maximum amount of time, in seconds, a transaction manager persists in attempting to complete the second phase of a two-phase commit transaction.                                                        |
[jta_before_completion_iteration_limit](#wls_cluster_jta_before_completion_iteration_limit)                             | The maximum number of cycles that the transaction manager performs the <code>beforeCompletion</code> synchronization callback for this cluster.                                                                       |
[jta_checkpoint_interval_seconds](#wls_cluster_jta_checkpoint_interval_seconds)                                         | The interval at which the transaction manager creates a new transaction log file and checks all old transaction log files to see if they are ready to be deleted.                                                     |
[jta_clusterwide_recovery_enabled](#wls_cluster_jta_clusterwide_recovery_enabled)                                       | Indicates that cluster-wide recovery is used for distributed transactions.                                                                                                                                            |
[jta_completion_timeout_seconds](#wls_cluster_jta_completion_timeout_seconds)                                           | Specifies the maximum amount of time, in seconds, a transaction manager waits for all resource managers to respond and indicate if the transaction can be committed or rolled back.                                   |
[jta_cross_domain_recovery_retry_interval](#wls_cluster_jta_cross_domain_recovery_retry_interval)                       | The interval at which a store lock for a given server in a recovery domain will be checked for takeover eligibility.                                                                                                  |
[jta_cross_site_recovery_lease_expiration](#wls_cluster_jta_cross_site_recovery_lease_expiration)                       | The time after which a lease expires making it eligible for recovery by another site.                                                                                                                                 |
[jta_cross_site_recovery_lease_update](#wls_cluster_jta_cross_site_recovery_lease_update)                               | The time in seconds in which to update at lease timestamp.                                                                                                                                                            |
[jta_cross_site_recovery_retry_interval](#wls_cluster_jta_cross_site_recovery_retry_interval)                           | The interval at which a lease for a given server in a recovery domain will be checked for takeover eligibility.                                                                                                       |
[jta_determiner_candidate_resource_info_list](#wls_cluster_jta_determiner_candidate_resource_info_list)                 | Returns a list of one or more transaction resources (determiners).                                                                                                                                                    |
[jta_determiners](#wls_cluster_jta_determiners)                                                                         | Specifies a list of one or more transaction resources (determiners) separated by line breaks.                                                                                                                         |
[jta_forget_heuristics](#wls_cluster_jta_forget_heuristics)                                                             | Specifies whether the transaction manager automatically performs an XA Resource <code>forget</code> operation for heuristic transaction completions.                                                                  |
[jta_max_resource_requests_on_server](#wls_cluster_jta_max_resource_requests_on_server)                                 | Maximum number of concurrent requests to resources allowed for each server.                                                                                                                                           |
[jta_max_resource_unavailable_millis](#wls_cluster_jta_max_resource_unavailable_millis)                                 | Maximum duration time, in milliseconds, that a resource is declared dead.                                                                                                                                             |
[jta_max_retry_seconds_before_determiner_fail](#wls_cluster_jta_max_retry_seconds_before_determiner_fail)               | The maximum amount of time, in seconds, WebLogic Server waits for the determiner to recover from a failure.                                                                                                           |
[jta_max_transactions](#wls_cluster_jta_max_transactions)                                                               | The maximum number of simultaneous in-progress transactions allowed on a server in this cluster.                                                                                                                      |
[jta_max_transactions_health_interval_millis](#wls_cluster_jta_max_transactions_health_interval_millis)                 | The interval for which the transaction map must be full for the JTA subsystem to declare its health as CRITICAL.                                                                                                      |
[jta_max_unique_name_statistics](#wls_cluster_jta_max_unique_name_statistics)                                           | The maximum number of unique transaction names for which statistics are maintained.                                                                                                                                   |
[jta_max_xa_call_millis](#wls_cluster_jta_max_xa_call_millis)                                                           | Maximum allowed time duration, in milliseconds,  for XA calls to resources.                                                                                                                                           |
[jta_migration_checkpoint_interval_seconds](#wls_cluster_jta_migration_checkpoint_interval_seconds)                     | The time interval, in seconds,  that the checkpoint is done for the migrated transaction logs (TLOGs).                                                                                                                |
[jta_notes](#wls_cluster_jta_notes)                                                                                     | Optional information that you can include to describe this configuration.                                                                                                                                             |
[jta_parallel_xa_dispatch_policy](#wls_cluster_jta_parallel_xa_dispatch_policy)                                         | The dispatch policy to use when performing XA operations in parallel.                                                                                                                                                 |
[jta_parallel_xa_enabled](#wls_cluster_jta_parallel_xa_enabled)                                                         | Indicates that XA calls are executed in parallel if there are available threads.                                                                                                                                      |
[jta_purge_resource_from_checkpoint_interval_seconds](#wls_cluster_jta_purge_resource_from_checkpoint_interval_seconds) | The interval that a particular resource must be accessed within for it to be included in the checkpoint record.                                                                                                       |
[jta_recovery_site_name](#wls_cluster_jta_recovery_site_name)                                                           | The name of the site whose transactions this site/domain will recover in the event that intra-cluster transaction service migration is not successful or efficient.                                                   |
[jta_recovery_threshold_millis](#wls_cluster_jta_recovery_threshold_millis)                                             | The interval that recovery is attempted until the resource becomes available.                                                                                                                                         |
[jta_security_interop_mode](#wls_cluster_jta_security_interop_mode)                                                     | Specifies the security mode of the communication channel used for XA calls between servers that participate in a global transaction.                                                                                  |
[jta_serialize_enlistments_gc_interval_millis](#wls_cluster_jta_serialize_enlistments_gc_interval_millis)               | The time interval, in milliseconds, at which internal objects used to serialize resource enlistment are cleaned up.                                                                                                   |
[jta_shutdown_grace_period](#wls_cluster_jta_shutdown_grace_period)                                                     | Indicates how long the server should wait for active transactions to complete before allowing shutdown.                                                                                                               |
[jta_tags](#wls_cluster_jta_tags)                                                                                       | Return all tags on this Configuration MBean
                                                                                                                                                                          |
[jta_tightly_coupled_transactions_enabled](#wls_cluster_jta_tightly_coupled_transactions_enabled)                       | Indicates tight coupling of transaction branches that span different transaction manager systems.                                                                                                                     |
[jta_timeout_seconds](#wls_cluster_jta_timeout_seconds)                                                                 | Specifies the maximum amount of time, in seconds, an active transaction is allowed to be in the first phase of a two-phase commit transaction.                                                                        |
[jta_tlog_write_when_determiner_exists_enabled](#wls_cluster_jta_tlog_write_when_determiner_exists_enabled)             | Indicates two-phase transaction recovery logs are written even if one or more determiners are configured.                                                                                                             |
[jta_two_phase_enabled](#wls_cluster_jta_two_phase_enabled)                                                             | Indicates that the two-phase commit protocol is used to coordinate transactions across two or more resource managers.                                                                                                 |
[jta_unregister_resource_grace_period](#wls_cluster_jta_unregister_resource_grace_period)                               | The amount of time, in seconds, a  transaction manager waits for transactions involving the resource to complete before unregistering a resource.                                                                     |
[jta_wsat_issued_token_enabled](#wls_cluster_jta_wsat_issued_token_enabled)                                             | Specifies whether to use <code>issuedtoken</code> to enable authentication between the WS-AT coordinator and participant.                                                                                             |
[jta_wsat_transport_security_mode](#wls_cluster_jta_wsat_transport_security_mode)                                       |  Specifies transport security mode required by WebService Transaction endpoints.                                                                                                                                      |
[member_death_detector_enabled](#wls_cluster_member_death_detector_enabled)                                             | Enables faster Automatic Service Migration times with Database Leasing Basis.                                                                                                                                         |
[member_warmup_timeout_seconds](#wls_cluster_member_warmup_timeout_seconds)                                             | Maximum number of seconds that a cluster member will wait to discover and synchronize with other servers in the cluster.                                                                                              |
[message_ordering_enabled](#wls_cluster_message_ordering_enabled)                                                       | Forces unicast messages to be processed in order.                                                                                                                                                                     |
[messagingmode](#wls_cluster_messagingmode)                                                                             | Specifies the messaging type used in the cluster.                                                                                                                                                                     |
[migration_basis](#wls_cluster_migration_basis)                                                                         | Controls the mechanism used for server and service migration.                                                                                                                                                         |
[migration_datasource](#wls_cluster_migration_datasource)                                                               | The data source used by servers in the cluster during migration.                                                                                                                                                      |
[migration_table_name](#wls_cluster_migration_table_name)                                                               | Return the name of the table to be used for server migration.                                                                                                                                                         |
[migrationbasis](#wls_cluster_migrationbasis)                                                                           | Controls the mechanism used for server and service migration.                                                                                                                                                         |
[millis_to_sleep_between_auto_migration_attempts](#wls_cluster_millis_to_sleep_between_auto_migration_attempts)         | Controls how long of a pause there should be between the migration attempts described in getAdditionalAutoMigrationAttempts().                                                                                        |
[multicast_address](#wls_cluster_multicast_address)                                                                     | The multicast address used by cluster members to communicate with each other.                                                                                                                                         |
[multicast_buffer_size](#wls_cluster_multicast_buffer_size)                                                             | The multicast socket send/receive buffer size (at least 64 kilobytes).                                                                                                                                                |
[multicast_data_encryption](#wls_cluster_multicast_data_encryption)                                                     | Enables multicast data to be encrypted.                                                                                                                                                                               |
[multicast_port](#wls_cluster_multicast_port)                                                                           | The multicast port (between 1 and 65535) used by cluster members to communicate with each other.                                                                                                                      |
[multicast_send_delay](#wls_cluster_multicast_send_delay)                                                               | The amount of time (between 0 and 250 milliseconds) to delay sending message fragments over multicast in order to avoid OS-level buffer overflow.                                                                     |
[multicast_ttl](#wls_cluster_multicast_ttl)                                                                             | The number of network hops (between 1 and 255) that a cluster multicast message is allowed to travel.                                                                                                                 |
[multicastaddress](#wls_cluster_multicastaddress)                                                                       | The multicast address used by cluster members to communicate with each other.                                                                                                                                         |
[multicastport](#wls_cluster_multicastport)                                                                             | The multicast port (between 1 and 65535) used by cluster members to communicate with each other.                                                                                                                      |
[name](#wls_cluster_name)                                                                                               | The name.                                                                                                                                                                                                             |
[notes](#wls_cluster_notes)                                                                                             | Optional information that you can include to describe this configuration.                                                                                                                                             |
[number_of_servers_in_cluster_address](#wls_cluster_number_of_servers_in_cluster_address)                               | Number of servers to be listed from this cluster when generating a cluster address automatically.                                                                                                                     |
[one_way_rmi_for_replication_enabled](#wls_cluster_one_way_rmi_for_replication_enabled)                                 | Indicates if one-way RMI is being used for replication.                                                                                                                                                               |
[overload_failure_action](#wls_cluster_overload_failure_action)                                                         | Enable automatic forceshutdown of the server on failed state.                                                                                                                                                         |
[overload_free_memory_percent_high_threshold](#wls_cluster_overload_free_memory_percent_high_threshold)                 | Percentage free memory after which the server overload condition is cleared.                                                                                                                                          |
[overload_free_memory_percent_low_threshold](#wls_cluster_overload_free_memory_percent_low_threshold)                   | Percentage free memory below which the server is considered overloaded.                                                                                                                                               |
[overload_notes](#wls_cluster_overload_notes)                                                                           | Optional information that you can include to describe this configuration.                                                                                                                                             |
[overload_panic_action](#wls_cluster_overload_panic_action)                                                             | Exit the server process when the kernel encounters a panic condition like an unhandled OOME.                                                                                                                          |
[overload_server_failure_trigger](#wls_cluster_overload_server_failure_trigger)                                         | Configure a trigger that marks the server as failed when the condition is met.                                                                                                                                        |
[overload_shared_capacity_for_work_managers](#wls_cluster_overload_shared_capacity_for_work_managers)                   | Total number of requests that can be present in the server.                                                                                                                                                           |
[persist_sessions_on_shutdown](#wls_cluster_persist_sessions_on_shutdown)                                               | When shutting down servers, sessions are not updated.                                                                                                                                                                 |
[provider](#wls_cluster_provider)                                                                                       | resource.                                                                                                                                                                                                             |
[remote_cluster_address](#wls_cluster_remote_cluster_address)                                                           | Set the foreign cluster.                                                                                                                                                                                              |
[replication_channel](#wls_cluster_replication_channel)                                                                 | The channel name to be used for replication traffic.                                                                                                                                                                  |
[replication_timeout_enabled](#wls_cluster_replication_timeout_enabled)                                                 | Indicates if timeout should be applied to session replication calls.                                                                                                                                                  |
[secure_replication_enabled](#wls_cluster_secure_replication_enabled)                                                   | Servers in a cluster replicate session data.                                                                                                                                                                          |
[securereplication](#wls_cluster_securereplication)                                                                     | Servers in a cluster replicate session data.                                                                                                                                                                          |
[servers](#wls_cluster_servers)                                                                                         | The WebLogic servers which are part of this cluster.                                                                                                                                                                  |
[service_activation_request_response_timeout](#wls_cluster_service_activation_request_response_timeout)                 | The maximum time, in milliseconds seconds, for services to wait for response from cluster members.                                                                                                                    |
[service_age_threshold_seconds](#wls_cluster_service_age_threshold_seconds)                                             | The number of seconds (between 0 and 65534) by which the age of two conflicting services must differ before one is considered older than the other.                                                                   |
[session_flush_interval](#wls_cluster_session_flush_interval)                                                           | Interval in seconds until HTTP Sessions are periodically flushed to the backup cluster to dump session state on disk.                                                                                                 |
[session_flush_threshold](#wls_cluster_session_flush_threshold)                                                         | When number of sessions to be flushed reaches this threshold limit, sessions will be flushed to the backup cluster before the flush interval.                                                                         |
[session_lazy_deserialization_enabled](#wls_cluster_session_lazy_deserialization_enabled)                               | Enables increased efficiency with session replication.                                                                                                                                                                |
[session_state_query_protocol_enabled](#wls_cluster_session_state_query_protocol_enabled)                               | Indicates if session state query protocol is enabled.                                                                                                                                                                 |
[session_state_query_request_timeout](#wls_cluster_session_state_query_request_timeout)                                 | The maximum time, in seconds, for session state query request to wait for response from cluster members.                                                                                                              |
[tags](#wls_cluster_tags)                                                                                               | Return all tags on this Configuration MBean.                                                                                                                                                                          |
[timeout](#wls_cluster_timeout)                                                                                         | Timeout for applying a resource.                                                                                                                                                                                      |
[txn_affinity_enabled](#wls_cluster_txn_affinity_enabled)                                                               | If enabled, a server's transaction requests go to servers in the cluster that are already participating in the global transaction.                                                                                    |
[unicastbroadcastchannel](#wls_cluster_unicastbroadcastchannel)                                                         | Specifies the channel used to handle communications within a cluster.                                                                                                                                                 |
[wan_session_persistence_table_name](#wls_cluster_wan_session_persistence_table_name)                                   | Return the name of the table to be used for WAN session persistence.                                                                                                                                                  |
[weblogic_plugin_enabled](#wls_cluster_weblogic_plugin_enabled)                                                         | Specifies whether the proprietary <tt>WL-Proxy-Client-IP</tt> header should be used.                                                                                                                                  |




### additional_auto_migration_attempts<a name='wls_cluster_additional_auto_migration_attempts'>

A migratable server could fail to come up on every possible configured machine. This attribute controls how many further attempts, after the first one, should be tried.  Note that each attempt specified here indicates another full circuit of migrations amongst all the configured machines. So for a 3-server cluster, and the default value of 3, a total of 9 migrations will be attempted.  If it is set to -1, migrations will go on forever until the server starts.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       additional_auto_migration_attempts => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:additional_auto_migration_attempts']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### async_session_queue_timeout<a name='wls_cluster_async_session_queue_timeout'>

Interval in seconds until the producer thread will wait for the AsyncSessionQueue to become unblocked.  Should be similar to the RequestTimeOut as that will determine the longest that the queue should remain full.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       async_session_queue_timeout => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:async_session_queue_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### auto_migration_table_name<a name='wls_cluster_auto_migration_table_name'>

Return the name of the table to be used for server migration.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       auto_migration_table_name => 'ACTIVE'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:auto_migration_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### candidate_machines_for_migratable_servers<a name='wls_cluster_candidate_machines_for_migratable_servers'>

The set of machines (and order of preference) on which Node Manager will restart failed servers.
(Requires you to enable each server for automatic migration.)



[Back to overview of wls_cluster](#attributes)

### client_cert_proxy_enabled<a name='wls_cluster_client_cert_proxy_enabled'>

Specifies whether to honor the WL-Proxy-Client-Cert header coming with the request or not.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       client_cert_proxy_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:client_cert_proxy_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### cluster_address<a name='wls_cluster_cluster_address'>

The address that forms a portion of the URL a client uses to connect to this cluster, and that is used for generating EJB handles and entity EJB failover addresses. (This address may be either a DNS host name that maps to multiple IP addresses or a comma-separated list of single address host names or IP addresses.)  Defines the address to be used by clients to connect to this cluster. This address may be either a DNS host name that maps to multiple IP addresses or a comma separated list of single address host names or IP addresses. If network channels are configured, it is possible to set the cluster address on a per channel basis.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       cluster_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:cluster_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### cluster_broadcast_channel<a name='wls_cluster_cluster_broadcast_channel'>

Specifies the channel used to handle communications within a cluster. If no channel is specified the default channel is used. ClusterBroadcastChannel is only are supported if the unicast messaging type is used.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       cluster_broadcast_channel => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:cluster_broadcast_channel']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### cluster_messaging_mode<a name='wls_cluster_cluster_messaging_mode'>

Specifies the messaging type used in the cluster. Multicast messaging is provided for backwards compatibility.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       cluster_messaging_mode => 'unicast'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:cluster_messaging_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### cluster_name<a name='wls_cluster_cluster_name'>

The cluster name. This must be an alphanumeric string.

To identify an cluster, use:

    wls_cluster { 'domain_name/TheClusterName':
    ...
    }



[Back to overview of wls_cluster](#attributes)

### cluster_type<a name='wls_cluster_cluster_type'>

Optimizes cross-cluster replication for the type of network that servers in the clusters use for administrative communication.  To enhance the reliability of HTTP sessions, you can configure servers in one cluster to replicate the session data to servers in a different cluster. In such an environment, configure the clusters to be one of the following types:  <ul> <li><code>man</code> If the clustered servers can send their data through a metro area network (man) in which latency is negligible. With this ClusterType value, servers replicate session state synchronously and in memory only. For example, when serverA in cluster1 starts an HTTP session, its backup server, serverB in cluster2, immediately replicates this session in memory to Server B. </li>  <li><code>wan</code> If the clusters are far apart or send their data through a wide area network (wan) that experiences significant network latency. With this ClusterType value, a server replicates session state synchronously to the backup server in the same cluster and asynchronously to a server in the remote cluster. For example, when serverA in cluster1 starts an HTTP session, it sends the data to serverB in cluster1 and then asynchronously sends data to serverX in cluster 2. ServerX will persist the session state in the database.  If you persist session data in a replicating database, and if you prefer to use the database to replicate the data instead of WebLogic Server, choose a cluster type of <code>wan</code> and leave the remote cluster address undefined. WebLogic Server saves the session data to the local database and assumes that the database replicates data as needed. </li> </ul>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       cluster_type => 'none'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:cluster_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### clusteraddress<a name='wls_cluster_clusteraddress'>

The address that forms a portion of the URL a client uses to connect to this cluster, and that is used for generating EJB handles and entity EJB failover addresses. (This address may be either a DNS host name that maps to multiple IP addresses or an array of single address host names or IP addresses.)  Defines the address to be used by clients to connect to this cluster. This address may be either a DNS host name that maps to multiple IP addresses or a comma separated list of single address host names or IP addresses. If network channels are configured, it is possible to set the cluster address on a per channel basis.

An example on how to use this:

      wls_cluster { 'aCluster':
        ...
        clusteraddress => '10.10.10.30',
        ...
      }

  or use a host name like this:

      wls_cluster { 'aCluster':
        ...
        clusteraddress => 'myhost.exaqmple.com',
        ...
      }



[Back to overview of wls_cluster](#attributes)

### data_source_for_automatic_migration<a name='wls_cluster_data_source_for_automatic_migration'>

The data source used by servers in the cluster during migration. (You must configure each Migratable Server within the cluster to use this data source.)

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       data_source_for_automatic_migration => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:data_source_for_automatic_migration']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### data_source_for_job_scheduler<a name='wls_cluster_data_source_for_job_scheduler'>

Data source required to support persistence of jobs scheduled with the job scheduler

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       data_source_for_job_scheduler => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:data_source_for_job_scheduler']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### data_source_for_session_persistence<a name='wls_cluster_data_source_for_session_persistence'>

To support HTTP Session failover across data centers, a datasource is required to dump session state on disk.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       data_source_for_session_persistence => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:data_source_for_session_persistence']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### database_leasing_basis_connection_retry_count<a name='wls_cluster_database_leasing_basis_connection_retry_count'>

The maximum number of times Database Leasing will try to obtain a valid connection from the Data Source.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       database_leasing_basis_connection_retry_count => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:database_leasing_basis_connection_retry_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### database_leasing_basis_connection_retry_delay<a name='wls_cluster_database_leasing_basis_connection_retry_delay'>

The length of time, in milliseconds,Database Leasing will wait before attempting to obtain a new connection from the Data Source when a connection has failed.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       database_leasing_basis_connection_retry_delay => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:database_leasing_basis_connection_retry_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### datasourceforjobscheduler<a name='wls_cluster_datasourceforjobscheduler'>

Data source required to support persistence of jobs scheduled with the job scheduler

An example on how to use this:

      wls_cluster { 'aCluster':
        ...
        datasourceforjobscheduler => 'schedulerDatasource',
        ...
      }



[Back to overview of wls_cluster](#attributes)

### default_load_algorithm<a name='wls_cluster_default_load_algorithm'>

Defines the algorithm to be used for load-balancing between replicated services if none is specified for a particular service. The <tt>round-robin</tt> algorithm cycles through a list of WebLogic Server instances in order. <tt>Weight-based</tt> load balancing improves on the round-robin algorithm by taking into account a pre-assigned weight for each server. In <tt>random</tt> load balancing, requests are routed to servers at random.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       default_load_algorithm => 'round-robin'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:default_load_algorithm']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### disable_corrective_change<a name='wls_cluster_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_cluster](#attributes)

### disable_corrective_ensure<a name='wls_cluster_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_cluster](#attributes)

### domain<a name='wls_cluster_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_cluster](#attributes)

### ensure<a name='wls_cluster_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_cluster](#attributes)

### fencing_grace_period_millis<a name='wls_cluster_fencing_grace_period_millis'>

During automatic migration, if the Cluster Master determines a server to be dead, it waits for this period of time (in milliseconds) before the Cluster Master migrates the service to another server in the cluster.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       fencing_grace_period_millis => '30000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:fencing_grace_period_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### frontend_host<a name='wls_cluster_frontend_host'>

The name of the host to which all redirected URLs will be sent.  Sets the HTTP FrontendHost for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct HOST information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       frontend_host => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:frontend_host']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### frontend_http_port<a name='wls_cluster_frontend_http_port'>

The name of the HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       frontend_http_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:frontend_http_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### frontend_https_port<a name='wls_cluster_frontend_https_port'>

The name of the secure HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPSPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       frontend_https_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:frontend_https_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### frontendhost<a name='wls_cluster_frontendhost'>

The name of the host to which all redirected URLs will be sent.  Sets the HTTP FrontendHost for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct HOST information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      frontendhost => '10.10.10.30',
      ...
    }

or use a host name like this:

    wls_cluster { 'aCluster':
      ...
      frontendhost => 'myhost.exaqmple.com',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### frontendhttpport<a name='wls_cluster_frontendhttpport'>

The name of the HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

Here is an example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       frontend_http_port => 'a_value'
       ...
    }



[Back to overview of wls_cluster](#attributes)

### frontendhttpsport<a name='wls_cluster_frontendhttpsport'>

The name of the secure HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPSPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      frontendhttpport => '9000',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### greedy_session_flush_interval<a name='wls_cluster_greedy_session_flush_interval'>

Interval in seconds until HTTP Sessions are periodically flushed to secondary server.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       greedy_session_flush_interval => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:greedy_session_flush_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### health_check_interval_millis<a name='wls_cluster_health_check_interval_millis'>

Interval in milliseconds at which Migratable Servers and Cluster Masters prove their liveness via the database.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       health_check_interval_millis => '10000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:health_check_interval_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### health_check_periods_until_fencing<a name='wls_cluster_health_check_periods_until_fencing'>

Maximum number of periods that a cluster member will wait before timing out a Cluster Master and also the maximum number of periods the Cluster Master will wait before timing out a Migratable Server.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       health_check_periods_until_fencing => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:health_check_periods_until_fencing']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### http_trace_support_enabled<a name='wls_cluster_http_trace_support_enabled'>

 Returns the value of HttpTraceSupportEnabled.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       http_trace_support_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:http_trace_support_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### idle_periods_until_timeout<a name='wls_cluster_idle_periods_until_timeout'>

Maximum number of periods that a cluster member will wait before timing out a member of a cluster.  Maximum number of periods that a cluster member will wait before timing out a member of a cluster.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       idle_periods_until_timeout => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:idle_periods_until_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### inter_cluster_comm_link_health_check_interval<a name='wls_cluster_inter_cluster_comm_link_health_check_interval'>

If the cluster link between two clusters goes down, a trigger will run periodically to see if the link is restored. The duration is specified in milliseconds.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       inter_cluster_comm_link_health_check_interval => '30000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:inter_cluster_comm_link_health_check_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### job_scheduler_table_name<a name='wls_cluster_job_scheduler_table_name'>

The table name to use for storing timers active with the job scheduler

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       job_scheduler_table_name => 'weblogic_timers'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:job_scheduler_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_abandon_timeout_seconds<a name='wls_cluster_jta_abandon_timeout_seconds'>

Specifies the maximum amount of time, in seconds, a transaction manager persists in attempting to complete the second phase of a two-phase commit transaction.   During the second phase of a two-phase commit transaction, the transaction manager continues to try to complete the transaction until all resource managers indicate that the transaction is completed. After the abandon transaction timer expires, no further attempt is made to resolve the transaction. If the transaction is in a prepared state before being abandoned, the transaction manager rolls back the transaction to release any locks held on behalf of the abandoned transaction.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_abandon_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_abandon_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_before_completion_iteration_limit<a name='wls_cluster_jta_before_completion_iteration_limit'>

The maximum number of cycles that the transaction manager performs the <code>beforeCompletion</code> synchronization callback for this cluster.  Nothing prevents a Synchronization object from registering another during <code>beforeCompletion</code>, even those whose <code>beforeCompletions</code> have already been called. For example, an EJB can call another in its <code>ejbStore()</code> method. To accommodate this, the transaction manager calls all Synchronization objects, then repeats the cycle if new ones have been registered. This count sets a limit to the number of cycles that synchronization occurs.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_before_completion_iteration_limit => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_before_completion_iteration_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_checkpoint_interval_seconds<a name='wls_cluster_jta_checkpoint_interval_seconds'>

The interval at which the transaction manager creates a new transaction log file and checks all old transaction log files to see if they are ready to be deleted.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_checkpoint_interval_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_checkpoint_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_clusterwide_recovery_enabled<a name='wls_cluster_jta_clusterwide_recovery_enabled'>

Indicates that cluster-wide recovery is used for distributed transactions.  When enabled, recovery operations for a distributed transaction are applied to all the servers of the cluster hosting a InterposedTransactionManager rather than just the server hosting the InterposedTransactionManager.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_clusterwide_recovery_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_clusterwide_recovery_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_completion_timeout_seconds<a name='wls_cluster_jta_completion_timeout_seconds'>

Specifies the maximum amount of time, in seconds, a transaction manager waits for all resource managers to respond and indicate if the transaction can be committed or rolled back.  <ul><li> The default value is 0, which sets the value to approximately twice the default <code>transaction-timeout</code> value with a maximum value of 120 seconds. This value provides backward compatibility for prior releases without this setting.</li> <li>If the specified value is -1, the maximum value supported by this attribute is used. </li> <li>If the specified value exceeds the value set for <code>abandon-timeout-seconds</code>, the value of <code>abandon-timeout-seconds</code> is used. </li> </ul>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_completion_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_completion_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_cross_domain_recovery_retry_interval<a name='wls_cluster_jta_cross_domain_recovery_retry_interval'>

The interval at which a store lock for a given server in a recovery domain will be checked for takeover eligibility.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_cross_domain_recovery_retry_interval => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_cross_domain_recovery_retry_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_cross_site_recovery_lease_expiration<a name='wls_cluster_jta_cross_site_recovery_lease_expiration'>

The time after which a lease expires making it eligible for recovery by another site.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_cross_site_recovery_lease_expiration => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_cross_site_recovery_lease_expiration']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_cross_site_recovery_lease_update<a name='wls_cluster_jta_cross_site_recovery_lease_update'>

The time in seconds in which to update at lease timestamp.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_cross_site_recovery_lease_update => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_cross_site_recovery_lease_update']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_cross_site_recovery_retry_interval<a name='wls_cluster_jta_cross_site_recovery_retry_interval'>

The interval at which a lease for a given server in a recovery domain will be checked for takeover eligibility.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_cross_site_recovery_retry_interval => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_cross_site_recovery_retry_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_determiner_candidate_resource_info_list<a name='wls_cluster_jta_determiner_candidate_resource_info_list'>

Returns a list of one or more transaction resources (determiners). A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_determiner_candidate_resource_info_list => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_determiner_candidate_resource_info_list']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_determiners<a name='wls_cluster_jta_determiners'>

Specifies a list of one or more transaction resources (determiners) separated by line breaks. A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_determiners => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_determiners']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_forget_heuristics<a name='wls_cluster_jta_forget_heuristics'>

Specifies whether the transaction manager automatically performs an XA Resource <code>forget</code> operation for heuristic transaction completions.  When enabled, the transaction manager automatically performs an XA Resource <code>forget()</code> operation for all resources as soon as the transaction learns of a heuristic outcome. Disable this feature only if you know what to do with the resource when it reports a heuristic decision.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_forget_heuristics => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_forget_heuristics']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_max_resource_requests_on_server<a name='wls_cluster_jta_max_resource_requests_on_server'>

Maximum number of concurrent requests to resources allowed for each server.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_resource_requests_on_server => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_resource_requests_on_server']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_resource_unavailable_millis<a name='wls_cluster_jta_max_resource_unavailable_millis'>

Maximum duration time, in milliseconds, that a resource is declared dead. After the duration, the resource is declared available again, even if the resource provider does not explicitly re-register the resource.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_resource_unavailable_millis => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_resource_unavailable_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_retry_seconds_before_determiner_fail<a name='wls_cluster_jta_max_retry_seconds_before_determiner_fail'>

The maximum amount of time, in seconds, WebLogic Server waits for the determiner to recover from a failure. If the determiner does not recover after this period, WebLogic Server sets the TLog health state to HEALTH_FAILED.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_retry_seconds_before_determiner_fail => '300'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_retry_seconds_before_determiner_fail']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_transactions<a name='wls_cluster_jta_max_transactions'>

The maximum number of simultaneous in-progress transactions allowed on a server in this cluster.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_transactions => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_transactions']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_transactions_health_interval_millis<a name='wls_cluster_jta_max_transactions_health_interval_millis'>

The interval for which the transaction map must be full for the JTA subsystem to declare its health as CRITICAL.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_transactions_health_interval_millis => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_transactions_health_interval_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_unique_name_statistics<a name='wls_cluster_jta_max_unique_name_statistics'>

The maximum number of unique transaction names for which statistics are maintained.  The first 1001 unique transaction names are maintained as their own transaction name and stored in each statistic. After the 1001st transaction name is reached, the transaction name is stored as <code>weblogic.transaction.statistics.namedOverflow</code>, and the transaction statistic is also merged and maintained in <code>weblogic.transaction.statistics.namedOverflow</code>.  A transaction name typically represents a category of business transactions, such as "funds-transfer."

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_unique_name_statistics => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_unique_name_statistics']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_max_xa_call_millis<a name='wls_cluster_jta_max_xa_call_millis'>

Maximum allowed time duration, in milliseconds,  for XA calls to resources. If a particular XA call to a resource exceeds the limit, the resource is declared unavailable.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_max_xa_call_millis => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_max_xa_call_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_migration_checkpoint_interval_seconds<a name='wls_cluster_jta_migration_checkpoint_interval_seconds'>

The time interval, in seconds,  that the checkpoint is done for the migrated transaction logs (TLOGs).

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_migration_checkpoint_interval_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_migration_checkpoint_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_notes<a name='wls_cluster_jta_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_parallel_xa_dispatch_policy<a name='wls_cluster_jta_parallel_xa_dispatch_policy'>

The dispatch policy to use when performing XA operations in parallel.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_parallel_xa_dispatch_policy => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_parallel_xa_dispatch_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_parallel_xa_enabled<a name='wls_cluster_jta_parallel_xa_enabled'>

Indicates that XA calls are executed in parallel if there are available threads.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_parallel_xa_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_parallel_xa_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_purge_resource_from_checkpoint_interval_seconds<a name='wls_cluster_jta_purge_resource_from_checkpoint_interval_seconds'>

The interval that a particular resource must be accessed within for it to be included in the checkpoint record.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_purge_resource_from_checkpoint_interval_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_purge_resource_from_checkpoint_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_recovery_site_name<a name='wls_cluster_jta_recovery_site_name'>

The name of the site whose transactions this site/domain will recover in the event that intra-cluster transaction service migration is not successful or efficient.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_recovery_site_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_recovery_site_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_recovery_threshold_millis<a name='wls_cluster_jta_recovery_threshold_millis'>

The interval that recovery is attempted until the resource becomes available.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_recovery_threshold_millis => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_recovery_threshold_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_security_interop_mode<a name='wls_cluster_jta_security_interop_mode'>

Specifies the security mode of the communication channel used for XA calls between servers that participate in a global transaction. All server instances in a domain must have the same security mode setting.  Security Interoperability Mode options: <ul> <li>default  The transaction coordinator makes calls using the kernel identity over an admin channel if it is enabled, and <code>anonymous</code> otherwise. Man-in-the-middle attacks are possible if the admin channel is not enabled.</li>  <li>performance  The transaction coordinator makes calls using <code>anonymous</code> at all times. This implies a security risk since a malicious third party could then try to affect the outcome of transactions using a man-in-the-middle attack.</li>  <li>compatibility  The transaction coordinator makes calls as the kernel identity over an insecure channel. This is a high security risk because a successful man-in-the-middle attack would allow the attacker to gain administrative control over both domains. This setting should only be used when strong network security is in place. </li> </ul>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_security_interop_mode => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_security_interop_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_serialize_enlistments_gc_interval_millis<a name='wls_cluster_jta_serialize_enlistments_gc_interval_millis'>

The time interval, in milliseconds, at which internal objects used to serialize resource enlistment are cleaned up.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_serialize_enlistments_gc_interval_millis => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_serialize_enlistments_gc_interval_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_shutdown_grace_period<a name='wls_cluster_jta_shutdown_grace_period'>

Indicates how long the server should wait for active transactions to complete before allowing shutdown.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_shutdown_grace_period => '180'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_shutdown_grace_period']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_tags<a name='wls_cluster_jta_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_tightly_coupled_transactions_enabled<a name='wls_cluster_jta_tightly_coupled_transactions_enabled'>

Indicates tight coupling of transaction branches that span different transaction manager systems.   When enabled, WebLogic uses the transaction identifier of a transaction imported by the InterposedTransactionManager for XA calls rather than an internally mapped Xid. This applies to inter-domain WebLogic transactions and transactions imported from Tuxedo. This allows for tight coupling of transaction branches for transactions that span across different transaction manager systems.  If a transaction between WebLogic and Tuxedo resources uses a GridLink Data Source with GridLink Affinity enabled, the XA Affinity context is automatically used for the transaction.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_tightly_coupled_transactions_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_tightly_coupled_transactions_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_timeout_seconds<a name='wls_cluster_jta_timeout_seconds'>

Specifies the maximum amount of time, in seconds, an active transaction is allowed to be in the first phase of a two-phase commit transaction. If the specified amount of time expires, the transaction is automatically rolled back.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_tlog_write_when_determiner_exists_enabled<a name='wls_cluster_jta_tlog_write_when_determiner_exists_enabled'>

Indicates two-phase transaction recovery logs are written even if one or more determiners are configured.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_tlog_write_when_determiner_exists_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_tlog_write_when_determiner_exists_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_two_phase_enabled<a name='wls_cluster_jta_two_phase_enabled'>

Indicates that the two-phase commit protocol is used to coordinate transactions across two or more resource managers.  If not selected: <ul> <li> Two-phase commit is disabled and any attempt to use two-phase commit results in a RollbackException being thrown.</li> <li> All transaction logging is disabled, including checkpoint records.</li> </ul>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_two_phase_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_two_phase_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_unregister_resource_grace_period<a name='wls_cluster_jta_unregister_resource_grace_period'>

The amount of time, in seconds, a  transaction manager waits for transactions involving the resource to complete before unregistering a resource. This grace period helps minimize the risk of abandoned transactions because of an unregistered resource, such as a JDBC data source module packaged with an application.  During the specified grace period, the <code>unregisterResource</code> call blocks until the call returns and no new transactions are started for the associated resource. If the number of outstanding transactions for the resource goes to <code>0</code>, the <code>unregisterResource</code> call returns immediately.  At the end of the grace period, if outstanding transactions are associated with the resource, the <code>unregisterResource</code> call returns and a log message is written to the server on which the resource was previously registered.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_unregister_resource_grace_period => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_unregister_resource_grace_period']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### jta_wsat_issued_token_enabled<a name='wls_cluster_jta_wsat_issued_token_enabled'>

Specifies whether to use <code>issuedtoken</code> to enable authentication between the WS-AT coordinator and participant.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_wsat_issued_token_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_wsat_issued_token_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### jta_wsat_transport_security_mode<a name='wls_cluster_jta_wsat_transport_security_mode'>

 Specifies transport security mode required by WebService Transaction endpoints. Transport Security options: <ul> <li>SSLNotRequired All WebService Transaction protocol messages are exchanged over the HTTP channel.</li>  <li>SSLRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS.</li>  <li>ClientCertRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS, and WLS enforces the presence of client certificate </li> </ul>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       jta_wsat_transport_security_mode => 'SSLNotRequired'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:jta_wsat_transport_security_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### member_death_detector_enabled<a name='wls_cluster_member_death_detector_enabled'>

Enables faster Automatic Service Migration times with Database Leasing Basis.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       member_death_detector_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:member_death_detector_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### member_warmup_timeout_seconds<a name='wls_cluster_member_warmup_timeout_seconds'>

Maximum number of seconds that a cluster member will wait to discover and synchronize with other servers in the cluster. Normally, the member will be able to sync in 30 seconds. If the value of this attribute is higher, that does not necessarily mean that it will take longer for the member to warmup. Instead it defines an upper bound on the time that a server will wait to sync with the servers that it has discovered. If the value is set 0, servers will not attempt to discover other running server in the cluster during server initialization

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       member_warmup_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:member_warmup_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### message_ordering_enabled<a name='wls_cluster_message_ordering_enabled'>

Forces unicast messages to be processed in order. There are scenarios where JMS may update JNDI very frequently. It will result in a lot of messages over unicast. Due to the close proximity of messages the probability of out of order handling of messages increases which would trigger frequent state dumps. Frequent JNDI tree refresh may result in NameNotFoundException. Use this property to prevent out of order handling of messages.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       message_ordering_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:message_ordering_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### messagingmode<a name='wls_cluster_messagingmode'>

Specifies the messaging type used in the cluster. Multicast messaging is provided for backwards compatibility.

Here is an example on how to use this:
    wls_cluster { 'aCluster':
      ...
      messagingmode => 'multicast',
      ...
    }

Valid values are `absent`, `multicast`, `unicast`. 

[Back to overview of wls_cluster](#attributes)

### migration_basis<a name='wls_cluster_migration_basis'>

Controls the mechanism used for server and service migration. <ul> <li>Database -- Requires the availability of a high-availability database, such as Oracle RAC, to store leasing information. <li>Consensus -- Stores the leasing information in-memory within a cluster member. This option requires Node Manager to be configured and running. </ul> Note: Within a WebLogic Server installation, you can only use one type of leasing. Although it is possible to implement multiple features that use leasing within your environment, each must use the same kind of leasing.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       migration_basis => 'database'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:migration_basis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### migration_datasource<a name='wls_cluster_migration_datasource'>

The data source used by servers in the cluster during migration. (You must configure each Migratable Server within the cluster to use this data source.)

Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      migration_datasource => 'mydatasourcename',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### migration_table_name<a name='wls_cluster_migration_table_name'>

Return the name of the table to be used for server migration.

Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      migration_table_name => 'MYTABLE',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### migrationbasis<a name='wls_cluster_migrationbasis'>


Controls the mechanism used for server and service migration. <ul> <li>Database -- Requires the availability of a high-availability database, such as Oracle RAC, to store leasing information. <li>Consensus -- Stores the leasing information in-memory within a cluster member. This option requires Node Manager to be configured and running. </ul> Note: Within a WebLogic Server installation, you can only use one type of leasing. Although it is possible to implement multiple features that use leasing within your environment, each must use the same kind of leasing.

Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      migrationbasis => 'database',
      ...
    }

Valid values are `absent`, `consensus`, `database`. 

[Back to overview of wls_cluster](#attributes)

### millis_to_sleep_between_auto_migration_attempts<a name='wls_cluster_millis_to_sleep_between_auto_migration_attempts'>

Controls how long of a pause there should be between the migration attempts described in getAdditionalAutoMigrationAttempts(). Note that this delay only happens when the server has failed to come up on every machine.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       millis_to_sleep_between_auto_migration_attempts => '180000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:millis_to_sleep_between_auto_migration_attempts']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicast_address<a name='wls_cluster_multicast_address'>

The multicast address used by cluster members to communicate with each other.  The valid range is from from 224.0.0.0 to 239.255.255.255. The default value used by WebLogic Server is 239.192.0.0.  You should avoid using multicast addresses in the range x.0.0.1  This address should be unique to this cluster and should not be shared by other applications.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_address => '239.192.0.0'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicast_buffer_size<a name='wls_cluster_multicast_buffer_size'>

The multicast socket send/receive buffer size (at least 64 kilobytes).  Returns the multicast socket send/receive buffer size.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_buffer_size => '64'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicast_data_encryption<a name='wls_cluster_multicast_data_encryption'>

Enables multicast data to be encrypted. Only the multicast data is encrypted. Multicast header information is not encrypted.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_data_encryption => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_data_encryption']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### multicast_port<a name='wls_cluster_multicast_port'>

The multicast port (between 1 and 65535) used by cluster members to communicate with each other.  Defines the multicast port used by cluster members to communicate with each other.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_port => '7001'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicast_send_delay<a name='wls_cluster_multicast_send_delay'>

The amount of time (between 0 and 250 milliseconds) to delay sending message fragments over multicast in order to avoid OS-level buffer overflow.  Defines the number of milliseconds to delay sending message fragments over multicast in order to avoid OS-level buffer overflow.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_send_delay => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_send_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicast_ttl<a name='wls_cluster_multicast_ttl'>

The number of network hops (between 1 and 255) that a cluster multicast message is allowed to travel.  Defines the number of network hops that a cluster multicast message is allowed to travel. 1 restricts the cluster to one subnet.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       multicast_ttl => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:multicast_ttl']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### multicastaddress<a name='wls_cluster_multicastaddress'>

The multicast address used by cluster members to communicate with each other.  The valid range is from from 224.0.0.0 to 239.255.255.255. The default value used by WebLogic Server is 239.192.0.0.  You should avoid using multicast addresses in the range x.0.0.1  This address should be unique to this cluster and should not be shared by other applications.

You can use an ip address like this:

    wls_cluster { 'aCluster':
      ...
      multicastaddress => '10.10.10.30',
      ...
    }

or use a host name like this:

    wls_coherence_cluster { 'aCluster':
      ...
      multicastaddress => 'myhost.exaqmple.com',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### multicastport<a name='wls_cluster_multicastport'>

The multicast port (between 1 and 65535) used by cluster members to communicate with each other.  Defines the multicast port used by cluster members to communicate with each other.

Here is an example on how to use this on a regular WebLogic cluster:

    wls_cluster { 'aCluster':
      ...
      multicastport => '9000',
      ...
    }



[Back to overview of wls_cluster](#attributes)

### name<a name='wls_cluster_name'>

The name.



[Back to overview of wls_cluster](#attributes)

### notes<a name='wls_cluster_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### number_of_servers_in_cluster_address<a name='wls_cluster_number_of_servers_in_cluster_address'>

Number of servers to be listed from this cluster when generating a cluster address automatically. This setting has no effect if Cluster Address is explicitly set.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       number_of_servers_in_cluster_address => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:number_of_servers_in_cluster_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### one_way_rmi_for_replication_enabled<a name='wls_cluster_one_way_rmi_for_replication_enabled'>

Indicates if one-way RMI is being used for replication. One-way RMI also requires configuring replication ports on each server in the cluster.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       one_way_rmi_for_replication_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:one_way_rmi_for_replication_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### overload_failure_action<a name='wls_cluster_overload_failure_action'>

Enable automatic forceshutdown of the server on failed state. The server self-health monitoring detects fatal failures and mark the server as failed. The server can be restarted using NodeManager or a HA agent.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_failure_action => 'no-action'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_failure_action']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_free_memory_percent_high_threshold<a name='wls_cluster_overload_free_memory_percent_high_threshold'>

Percentage free memory after which the server overload condition is cleared. WorkManagers stop performing overloadActions and start regular execution once the overload condition is cleared.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_free_memory_percent_high_threshold => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_free_memory_percent_high_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_free_memory_percent_low_threshold<a name='wls_cluster_overload_free_memory_percent_low_threshold'>

Percentage free memory below which the server is considered overloaded. WorkManagers perform overloadAction once the server is marked as overloaded.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_free_memory_percent_low_threshold => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_free_memory_percent_low_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_notes<a name='wls_cluster_overload_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_panic_action<a name='wls_cluster_overload_panic_action'>

Exit the server process when the kernel encounters a panic condition like an unhandled OOME. An unhandled OOME could lead to inconsistent state and a server restart is advisable if backed by node manager or a HA agent.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_panic_action => 'system-exit'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_panic_action']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_server_failure_trigger<a name='wls_cluster_overload_server_failure_trigger'>

Configure a trigger that marks the server as failed when the condition is met. A failed server in turn can be configured to shutdown or go into admin state.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_server_failure_trigger => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_server_failure_trigger']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### overload_shared_capacity_for_work_managers<a name='wls_cluster_overload_shared_capacity_for_work_managers'>

Total number of requests that can be present in the server. This includes requests that are enqueued and those under execution.  The server performs a differentiated denial of service on reaching the shared capacity. A request with higher priority will be accepted in place of a lower priority request already in the queue. The lower priority request is kept waiting in the queue till all high priority requests are executed. Further enqueues of the low priority requests are rejected right away.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       overload_shared_capacity_for_work_managers => '65536'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:overload_shared_capacity_for_work_managers']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### persist_sessions_on_shutdown<a name='wls_cluster_persist_sessions_on_shutdown'>

When shutting down servers, sessions are not updated. If the primary and secondary servers of a session are shut down with no session updates, the session will be lost. Turning on PersistSessionsOnShutdown will save any active sessions to the database specified in {@link ClusterMBean#getDataSourceForSessionPersistence()} when a server is shutdown. The sessions will not be written at any other time. (For example, they are not saved via this mechanism if there is a server crash.)  This attribute is applicable both to session persistence on server shutdown or session persistence across a WAN.  Rolling upgrade can potentially have a bad interaction with traditional in-memory session replication.  As managed servers are shutdown and upgraded, in-memory servlet sessions will be lost if both primary and secondary are rebooted before a new request arrives for the session.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       persist_sessions_on_shutdown => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:persist_sessions_on_shutdown']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### provider<a name='wls_cluster_provider'>

The specific backend to use for this `wls_cluster`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a cluster in an WebLogic domain via regular WLST



[Back to overview of wls_cluster](#attributes)

### remote_cluster_address<a name='wls_cluster_remote_cluster_address'>

Set the foreign cluster. Cluster infrastructure uses this address to connect to foreign cluster for HTTP Session WAN/MAN failover.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       remote_cluster_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:remote_cluster_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### replication_channel<a name='wls_cluster_replication_channel'>

The channel name to be used for replication traffic. Cluster infrastructure uses this channel to send updates for HTTP sessions and stateful session beans. If none is set then the default channel will be used.  In order for this feature to work, the named channel must exist on all members of the cluster and must be configured to use the same protocol. It is valid for the selected channel to be configured to use a secure protocol.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       replication_channel => 'ReplicationChannel'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:replication_channel']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### replication_timeout_enabled<a name='wls_cluster_replication_timeout_enabled'>

Indicates if timeout should be applied to session replication calls.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       replication_timeout_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:replication_timeout_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### secure_replication_enabled<a name='wls_cluster_secure_replication_enabled'>

Servers in a cluster replicate session data. If a replication channel is defined then the session data will be sent using the replication channel protocol and secured replication settings will be ignored. If no replication channel is defined and secured replication is enabled then session data for in-memory replication will be sent over SSL using the default secured channel. However, this added security for replication traffic comes with a significant cluster performance degradation. It should only be enabled if security is of greater concern than performance degradation.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       secure_replication_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:secure_replication_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### securereplication<a name='wls_cluster_securereplication'>

Servers in a cluster replicate session data. If a replication channel is defined then the session data will be sent using the replication channel protocol and secured replication settings will be ignored. If no replication channel is defined and secured replication is enabled then session data for in-memory replication will be sent over SSL using the default secured channel. However, this added security for replication traffic comes with a significant cluster performance degradation. It should only be enabled if security is of greater concern than performance degradation.

Here is an example on how to use this:
    wls_cluster { 'aCluster':
      ...
      securereplication => 1,
      ...
    }

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### servers<a name='wls_cluster_servers'>

The WebLogic servers which are part of this cluster.
Here is an example on how to use this:

    wls_cluster { 'aCluster':
      ...
      servers => ['server_1','server_2],
      ...
    }



[Back to overview of wls_cluster](#attributes)

### service_activation_request_response_timeout<a name='wls_cluster_service_activation_request_response_timeout'>

The maximum time, in milliseconds seconds, for services to wait for response from cluster members.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       service_activation_request_response_timeout => '10000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:service_activation_request_response_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### service_age_threshold_seconds<a name='wls_cluster_service_age_threshold_seconds'>

The number of seconds (between 0 and 65534) by which the age of two conflicting services must differ before one is considered older than the other.  Defines the number of seconds by which the age of two conflicting services must differ before one is considered older than the other.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       service_age_threshold_seconds => '180'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:service_age_threshold_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### session_flush_interval<a name='wls_cluster_session_flush_interval'>

Interval in seconds until HTTP Sessions are periodically flushed to the backup cluster to dump session state on disk.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       session_flush_interval => '180'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:session_flush_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### session_flush_threshold<a name='wls_cluster_session_flush_threshold'>

When number of sessions to be flushed reaches this threshold limit, sessions will be flushed to the backup cluster before the flush interval. This helps the server to flush sessions faster under load.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       session_flush_threshold => '10000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:session_flush_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### session_lazy_deserialization_enabled<a name='wls_cluster_session_lazy_deserialization_enabled'>

Enables increased efficiency with session replication. Enabling this attribute should be used only when configuring a WebLogic domain for Oracle Exalogic.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       session_lazy_deserialization_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:session_lazy_deserialization_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### session_state_query_protocol_enabled<a name='wls_cluster_session_state_query_protocol_enabled'>

Indicates if session state query protocol is enabled.  The Session State Query protocol will query the local cluster for the location of a session state instance if a request arrives at a server that is neither the primary or secondary server.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       session_state_query_protocol_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:session_state_query_protocol_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### session_state_query_request_timeout<a name='wls_cluster_session_state_query_request_timeout'>

The maximum time, in seconds, for session state query request to wait for response from cluster members.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       session_state_query_request_timeout => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:session_state_query_request_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### tags<a name='wls_cluster_tags'>

Return all tags on this Configuration MBean.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### timeout<a name='wls_cluster_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_cluster](#attributes)

### txn_affinity_enabled<a name='wls_cluster_txn_affinity_enabled'>

If enabled, a server's transaction requests go to servers in the cluster that are already participating in the global transaction.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       txn_affinity_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:txn_affinity_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)

### unicastbroadcastchannel<a name='wls_cluster_unicastbroadcastchannel'>

Specifies the channel used to handle communications within a cluster. If no channel is specified the default channel is used. ClusterBroadcastChannel is only are supported if the unicast messaging type is used.

Here is an example on how to use this:
    wls_cluster { 'aCluster':
      ...
      unicastbroadcastchannel => 'my_cluster_channel',
      ...
    }

For this property Puppet is not able to figure out the final name
of the channel. So you have to take of the oridering yourself.



[Back to overview of wls_cluster](#attributes)

### wan_session_persistence_table_name<a name='wls_cluster_wan_session_persistence_table_name'>

Return the name of the table to be used for WAN session persistence.

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       wan_session_persistence_table_name => 'WLS_WAN_PERSISTENCE_TABLE'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:wan_session_persistence_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_cluster](#attributes)

### weblogic_plugin_enabled<a name='wls_cluster_weblogic_plugin_enabled'>

Specifies whether the proprietary <tt>WL-Proxy-Client-IP</tt> header should be used. (This needed only when WebLogic plugins are configured.)  Gets the weblogicPluginEnabled attribute of the ClusterMBean object

An example on how to use this:

    wls_cluster {a_wls_cluster :
       ...
       weblogic_plugin_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_cluster:weblogic_plugin_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_cluster](#attributes)
