---
title: wls coherence cluster
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a coherence cluster in a WebLogic domain.

Here is an example on how you should use this:

    wls_coherence_cluster { 'WebCoherenceCluster':
      ensure          => 'present',
      clusteringmode  => 'unicast',
      multicastport   => '33389',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
      unicastport     => '9999',
      storage_enabled =>  '1',
    }

In this example you are managing a cluster in the default domain. When you want to
manage a coherence cluster in a specific domain, you can use:

    wls_coherence_cluster { 'my_domain/defaultCoherenceCluster':
      ensure         => 'present',
      clusteringmode => 'unicast',
      multicastport  => '33387',
      unicastport    => '8888',
    }

Check [the Oracle Weblogic documentation](http://docs.oracle.com/middleware/1221/wls/INTRO/domains.htm#INTRO330)
for more documentation about setting up and managing a coherence cluster.

## Attributes



Attribute Name                                                                                            | Short Description                                                                                                                           |
--------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------- |
[cluster_listen_port](#wls_coherence_cluster_cluster_listen_port)                                         | The cluster listen port used by Coherence; Coherence cluster members use this port to discover and join, or create the cluster.             |
[clustering_mode](#wls_coherence_cluster_clustering_mode)                                                 | Specifies a clustering mode of either Unicast or Multicast.                                                                                 |
[clusteringmode](#wls_coherence_cluster_clusteringmode)                                                   | Specifies a clustering mode of either Unicast or Multicast.                                                                                 |
[coherence_cluster_name](#wls_coherence_cluster_coherence_cluster_name)                                   | The coherence cluster name.                                                                                                                 |
[compatibility_name](#wls_coherence_cluster_compatibility_name)                                           |  This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean. |
[deployment_order](#wls_coherence_cluster_deployment_order)                                               | An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.                 |
[deployment_principal_name](#wls_coherence_cluster_deployment_principal_name)                             | A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown.             |
[disable_corrective_change](#wls_coherence_cluster_disable_corrective_change)                             | Disable the modification of a resource when Puppet decides it is a corrective change.                                                       |
[disable_corrective_ensure](#wls_coherence_cluster_disable_corrective_ensure)                             | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                                   |
[domain](#wls_coherence_cluster_domain)                                                                   | With this parameter, you identify the domain, where your objects is in.                                                                     |
[ensure](#wls_coherence_cluster_ensure)                                                                   | The basic property that the resource should be in.                                                                                          |
[module_type](#wls_coherence_cluster_module_type)                                                         | The values match those defined by jsr88.                                                                                                    |
[multicast_listen_address](#wls_coherence_cluster_multicast_listen_address)                               | The IP address for the cluster multicast listener.                                                                                          |
[multicast_listen_port](#wls_coherence_cluster_multicast_listen_port)                                     | The port for the cluster multicast listener.                                                                                                |
[multicastaddress](#wls_coherence_cluster_multicastaddress)                                               | The IP address for the cluster multicast listener.                                                                                          |
[multicastport](#wls_coherence_cluster_multicastport)                                                     | The port for the cluster multicast listener.                                                                                                |
[name](#wls_coherence_cluster_name)                                                                       | The name.                                                                                                                                   |
[notes](#wls_coherence_cluster_notes)                                                                     | Optional information that you can include to describe this configuration.                                                                   |
[provider](#wls_coherence_cluster_provider)                                                               | resource.                                                                                                                                   |
[report_group_file](#wls_coherence_cluster_report_group_file)                                             | Get the report group file representing the superset of runtime metrics to be collected for this cluster.                                    |
[security_framework_enabled](#wls_coherence_cluster_security_framework_enabled)                           | Check if security framework is enabled
                                                                                                     |
[source_path](#wls_coherence_cluster_source_path)                                                         | 
                                                                                                                                           |
[storage_enabled](#wls_coherence_cluster_storage_enabled)                                                 | Enables coherence storage on its cluster/server targets
                                                                                    |
[tags](#wls_coherence_cluster_tags)                                                                       | Return all tags on this Configuration MBean
                                                                                                |
[target](#wls_coherence_cluster_target)                                                                   | An array of target names.                                                                                                                   |
[targettype](#wls_coherence_cluster_targettype)                                                           | An array of target types.                                                                                                                   |
[time_to_live](#wls_coherence_cluster_time_to_live)                                                       | Sets the time-to-live (TTL) setting for the multicast message.                                                                              |
[timeout](#wls_coherence_cluster_timeout)                                                                 | Timeout for applying a resource.                                                                                                            |
[transport](#wls_coherence_cluster_transport)                                                             | Specify the underlying transport protocol to use for cluster communication.                                                                 |
[unicast_listen_address](#wls_coherence_cluster_unicast_listen_address)                                   | The IP address for the cluster unicast listener.                                                                                            |
[unicast_listen_port](#wls_coherence_cluster_unicast_listen_port)                                         | The port for the cluster unicast listener.                                                                                                  |
[unicast_port_auto_adjust](#wls_coherence_cluster_unicast_port_auto_adjust)                               |  Specifies whether the unicast port will be automatically incremented if the port cannot be bound because it is already in use.             |
[unicastaddress](#wls_coherence_cluster_unicastaddress)                                                   | The IP address for the cluster unicast listener.                                                                                            |
[unicastport](#wls_coherence_cluster_unicastport)                                                         | The port for the cluster unicast listener.                                                                                                  |
[using_custom_cluster_configuration_file](#wls_coherence_cluster_using_custom_cluster_configuration_file) |  Specifies whether you are using a custom external Coherence cluster configuration file.                                                    |




### cluster_listen_port<a name='wls_coherence_cluster_cluster_listen_port'>

The cluster listen port used by Coherence; Coherence cluster members use this port to discover and join, or create the cluster. If unspecified, the Coherence cluster multicast listen port will be used.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       cluster_listen_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:cluster_listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### clustering_mode<a name='wls_coherence_cluster_clustering_mode'>

Specifies a clustering mode of either Unicast or Multicast. If multicast is undesirable or unavailable in an environment, or when an environment is not properly configured to support multicast, then setting up the Well Known Addresses (WKA) feature is required. All cluster multicast communication is disabled if WKA is enabled.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       clustering_mode => 'unicast'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:clustering_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### clusteringmode<a name='wls_coherence_cluster_clusteringmode'>

Specifies a clustering mode of either Unicast or Multicast. If multicast is undesirable or unavailable in an environment, or when an environment is not properly configured to support multicast, then setting up the Well Known Addresses (WKA) feature is required. All cluster multicast communication is disabled if WKA is enabled.

Here is an example on how to use this:

    wls_coherence_cluster { 'aCluster':
      ...
      clusteringmode => 'unicast',
      ...
    }

Valid values are `absent`, `multicast`, `unicast`. 

[Back to overview of wls_coherence_cluster](#attributes)

### coherence_cluster_name<a name='wls_coherence_cluster_coherence_cluster_name'>

The coherence cluster name.

To identify a coherence cluster, use:

    wls_coherence_cluster { 'domain_name/TheClusterName':
    ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### compatibility_name<a name='wls_coherence_cluster_compatibility_name'>

 This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.  Standalone modules in 8.1 have both an ApplicationMBean name and ComponentMBean name. This attribute stores the name of the latter, to be used when the server creates the transient ComponentMBean for backward compatibility.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       compatibility_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:compatibility_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### deployment_order<a name='wls_coherence_cluster_deployment_order'>

An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.  Units with lower values are deployed before those with higher values.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       deployment_order => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### deployment_principal_name<a name='wls_coherence_cluster_deployment_principal_name'>

A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown. This principal will be used to set the current subject when calling out into application code for interfaces such as ApplicationLifecycleListener. If no principal name is specified, then the anonymous principal will be used.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       deployment_principal_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:deployment_principal_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### disable_corrective_change<a name='wls_coherence_cluster_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_coherence_cluster](#attributes)

### disable_corrective_ensure<a name='wls_coherence_cluster_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_coherence_cluster](#attributes)

### domain<a name='wls_coherence_cluster_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_coherence_cluster](#attributes)

### ensure<a name='wls_coherence_cluster_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_coherence_cluster](#attributes)

### module_type<a name='wls_coherence_cluster_module_type'>

The values match those defined by jsr88. This attribute may move to another MBean.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       module_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:module_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### multicast_listen_address<a name='wls_coherence_cluster_multicast_listen_address'>

The IP address for the cluster multicast listener.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       multicast_listen_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:multicast_listen_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### multicast_listen_port<a name='wls_coherence_cluster_multicast_listen_port'>

The port for the cluster multicast listener.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       multicast_listen_port => '33387'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:multicast_listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### multicastaddress<a name='wls_coherence_cluster_multicastaddress'>

The IP address for the cluster multicast listener.

    wls_coherence_cluster { 'aCluster':
      ...
      multicastaddress => '10.10.10.30',
      ...
    }

or use a host name like this:

    wls_coherence_cluster { 'aCluster':
      ...
      multicastaddress => 'myhost.exaqmple.com',
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### multicastport<a name='wls_coherence_cluster_multicastport'>

The port for the cluster multicast listener.

Here is an example on how to use this:

    wls_coherence_cluster { 'aCluster':
      ...
      multicastport => '9000',
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### name<a name='wls_coherence_cluster_name'>

The name.



[Back to overview of wls_coherence_cluster](#attributes)

### notes<a name='wls_coherence_cluster_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### provider<a name='wls_coherence_cluster_provider'>

The specific backend to use for this `wls_coherence_cluster`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage coherence clusters



[Back to overview of wls_coherence_cluster](#attributes)

### report_group_file<a name='wls_coherence_cluster_report_group_file'>

Get the report group file representing the superset of runtime metrics to be collected for this cluster.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       report_group_file => 'em/coherence/report-group.xml'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:report_group_file']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### security_framework_enabled<a name='wls_coherence_cluster_security_framework_enabled'>

Check if security framework is enabled

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       security_framework_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:security_framework_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_coherence_cluster](#attributes)

### source_path<a name='wls_coherence_cluster_source_path'>



An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       source_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:source_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### storage_enabled<a name='wls_coherence_cluster_storage_enabled'>

Enables coherence storage on its cluster/server targets

Here is an example on how to use this:

    wls_coherence_cluster { 'aCluster':
      ...
      storage_enabled => '0',
      ...
    }

Valid values are `1`, `0`. 

[Back to overview of wls_coherence_cluster](#attributes)

### tags<a name='wls_coherence_cluster_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### target<a name='wls_coherence_cluster_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    wls_coherence_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### targettype<a name='wls_coherence_cluster_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    wls_coherence_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### time_to_live<a name='wls_coherence_cluster_time_to_live'>

Sets the time-to-live (TTL) setting for the multicast message. The TTL setting designates how far multicast UDP/IP packets can travel on a network. The TTL is expressed in terms of how many hops a packet survives; each network interface, router, and managed switch is considered one hop. The TTL value should be set to the lowest integer value that works. Setting the value too high can use unnecessary bandwidth on other LAN segments and can even cause the operating system or network devices to disable multicast traffic. Typically, setting the TTL value to 1 works on a simple switched backbone. A value of 2 or more may be required on an advanced backbone with intelligent switching. A value of 0 is used for single server clusters that are used for development and testing.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       time_to_live => '4'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### timeout<a name='wls_coherence_cluster_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_coherence_cluster](#attributes)

### transport<a name='wls_coherence_cluster_transport'>

Specify the underlying transport protocol to use for cluster communication. The TMB, SDMB, or IMB are only applicable to Exalogic environment.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       transport => 'udp'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:transport']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### unicast_listen_address<a name='wls_coherence_cluster_unicast_listen_address'>

The IP address for the cluster unicast listener.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       unicast_listen_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:unicast_listen_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### unicast_listen_port<a name='wls_coherence_cluster_unicast_listen_port'>

The port for the cluster unicast listener. A value of 0 indicates that the unicast listener port value will be derived from the server listen port. This value or the derived value will be used only if the CoherenceMemberConfigMBean unicast listen port is 0.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       unicast_listen_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:unicast_listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_cluster](#attributes)

### unicast_port_auto_adjust<a name='wls_coherence_cluster_unicast_port_auto_adjust'>

 Specifies whether the unicast port will be automatically incremented if the port cannot be bound because it is already in use.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       unicast_port_auto_adjust => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:unicast_port_auto_adjust']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_coherence_cluster](#attributes)

### unicastaddress<a name='wls_coherence_cluster_unicastaddress'>

The IP address for the cluster unicast listener.

    wls_coherence_cluster{'my_coherence_cluster':
      ...
      unicastaddress => '10.10.10.30',
      ...
    }

or use a host name like this:

    wls_coherence_cluster { 'aCluster':
      ...
      unicastaddress => 'myhost.exaqmple.com',
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### unicastport<a name='wls_coherence_cluster_unicastport'>

The port for the cluster unicast listener. A value of 0 indicates that the unicast listener port value will be derived from the server listen port. This value or the derived value will be used only if the CoherenceMemberConfigMBean unicast listen port is 0.

Here is an example on how to use this on a coherence cluster:

    wls_coherence_cluster{'my_coherence_cluster':
      ...
      unicastport => '9000',
      ...
    }



[Back to overview of wls_coherence_cluster](#attributes)

### using_custom_cluster_configuration_file<a name='wls_coherence_cluster_using_custom_cluster_configuration_file'>

 Specifies whether you are using a custom external Coherence cluster configuration file.

An example on how to use this:

    wls_coherence_cluster {a_wls_coherence_cluster :
       ...
       using_custom_cluster_configuration_file => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_cluster:using_custom_cluster_configuration_file']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_coherence_cluster](#attributes)
