---
title: wls domain
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage domain options.

This resource allows you to make changes to the existing WebLogic domain. You cannot
create a domain with this resource. If you want to create a domain, use `wls_install::domain`.
Here is an example on how you should use this:

    # In this case it will use default as wls_setting identifier
    wls_domain { 'Wls1036':
      ensure                                            => 'present',
      jmx_platform_mbean_server_enabled                 => 1,
      jmx_platform_mbean_server_used                    => 1,
      jpa_default_provider                              => 'org.eclipse.persistence.jpa.PersistenceProvider',
      jta_max_transactions                              => '20000',
      jta_transaction_timeout                           => '35',
      log_file_min_size                                 => '5000',
      log_filecount                                     => '10',
      log_filename                                      => '/var/log/weblogic/Wls1036.log',
      log_number_of_files_limited                       => 1,
      log_rotate_logon_startup                          => 1,
      log_rotationtype                                  => 'bySize',
      security_crossdomain                              => '0',
      web_app_container_show_archived_real_path_enabled => 1,
    }

In this example you are managing a domain in the default domain. When you want to
manage a domain in a specific domain, you can use:

    wls_domain { 'Wls11gSetting/Wls11g':
      ensure                                            => 'present',
      jmx_platform_mbean_server_enabled                 => '0',
      jmx_platform_mbean_server_used                    => 1,
      jpa_default_provider                              => 'org.apache.openjpa.persistence.PersistenceProviderImpl',
      jta_max_transactions                              => '10000',
      jta_transaction_timeout                           => '30',
      log_file_min_size                                 => '5000',
      log_filecount                                     => '5',
      log_filename                                      => '/var/log/weblogic/Wls11g.log',
      log_number_of_files_limited                       => '0',
      log_rotate_logon_startup                          => '0',
      log_rotationtype                                  => 'byTime',
      security_crossdomain                              => 1,
      web_app_container_show_archived_real_path_enabled => '0',
    }

## Attributes



Attribute Name                                                                                                               | Short Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
---------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[admin_server_name](#wls_domain_admin_server_name)                                                                           | 
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[administration_mbean_auditing_enabled](#wls_domain_administration_mbean_auditing_enabled)                                   | Specifies whether the Administration Server generates a log message when this WebLogic Server domain's configuration has been modified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[administration_port](#wls_domain_administration_port)                                                                       | The common secure administration port for this WebLogic Server domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[administration_port_enabled](#wls_domain_administration_port_enabled)                                                       | Specifies whether the domain-wide administration port should be enabled for this WebLogic Server domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[administration_protocol](#wls_domain_administration_protocol)                                                               | The default protocol for communicating through the administration port or administration channels.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[archive_configuration_count](#wls_domain_archive_configuration_count)                                                       | The number of archival versions of <tt>config.xml</tt> saved by the Administration Server each time the domain configuration is modified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[batch_jobs_data_source_jndi_name](#wls_domain_batch_jobs_data_source_jndi_name)                                             | Returns the Batch DataSource jndi name.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[batch_jobs_executor_service_name](#wls_domain_batch_jobs_executor_service_name)                                             | Returns the name of the application-scoped ManagedExecutorService.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[cluster_constraints_enabled](#wls_domain_cluster_constraints_enabled)                                                       | Specifies that deployments targeted to a cluster succeed only if all servers in the cluster are running.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[config_backup_enabled](#wls_domain_config_backup_enabled)                                                                   | If true, then backups of the configuration will be made during server boot.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[configuration_audit_type](#wls_domain_configuration_audit_type)                                                             | Returns the criteria used for auditing configuration events  (configuration changes and other operations): <ul> <li><code>CONFIG_CHANGE_NONE</code> Configuration events will neither be written to the server log or directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG</code> Configuration events will be written to the server log.</li> <li><code>CONFIG_CHANGE_AUDIT</code>Configuration events will be directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG_AND_AUDIT</code> Configuration events will be written to the server log and directed to the Security Audit Framework.</li> </ul>
 |
[configuration_version](#wls_domain_configuration_version)                                                                   | The release identifier for the configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[console_context_path](#wls_domain_console_context_path)                                                                     | The context path that you want to use in URLs that specify the Administration Console.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[console_enabled](#wls_domain_console_enabled)                                                                               | Specifies whether the Administration Server automatically deploys the Administration Console in the current domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[console_extension_directory](#wls_domain_console_extension_directory)                                                       | Returns the directory path that console extensions are loaded from.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[diagnostic_context_compatibility_mode_enabled](#wls_domain_diagnostic_context_compatibility_mode_enabled)                   | Specifies whether WLDF sends a pre-12.2.1-style diagnostic context along with the current-style diagnostic context.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[disable_corrective_change](#wls_domain_disable_corrective_change)                                                           | Disable the modification of a resource when Puppet decides it is a corrective change.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[disable_corrective_ensure](#wls_domain_disable_corrective_ensure)                                                           | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[domain](#wls_domain_domain)                                                                                                 | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[domain_name](#wls_domain_domain_name)                                                                                       | Domain name.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[domain_version](#wls_domain_domain_version)                                                                                 | Defines the common version of all servers in a domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[enable_ee_compliant_classloading_for_embedded_adapters](#wls_domain_enable_ee_compliant_classloading_for_embedded_adapters) | Specifies the class loading behavior for embedded adapters.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[ensure](#wls_domain_ensure)                                                                                                 | The basic property that the resource should be in.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[exalogic_optimizations_enabled](#wls_domain_exalogic_optimizations_enabled)                                                 | Specifies whether optimizations for Oracle Exalogic should be enabled.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[exalogicoptimizationsenabled](#wls_domain_exalogicoptimizationsenabled)                                                     | Enable or disabled exalogic optimizations.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[guardian_enabled](#wls_domain_guardian_enabled)                                                                             | Specifies whether the Guardian Agent is deployed when starting servers in the current domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[internal_apps_deploy_on_demand_enabled](#wls_domain_internal_apps_deploy_on_demand_enabled)                                 | Specifies whether internal applications such as the console, uddi, wlstestclient, and uddiexplorer are deployed on demand (first access) instead of during server startup.                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[java_service_console_enabled](#wls_domain_java_service_console_enabled)                                                     | Specifies whether the Administration Server automatically deploys the Java Service Administration Console in the current domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[java_service_enabled](#wls_domain_java_service_enabled)                                                                     | Specifies whether features to support the use of this WebLogic Server as a Java Service in a cloud environment should be enabled.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[jmx_compatibility_mbean_server_enabled](#wls_domain_jmx_compatibility_mbean_server_enabled)                                 | Enables JMX clients to use the deprecated <code>MBeanHome</code> interface.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jmx_domain_mbean_server_enabled](#wls_domain_jmx_domain_mbean_server_enabled)                                               | Specifies whether the Administration Server initializes the Domain MBean Server, which provides federated access to all run-time MBeans and read-only configuration MBeans in the domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jmx_edit_mbean_server_enabled](#wls_domain_jmx_edit_mbean_server_enabled)                                                   | Specifies whether the Administration Server initializes the Edit MBean Server, which contains the hierarchy of MBeans used to make modifications to the domain's configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
[jmx_invocation_timeout_seconds](#wls_domain_jmx_invocation_timeout_seconds)                                                 | The number of seconds that internal WebLogic Server processes wait to connect to an MBean server, invoke an MBean server method, and return the results of the invocation.                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[jmx_managed_server_notifications_enabled](#wls_domain_jmx_managed_server_notifications_enabled)                             | Specifies whether the WebLogic Server Domain Runtime MBean Server will support notifications from the federated Runtime MBean Servers on the managed and administration servers.                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[jmx_management_ejb_enabled](#wls_domain_jmx_management_ejb_enabled)                                                         | Enables access to the Management EJB (MEJB), which is part of the J2EE Management APIs (JSR-77).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[jmx_notes](#wls_domain_jmx_notes)                                                                                           | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jmx_platform_mbean_server_enabled](#wls_domain_jmx_platform_mbean_server_enabled)                                           | Platform MBean server enabled.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[jmx_platform_mbean_server_used](#wls_domain_jmx_platform_mbean_server_used)                                                 | Platform MBean server used.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jmx_runtime_mbean_server_enabled](#wls_domain_jmx_runtime_mbean_server_enabled)                                             | Specifies whether each server instance in the domain initializes its Runtime MBean Server, which provides access to a server's run-time MBeans and read-only configuration MBeans.                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[jmx_tags](#wls_domain_jmx_tags)                                                                                             | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[jpa_default_jpa_provider](#wls_domain_jpa_default_jpa_provider)                                                             | The configured default JPA provider for the domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[jpa_default_provider](#wls_domain_jpa_default_provider)                                                                     | The JPA default provider java class.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[jpa_notes](#wls_domain_jpa_notes)                                                                                           | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jpa_tags](#wls_domain_jpa_tags)                                                                                             | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[jta_abandon_timeout_seconds](#wls_domain_jta_abandon_timeout_seconds)                                                       | Specifies the maximum amount of time, in seconds, a transaction manager persists in attempting to complete the second phase of a two-phase commit transaction.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[jta_before_completion_iteration_limit](#wls_domain_jta_before_completion_iteration_limit)                                   | The maximum number of cycles that the transaction manager performs the <tt>beforeCompletion</tt> synchronization callback for this WebLogic Server domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[jta_checkpoint_interval_seconds](#wls_domain_jta_checkpoint_interval_seconds)                                               | The interval at which the transaction manager creates a new transaction log file and checks all old transaction log files to see if they are ready to be deleted.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[jta_clusterwide_recovery_enabled](#wls_domain_jta_clusterwide_recovery_enabled)                                             | Indicates that cluster-wide recovery is used for distributed transactions.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[jta_completion_timeout_seconds](#wls_domain_jta_completion_timeout_seconds)                                                 | Specifies the maximum amount of time, in seconds, a transaction manager waits for all resource managers to respond and indicate if the transaction can be committed or rolled back.                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[jta_cross_domain_recovery_retry_interval](#wls_domain_jta_cross_domain_recovery_retry_interval)                             | The interval at which a store lock for a given server in a recovery domain will be checked for takeover eligibility.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[jta_determiner_candidate_resource_info_list](#wls_domain_jta_determiner_candidate_resource_info_list)                       | Returns a list of one or more transaction resources (determiners).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[jta_determiners](#wls_domain_jta_determiners)                                                                               | Specifies a list of one or more transaction resources (determiners) separated by line breaks.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[jta_forget_heuristics](#wls_domain_jta_forget_heuristics)                                                                   | Specifies whether the transaction manager automatically performs an XA Resource <code>forget</code> operation for heuristic transaction completions.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[jta_max_resource_requests_on_server](#wls_domain_jta_max_resource_requests_on_server)                                       | Maximum number of concurrent requests to resources allowed for each server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jta_max_resource_unavailable_millis](#wls_domain_jta_max_resource_unavailable_millis)                                       | Maximum duration time, in milliseconds, that a resource is declared dead.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jta_max_retry_seconds_before_determiner_fail](#wls_domain_jta_max_retry_seconds_before_determiner_fail)                     | The maximum amount of time, in seconds, WebLogic Server waits for the determiner to recover from a failure.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jta_max_transactions](#wls_domain_jta_max_transactions)                                                                     | The JTA transaction max transactions value.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jta_max_unique_name_statistics](#wls_domain_jta_max_unique_name_statistics)                                                 | The maximum number of unique transaction names for which statistics are maintained.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[jta_max_xa_call_millis](#wls_domain_jta_max_xa_call_millis)                                                                 | Maximum allowed time duration, in milliseconds,  for XA calls to resources.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[jta_notes](#wls_domain_jta_notes)                                                                                           | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jta_parallel_xa_enabled](#wls_domain_jta_parallel_xa_enabled)                                                               | Indicates that XA calls are executed in parallel if there are available threads.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[jta_recovery_site_name](#wls_domain_jta_recovery_site_name)                                                                 | The name of the site whose transactions this site/domain will recover in the event that intra-cluster transaction service migration is not successful or efficient.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[jta_security_interop_mode](#wls_domain_jta_security_interop_mode)                                                           | Specifies the security mode of the communication channel used for XA calls between servers that participate in a global transaction.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[jta_serialize_enlistments_gc_interval_millis](#wls_domain_jta_serialize_enlistments_gc_interval_millis)                     | The time interval, in milliseconds, at which internal objects used to serialize resource enlistment are cleaned up.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[jta_shutdown_grace_period](#wls_domain_jta_shutdown_grace_period)                                                           | Indicates how long the server should wait for active transactions to complete before allowing shutdown.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[jta_tags](#wls_domain_jta_tags)                                                                                             | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[jta_tightly_coupled_transactions_enabled](#wls_domain_jta_tightly_coupled_transactions_enabled)                             | Indicates tight coupling of transaction branches that span different transaction manager systems.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[jta_timeout_seconds](#wls_domain_jta_timeout_seconds)                                                                       | Specifies the maximum amount of time, in seconds, an active transaction is allowed to be in the first phase of a two-phase commit transaction.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[jta_tlog_write_when_determiner_exists_enabled](#wls_domain_jta_tlog_write_when_determiner_exists_enabled)                   | Indicates two-phase transaction recovery logs are written even if one or more determiners are configured.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jta_transaction_timeout](#wls_domain_jta_transaction_timeout)                                                               | The JTA transaction timeout value.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[jta_two_phase_enabled](#wls_domain_jta_two_phase_enabled)                                                                   | Indicates that the two-phase commit protocol is used to coordinate transactions across two or more resource managers.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[jta_unregister_resource_grace_period](#wls_domain_jta_unregister_resource_grace_period)                                     | The amount of time, in seconds, a  transaction manager waits for transactions involving the resource to complete before unregistering a resource.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[jta_wsat_issued_token_enabled](#wls_domain_jta_wsat_issued_token_enabled)                                                   | Specifies whether to use <code>issuedtoken</code> to enable authentication between the WS-AT coordinator and participant.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[jta_wsat_transport_security_mode](#wls_domain_jta_wsat_transport_security_mode)                                             |  Specifies transport security mode required by WebService Transaction endpoints.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[log_buffer_size_kb](#wls_domain_log_buffer_size_kb)                                                                         | Gets the underlying log buffer size in kilobytes
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[log_date_format_pattern](#wls_domain_log_date_format_pattern)                                                               | The date format pattern used for rendering dates in the  log.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[log_date_pattern](#wls_domain_log_date_pattern)                                                                             | The date format pattern used for rendering dates in the log.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[log_domain_log_broadcast_filter](#wls_domain_log_domain_log_broadcast_filter)                                               | The filter configuration for log events being sent to the domain log.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[log_domain_log_broadcast_severity](#wls_domain_log_domain_log_broadcast_severity)                                           | The minimum severity of log messages going to the domain log from this server's log broadcaster.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[log_domain_log_broadcaster_buffer_size](#wls_domain_log_domain_log_broadcaster_buffer_size)                                 | Broadcasts log messages to the domain log in batch mode.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_file_count](#wls_domain_log_file_count)                                                                                 | The maximum number of log files that the server creates when it rotates the log.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[log_file_filter](#wls_domain_log_file_filter)                                                                               | The filter configuration for the server log file.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[log_file_min_size](#wls_domain_log_file_min_size)                                                                           | The log file min size of a domain or server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[log_file_name](#wls_domain_log_file_name)                                                                                   | The name of the file that stores current log messages.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[log_file_rotation_dir](#wls_domain_log_file_rotation_dir)                                                                   | The directory where the rotated log files will be stored.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[log_file_severity](#wls_domain_log_file_severity)                                                                           | The minimum severity of log messages going to the server log file.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[log_file_time_span](#wls_domain_log_file_time_span)                                                                         | The interval (in hours) at which the server saves old log messages to another file.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[log_filecount](#wls_domain_log_filecount)                                                                                   | The log file count of a domain or server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[log_filename](#wls_domain_log_filename)                                                                                     | The domain log filename.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_format_compatibility_enabled](#wls_domain_log_format_compatibility_enabled)                                             | Configures whether log messages will be logged in legacy format without supplemental attributes.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[log_log4j_logging_enabled](#wls_domain_log_log4j_logging_enabled)                                                           | Specifies whether the server logging is based on a Log4j implementation.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_logger_severity](#wls_domain_log_logger_severity)                                                                       | The minimum severity of log messages going to all log destinations.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[log_logger_severity_properties](#wls_domain_log_logger_severity_properties)                                                 | The configuration of the different logger severities keyed by name.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[log_memory_buffer_filter](#wls_domain_log_memory_buffer_filter)                                                             | The filter configuration for messages that are stored in the log memory buffer.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
[log_memory_buffer_severity](#wls_domain_log_memory_buffer_severity)                                                         | The minimum severity of log messages going to the memory buffer of recent log events.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[log_memory_buffer_size](#wls_domain_log_memory_buffer_size)                                                                 | The size of the memory buffer that holds the last n log records.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[log_monitoring_enabled](#wls_domain_log_monitoring_enabled)                                                                 | Enable or disable log monitoring.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
[log_monitoring_interval_secs](#wls_domain_log_monitoring_interval_secs)                                                     | Timer interval in seconds to check the counts of messages logged during the interval.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[log_monitoring_throttle_message_length](#wls_domain_log_monitoring_throttle_message_length)                                 | Cut-off length of the log message for evaluation during throttle period.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_monitoring_throttle_threshold](#wls_domain_log_monitoring_throttle_threshold)                                           | The threshold number of messages logged during the evaluation period which enables or disables the throttling.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[log_notes](#wls_domain_log_notes)                                                                                           | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[log_number_of_files_limited](#wls_domain_log_number_of_files_limited)                                                       | Indicates whether to limit the number of log files that this server instance creates to store old messages.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[log_platform_logger_levels](#wls_domain_log_platform_logger_levels)                                                         | Specifies the platform logger and the associated level names set through the WebLogic Server configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[log_redirect_stderr_to_server_log_enabled](#wls_domain_log_redirect_stderr_to_server_log_enabled)                           | Specifies whether the stderr of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic Logging system.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[log_redirect_stdout_to_server_log_enabled](#wls_domain_log_redirect_stdout_to_server_log_enabled)                           | Specifies whether the stdout of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic logging system.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[log_rotate_log_on_startup](#wls_domain_log_rotate_log_on_startup)                                                           | Specifies whether a server rotates its log file during its startup cycle.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[log_rotate_logon_startup](#wls_domain_log_rotate_logon_startup)                                                             | log rotate Logon at startup of a domain or server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[log_rotation_time](#wls_domain_log_rotation_time)                                                                           | Determines the start time (hour and minute) for a time-based rotation sequence.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
[log_rotation_type](#wls_domain_log_rotation_type)                                                                           | Criteria for moving old log messages to a separate file.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_rotationtype](#wls_domain_log_rotationtype)                                                                             | log rotation type of a domain or server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[log_server_logging_bridge_use_parent_loggers_enabled](#wls_domain_log_server_logging_bridge_use_parent_loggers_enabled)     | Specifies whether application log messages are propagated to the parent node in the Logger tree or to the WebLogic Server log by means of the Logging Bridge.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[log_stdout_filter](#wls_domain_log_stdout_filter)                                                                           | The filter configuration for log events being sent to the standard out.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[log_stdout_format](#wls_domain_log_stdout_format)                                                                           | The output format to use when logging to the console.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
[log_stdout_log_stack](#wls_domain_log_stdout_log_stack)                                                                     | Specifies whether to dump stack traces to the console when included in logged message.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[log_stdout_severity](#wls_domain_log_stdout_severity)                                                                       | The minimum severity of log messages going to the standard out.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
[log_tags](#wls_domain_log_tags)                                                                                             | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[max_concurrent_long_running_requests](#wls_domain_max_concurrent_long_running_requests)                                     | The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the global/domain partition on the current server.                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[max_concurrent_new_threads](#wls_domain_max_concurrent_new_threads)                                                         | The maximum number of running threads that can be created by all the Managed Thread Factories in the global/domain partition on the current server.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[name](#wls_domain_name)                                                                                                     | The name.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[notes](#wls_domain_notes)                                                                                                   | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[parallel_deploy_application_modules](#wls_domain_parallel_deploy_application_modules)                                       | Determines if the modules of applications will be deployed in parallel.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[parallel_deploy_applications](#wls_domain_parallel_deploy_applications)                                                     | Determines if applications will be deployed in parallel.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[production_mode_enabled](#wls_domain_production_mode_enabled)                                                               | Specifies whether all servers in this domain run in production mode.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[provider](#wls_domain_provider)                                                                                             | resource.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[root_directory](#wls_domain_root_directory)                                                                                 | Return the root directory for the domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[security_administrative_identity_domain](#wls_domain_security_administrative_identity_domain)                               | Domain's administrative identity domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[security_anonymous_admin_lookup_enabled](#wls_domain_security_anonymous_admin_lookup_enabled)                               | Returns true if anonymous JNDI access for Admin MBean home is permitted.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[security_clear_text_credential_access_enabled](#wls_domain_security_clear_text_credential_access_enabled)                   | Returns true if allow access to credential in clear text.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[security_compatibility_connection_filters_enabled](#wls_domain_security_compatibility_connection_filters_enabled)           | Specifies whether this WebLogic Server domain enables compatiblity with previous connection filters.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[security_connection_filter](#wls_domain_security_connection_filter)                                                         | The name of the Java class that implements a connection filter (that is, the <tt>weblogic.security.net.ConnectionFilter</tt> interface).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
[security_connection_filter_rules](#wls_domain_security_connection_filter_rules)                                             | The rules used by any connection filter that implements the <tt>ConnectionFilterRulesListener</tt> interface.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[security_connection_logger_enabled](#wls_domain_security_connection_logger_enabled)                                         | Specifies whether this WebLogic Server domain should log accepted connections.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[security_console_full_delegation_enabled](#wls_domain_security_console_full_delegation_enabled)                             | Indicates whether the console is enabled for fully delegate authorization.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[security_credential](#wls_domain_security_credential)                                                                       | The password for the domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[security_cross_domain_security_enabled](#wls_domain_security_cross_domain_security_enabled)                                 |  Indicates whether or not cross-domain security is enabled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[security_crossdomain](#wls_domain_security_crossdomain)                                                                     | The cross domain enabled.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[security_downgrade_untrusted_principals](#wls_domain_security_downgrade_untrusted_principals)                               | Whether or not to downgrade to anonymous principals that cannot be verified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[security_enforce_strict_url_pattern](#wls_domain_security_enforce_strict_url_pattern)                                       | Whether or not the system should enforce strict URL pattern or not.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
[security_enforce_valid_basic_auth_credentials](#wls_domain_security_enforce_valid_basic_auth_credentials)                   | Whether or not the system should allow requests with invalid Basic Authentication credentials to access unsecure resources.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[security_excluded_domain_names](#wls_domain_security_excluded_domain_names)                                                 |  Specifies a list of remote domains for which cross-domain check should not be applied.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[security_identity_domain_aware_providers_required](#wls_domain_security_identity_domain_aware_providers_required)           | Returns true if all role mapping, authorization, credential mapping, and audit providers configured in the domain must support the IdentityDomainAwareProviderMBean interface's administrative identity domain.                                                                                                                                                                                                                                                                                                                                                                                                                                    |
[security_node_manager_password](#wls_domain_security_node_manager_password)                                                 | The password that the Administration Server uses to communicate with Node Manager when starting, stopping, or restarting Managed Servers.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[security_node_manager_username](#wls_domain_security_node_manager_username)                                                 | The user name that the Administration Server uses to communicate with Node Manager when starting, stopping, or restarting Managed Servers.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[security_nonce_timeout_seconds](#wls_domain_security_nonce_timeout_seconds)                                                 | Returns the value of the nonce timeout in seconds.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
[security_notes](#wls_domain_security_notes)                                                                                 | Optional information that you can include to describe this configuration.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[security_principal_equals_case_insensitive](#wls_domain_security_principal_equals_case_insensitive)                         | Specifies whether the WebLogic Server principal name is compared using a case insensitive match when the equals method for the principal object is performed.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[security_principal_equals_compare_dn_and_guid](#wls_domain_security_principal_equals_compare_dn_and_guid)                   | Specifies whether the GUID and DN data in a WebLogic Server principal object are used when the equals method of that object is invoked.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
[security_tags](#wls_domain_security_tags)                                                                                   | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[security_use_kss_for_demo](#wls_domain_security_use_kss_for_demo)                                                           | Determines whether the Demo Identity and Demo Trust key stores should be obtained from the Oracle Key Store Service (KSS).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
[security_web_app_files_case_insensitive](#wls_domain_security_web_app_files_case_insensitive)                               | This property defines the case sensitive URL-pattern matching behavior for security constraints, servlets, filters, virtual-hosts, and so on, in the Web application container and external security policies.                                                                                                                                                                                                                                                                                                                                                                                                                                     |
[server_migration_history_size](#wls_domain_server_migration_history_size)                                                   | Gets the history size of server migrations.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[service_migration_history_size](#wls_domain_service_migration_history_size)                                                 | Gets the history size of service migrations.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[setarchiveconfigurationcount](#wls_domain_setarchiveconfigurationcount)                                                     | The amount of archived backups of the domain configuration file retained.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
[setconfigbackupenabled](#wls_domain_setconfigbackupenabled)                                                                 | Enable or disable configuration backup for the domain.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
[setconfigurationaudittype](#wls_domain_setconfigurationaudittype)                                                           | The configuration audit type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
[setinternalappdeploymentondemandenable](#wls_domain_setinternalappdeploymentondemandenable)                                 | Enable or disabled internal app deployment.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
[site_name](#wls_domain_site_name)                                                                                           | The name of the site this domain is associated with.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
[tags](#wls_domain_tags)                                                                                                     | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
[timeout](#wls_domain_timeout)                                                                                               | Timeout for applying a resource.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
[web_app_container_show_archived_real_path_enabled](#wls_domain_web_app_container_show_archived_real_path_enabled)           | Archived real path enabled.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |




### admin_server_name<a name='wls_domain_admin_server_name'>



An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       admin_server_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:admin_server_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### administration_mbean_auditing_enabled<a name='wls_domain_administration_mbean_auditing_enabled'>

Specifies whether the Administration Server generates a log message when this WebLogic Server domain's configuration has been modified.  Any change to a server, module, or other item in the domain (either through the Administration Console, command-line utilities, or the APIs) will cause the Administration Server to generate this informational message.   This attribute has been deprecated in favor of ConfigurationAuditType. If values for both attributes are specified, the resultant behavior will be the logical OR condition of the two settings.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       administration_mbean_auditing_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:administration_mbean_auditing_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### administration_port<a name='wls_domain_administration_port'>

The common secure administration port for this WebLogic Server domain. (Requires you to enable the administration port.)

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       administration_port => '9002'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:administration_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### administration_port_enabled<a name='wls_domain_administration_port_enabled'>

Specifies whether the domain-wide administration port should be enabled for this WebLogic Server domain. Because the administration port uses SSL, enabling the administration port requires that SSL must be configured for all servers in the domain.  The domain-wide administration port enables you to start a WebLogic Server instance in <code>STANDBY</code> state. It also allows you to separate administration traffic from application traffic in your domain. Because all servers in the domain must enable or disable the administration port at once, you configure the default administration port settings at the domain level.  If you enable the administration port:  <ul> <li> The administration port accepts only connections that specify administrator credentials. </li>  <li> Connections that specify administrator credentials can use only the administration port. </li>  <li> The command that starts managed servers must specify a secure protocol and the administration port: <code>-Dweblogic.management.server=https://admin_server:administration_port</code> </li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       administration_port_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:administration_port_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### administration_protocol<a name='wls_domain_administration_protocol'>

The default protocol for communicating through the administration port or administration channels. (Requires you to enable the administration port or to create an administration channel.)  If requests through the administration port or an administration channel do not specify a protocol, WebLogic Server uses the protocol specified here.  Valid admin protocols are: <ul> <li> t3s <li> https <li> iiops </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       administration_protocol => 't3s'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:administration_protocol']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### archive_configuration_count<a name='wls_domain_archive_configuration_count'>

The number of archival versions of <tt>config.xml</tt> saved by the Administration Server each time the domain configuration is modified.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       archive_configuration_count => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:archive_configuration_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### batch_jobs_data_source_jndi_name<a name='wls_domain_batch_jobs_data_source_jndi_name'>

Returns the Batch DataSource jndi name. This jndi name will be used to lookup an instance of a DataSource that will be used to store the Batch jobs data.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       batch_jobs_data_source_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:batch_jobs_data_source_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### batch_jobs_executor_service_name<a name='wls_domain_batch_jobs_executor_service_name'>

Returns the name of the application-scoped ManagedExecutorService. This ManagedExecutorService instance will be used to run batch jobs that are submitted from applications deployed to the domain. The ManagedExecutorServiceTemplate by the same name must exit when a batch job is submitted in the domain. If this returns null, then the batch runtime will look to use the default Java EE ManagedExecutorService that is bound to the JNDI name: <code>java:comp/DefaultManagedExecutorService</code>.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       batch_jobs_executor_service_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:batch_jobs_executor_service_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### cluster_constraints_enabled<a name='wls_domain_cluster_constraints_enabled'>

Specifies that deployments targeted to a cluster succeed only if all servers in the cluster are running.  By default, cluster constraints are disabled and deployment is attempted only on the servers that are reachable at the time of deployment from the Administration Server. Any servers that have been shut down or are temporarily partitioned from the Administration Server will retrieve the deployment during server startup or shortly after the network partition is resolved.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       cluster_constraints_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:cluster_constraints_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### config_backup_enabled<a name='wls_domain_config_backup_enabled'>

If true, then backups of the configuration will be made during server boot.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       config_backup_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:config_backup_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### configuration_audit_type<a name='wls_domain_configuration_audit_type'>

Returns the criteria used for auditing configuration events  (configuration changes and other operations): <ul> <li><code>CONFIG_CHANGE_NONE</code> Configuration events will neither be written to the server log or directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG</code> Configuration events will be written to the server log.</li> <li><code>CONFIG_CHANGE_AUDIT</code>Configuration events will be directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG_AND_AUDIT</code> Configuration events will be written to the server log and directed to the Security Audit Framework.</li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       configuration_audit_type => 'none'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:configuration_audit_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### configuration_version<a name='wls_domain_configuration_version'>

The release identifier for the configuration. This identifier will be used to indicate the version of the configuration. All server generated configurations will be established with the release identifier of the running server. The form of the version is major.minor.servicepack.rollingpatch. Not all parts of the version are required. i.e. "7" is acceptable.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       configuration_version => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:configuration_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### console_context_path<a name='wls_domain_console_context_path'>

The context path that you want to use in URLs that specify the Administration Console. (Requires you to enable the Administration Console for the current domain.)  To access the Administration Console, you use the following URL: http://listen-addess:listen-port/context-path. For example, if you set the context path to <code>myconsole</code>, then you use the following URL to access the Administration Console: <code>http://localhost:7001/myconsole</code>.  To specify the listen address and listen port that you use to access the Administration Console, configure the listen address and listen port of the Administration Server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       console_context_path => 'console'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:console_context_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### console_enabled<a name='wls_domain_console_enabled'>

Specifies whether the Administration Server automatically deploys the Administration Console in the current domain.  If the Administration Console is not deployed, you can still use the WebLogic Scripting Tool or the management APIs to configure and monitor the domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       console_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:console_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### console_extension_directory<a name='wls_domain_console_extension_directory'>

Returns the directory path that console extensions are loaded from.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       console_extension_directory => 'console-ext'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:console_extension_directory']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### diagnostic_context_compatibility_mode_enabled<a name='wls_domain_diagnostic_context_compatibility_mode_enabled'>

Specifies whether WLDF sends a pre-12.2.1-style diagnostic context along with the current-style diagnostic context.  If outbound communication to pre-12.2.1 servers is possible, this setting should always be enabled to ensure that those servers receive a diagnostic context that they can process. Disabling this setting in those scenarios can result in correlation information being lost across tiers, and in information reported by WLDF and DMS to become of sync in some situations.  If there is no outbound communication to pre-12.2.1 servers possible, it is suggested to disable this mode as only the current-style diagnostic context is needed to be propagated outbound (propagating the old style will not cause a failure, but is unnecessary overhead in that situation).  This setting affects outbound only, inbound pre-12.2.1 style diagnostic contexts are always understood and handled.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       diagnostic_context_compatibility_mode_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:diagnostic_context_compatibility_mode_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### disable_corrective_change<a name='wls_domain_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_domain](#attributes)

### disable_corrective_ensure<a name='wls_domain_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_domain](#attributes)

### domain<a name='wls_domain_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_domain](#attributes)

### domain_name<a name='wls_domain_domain_name'>

Domain name.



[Back to overview of wls_domain](#attributes)

### domain_version<a name='wls_domain_domain_version'>

Defines the common version of all servers in a domain. In a domain containing servers that are not all at the same release version, this attribute is used to determine the feature level that servers will assume.  The value must be less than or equal to the version of any managed server in the domain.  If this value is not equal to the version of the release version of the admin server, then the admin server will not be allowed to make modifications to the configuration.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       domain_version => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:domain_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### enable_ee_compliant_classloading_for_embedded_adapters<a name='wls_domain_enable_ee_compliant_classloading_for_embedded_adapters'>

Specifies the class loading behavior for embedded adapters. If you enable this option, embedded adapters deployed to all partitions in the domain will use Java EE compliant class loading. The embedded adapter's classes will be accessible from other modules in the same application.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       enable_ee_compliant_classloading_for_embedded_adapters => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:enable_ee_compliant_classloading_for_embedded_adapters']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### ensure<a name='wls_domain_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_domain](#attributes)

### exalogic_optimizations_enabled<a name='wls_domain_exalogic_optimizations_enabled'>

Specifies whether optimizations for Oracle Exalogic should be enabled. Optimizations include improved thread management and request processing, and reduced lock contention. This attribute should be enabled only when configuring a WebLogic domain for Oracle Exalogic.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       exalogic_optimizations_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:exalogic_optimizations_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### exalogicoptimizationsenabled<a name='wls_domain_exalogicoptimizationsenabled'>

Enable or disabled exalogic optimizations.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### guardian_enabled<a name='wls_domain_guardian_enabled'>

Specifies whether the Guardian Agent is deployed when starting servers in the current domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       guardian_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:guardian_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### internal_apps_deploy_on_demand_enabled<a name='wls_domain_internal_apps_deploy_on_demand_enabled'>

Specifies whether internal applications such as the console, uddi, wlstestclient, and uddiexplorer are deployed on demand (first access) instead of during server startup.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       internal_apps_deploy_on_demand_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:internal_apps_deploy_on_demand_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### java_service_console_enabled<a name='wls_domain_java_service_console_enabled'>

Specifies whether the Administration Server automatically deploys the Java Service Administration Console in the current domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       java_service_console_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:java_service_console_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### java_service_enabled<a name='wls_domain_java_service_enabled'>

Specifies whether features to support the use of this WebLogic Server as a Java Service in a cloud environment should be enabled.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       java_service_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:java_service_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_compatibility_mbean_server_enabled<a name='wls_domain_jmx_compatibility_mbean_server_enabled'>

Enables JMX clients to use the deprecated <code>MBeanHome</code> interface. Prior to 9.0, WebLogic Server supported a typed API layer over its JMX layer. Your JMX application classes could import type-safe interfaces for WebLogic Server MBeans, retrieve a reference to the MBeans through the <code>weblogic.management.MBeanHome</code> interface, and invoke the MBean methods directly.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_compatibility_mbean_server_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_compatibility_mbean_server_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_domain_mbean_server_enabled<a name='wls_domain_jmx_domain_mbean_server_enabled'>

Specifies whether the Administration Server initializes the Domain MBean Server, which provides federated access to all run-time MBeans and read-only configuration MBeans in the domain. Through it, JMX clients can access all MBeans in a domain through a single connection.  The Administration Console and the WebLogic Scripting Tool use this MBean server for many (but not all) of their read operations.  This MBean server exists only on the Administration Server. The Administration Server initializes it the first time a JMX client requests a connection to it. If you set this attribute to <code>false</code>, the Administration Server will not start this MBean server and JMX clients cannot connect to it.  While this MBean server is instantiated lazily (only when requested), once it is instantiated it does use some memory and network traffic. Disabling this MBean server can conserve a minimal amount of resources, but the trade off is that JMX clients must maintain separate connections for each WebLogic Server's Runtime MBean Server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_domain_mbean_server_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_domain_mbean_server_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_edit_mbean_server_enabled<a name='wls_domain_jmx_edit_mbean_server_enabled'>

Specifies whether the Administration Server initializes the Edit MBean Server, which contains the hierarchy of MBeans used to make modifications to the domain's configuration. All JMX clients, including utilities such as the Administration Console and the WebLogic Scripting Tool, use the Edit MBean Server to modify a domain's configuration.  This MBean server exists only on the Administration Server. By default, when the Administration Server starts, it starts the Edit MBean Server. If you set the <code>EditMBeanServerEnabled</code> attribute to <code>false</code>, the Administration Server will not start this MBean server. If you disable this MBean server, JMX clients cannot modify the domain's configuration. You can, however, modify the domain configuration through the offline editing feature of WebLogic Scripting Tool.  <dl> <dt>Note:</dt>  <dd> Disabling the Edit MBean Server is not sufficient to prevent changes to a domain configuration. Because the WebLogic Server deployment service does not use JMX, the Administration Console and WLST can deploy or undeploy applications even if you have disabled the Edit MBean Server. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_edit_mbean_server_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_edit_mbean_server_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_invocation_timeout_seconds<a name='wls_domain_jmx_invocation_timeout_seconds'>

The number of seconds that internal WebLogic Server processes wait to connect to an MBean server, invoke an MBean server method, and return the results of the invocation. If the MBean server method does not complete (return) within the timeout period, WebLogic Server abandons its invocation attempt. Some internal management processes within WebLogic Server require a server instance to connect to MBean servers in other WebLogic Server instances and invoke an MBean server method. The timeout period prevents the internal process from locking up if an MBean server cannot successfully return a method invocation. A value of <code>0</code> (zero) prevents the method invocation from timing out. With such a value, the internal process will wait indefinitely until the MBean server's method returns.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_invocation_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_invocation_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jmx_managed_server_notifications_enabled<a name='wls_domain_jmx_managed_server_notifications_enabled'>

Specifies whether the WebLogic Server Domain Runtime MBean Server will support notifications from the federated Runtime MBean Servers on the managed and administration servers. Supporting notifications requires a significant amount of memory resources. A list of ObjectNames is maintained for each MBean from the Runtime MBean Servers. If notifications are not required for this domain, then disabling them will save on CPU and memory resources. This is particularly critical if there are large numbers of runtime MBeans and/or large numbers of servers.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_managed_server_notifications_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_managed_server_notifications_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_management_ejb_enabled<a name='wls_domain_jmx_management_ejb_enabled'>

Enables access to the Management EJB (MEJB), which is part of the J2EE Management APIs (JSR-77).  The Management API specification provides a standardized management data model for common resources on J2EE Web application servers.  The MEJB provides access to J2EE Managed Objects (JMOs), which describe the common J2EE resources. If you set this attribute to <code>false</code>, WebLogic Server does not register the MEJB in the JNDI tree, and effectively disables the J2EE Management APIs for the domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_management_ejb_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_management_ejb_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_notes<a name='wls_domain_jmx_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jmx_platform_mbean_server_enabled<a name='wls_domain_jmx_platform_mbean_server_enabled'>

Platform MBean server enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_platform_mbean_server_used<a name='wls_domain_jmx_platform_mbean_server_used'>

Platform MBean server used.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_runtime_mbean_server_enabled<a name='wls_domain_jmx_runtime_mbean_server_enabled'>

Specifies whether each server instance in the domain initializes its Runtime MBean Server, which provides access to a server's run-time MBeans and read-only configuration MBeans.  The Administration Console and the WebLogic Scripting Tool use this MBean server for some (but not all) of their read operations.  If <code>RuntimeMBeanServerEnabled</code> is <code>true</code>, each server starts its Runtime MBean Server during the server's startup cycle. If this attribute is <code>false</code>, no server instance in the domain will start its Runtime MBean Server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_runtime_mbean_server_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_runtime_mbean_server_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jmx_tags<a name='wls_domain_jmx_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jmx_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jmx_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jpa_default_jpa_provider<a name='wls_domain_jpa_default_jpa_provider'>

The configured default JPA provider for the domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jpa_default_jpa_provider => 'org.eclipse.persistence.jpa.PersistenceProvider'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jpa_default_jpa_provider']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jpa_default_provider<a name='wls_domain_jpa_default_provider'>

The JPA default provider java class.



[Back to overview of wls_domain](#attributes)

### jpa_notes<a name='wls_domain_jpa_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jpa_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jpa_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jpa_tags<a name='wls_domain_jpa_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jpa_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jpa_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_abandon_timeout_seconds<a name='wls_domain_jta_abandon_timeout_seconds'>

Specifies the maximum amount of time, in seconds, a transaction manager persists in attempting to complete the second phase of a two-phase commit transaction.   During the second phase of a two-phase commit transaction, the transaction manager continues to try to complete the transaction until all resource managers indicate that the transaction is completed. After the abandon transaction timer expires, no further attempt is made to resolve the transaction. If the transaction is in a prepared state before being abandoned, the transaction manager rolls back the transaction to release any locks held on behalf of the abandoned transaction.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_abandon_timeout_seconds => '86400'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_abandon_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_before_completion_iteration_limit<a name='wls_domain_jta_before_completion_iteration_limit'>

The maximum number of cycles that the transaction manager performs the <tt>beforeCompletion</tt> synchronization callback for this WebLogic Server domain.  Nothing prevents a Synchronization object from registering another during <code>beforeCompletion</code>, even those whose <code>beforeCompletions</code> have already been called. For example, an EJB can call another in its <code>ejbStore()</code> method. To accommodate this, the transaction manager calls all Synchronization objects, then repeats the cycle if new ones have been registered. This count sets a limit to the number of cycles that synchronization occurs.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_before_completion_iteration_limit => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_before_completion_iteration_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_checkpoint_interval_seconds<a name='wls_domain_jta_checkpoint_interval_seconds'>

The interval at which the transaction manager creates a new transaction log file and checks all old transaction log files to see if they are ready to be deleted.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_checkpoint_interval_seconds => '300'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_checkpoint_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_clusterwide_recovery_enabled<a name='wls_domain_jta_clusterwide_recovery_enabled'>

Indicates that cluster-wide recovery is used for distributed transactions.  When enabled, recovery operations for a distributed transaction are applied to all the servers of the cluster hosting a InterposedTransactionManager rather than just the server hosting the InterposedTransactionManager.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_clusterwide_recovery_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_clusterwide_recovery_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_completion_timeout_seconds<a name='wls_domain_jta_completion_timeout_seconds'>

Specifies the maximum amount of time, in seconds, a transaction manager waits for all resource managers to respond and indicate if the transaction can be committed or rolled back.  <ul><li> The default value is 0, which sets the value to approximately twice the default <code>transaction-timeout</code> value with a maximum value of 120 seconds. This value provides backward compatibility for prior releases without this setting.</li> <li>If the specified value is -1, the maximum value supported by this attribute is used. </li> <li>If the specified value exceeds the value set for <code>abandon-timeout-seconds</code>, the value of <code>abandon-timeout-seconds</code> is used. </li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_completion_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_completion_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_cross_domain_recovery_retry_interval<a name='wls_domain_jta_cross_domain_recovery_retry_interval'>

The interval at which a store lock for a given server in a recovery domain will be checked for takeover eligibility.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_cross_domain_recovery_retry_interval => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_cross_domain_recovery_retry_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_determiner_candidate_resource_info_list<a name='wls_domain_jta_determiner_candidate_resource_info_list'>

Returns a list of one or more transaction resources (determiners). A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_determiner_candidate_resource_info_list => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_determiner_candidate_resource_info_list']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_determiners<a name='wls_domain_jta_determiners'>

Specifies a list of one or more transaction resources (determiners) separated by line breaks. A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_determiners => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_determiners']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_forget_heuristics<a name='wls_domain_jta_forget_heuristics'>

Specifies whether the transaction manager automatically performs an XA Resource <code>forget</code> operation for heuristic transaction completions.  When enabled, the transaction manager automatically performs an XA Resource <code>forget()</code> operation for all resources as soon as the transaction learns of a heuristic outcome. Disable this feature only if you know what to do with the resource when it reports a heuristic decision.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_forget_heuristics => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_forget_heuristics']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_max_resource_requests_on_server<a name='wls_domain_jta_max_resource_requests_on_server'>

Maximum number of concurrent requests to resources allowed for each server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_max_resource_requests_on_server => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_max_resource_requests_on_server']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_max_resource_unavailable_millis<a name='wls_domain_jta_max_resource_unavailable_millis'>

Maximum duration time, in milliseconds, that a resource is declared dead. After the duration, the resource is declared available again, even if the resource provider does not explicitly re-register the resource.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_max_resource_unavailable_millis => '1800000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_max_resource_unavailable_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_max_retry_seconds_before_determiner_fail<a name='wls_domain_jta_max_retry_seconds_before_determiner_fail'>

The maximum amount of time, in seconds, WebLogic Server waits for the determiner to recover from a failure. If the determiner does not recover after this period, WebLogic Server sets the TLog health state to HEALTH_FAILED.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_max_retry_seconds_before_determiner_fail => '300'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_max_retry_seconds_before_determiner_fail']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_max_transactions<a name='wls_domain_jta_max_transactions'>

The JTA transaction max transactions value.



[Back to overview of wls_domain](#attributes)

### jta_max_unique_name_statistics<a name='wls_domain_jta_max_unique_name_statistics'>

The maximum number of unique transaction names for which statistics are maintained.  The first 1001 unique transaction names are maintained as their own transaction name and stored in each statistic. After the 1001st transaction name is reached, the transaction name is stored as <code>weblogic.transaction.statistics.namedOverflow</code>, and the transaction statistic is also merged and maintained in <code>weblogic.transaction.statistics.namedOverflow</code>.  A transaction name typically represents a category of business transactions, such as "funds-transfer."

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_max_unique_name_statistics => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_max_unique_name_statistics']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_max_xa_call_millis<a name='wls_domain_jta_max_xa_call_millis'>

Maximum allowed time duration, in milliseconds,  for XA calls to resources. If a particular XA call to a resource exceeds the limit, the resource is declared unavailable.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_max_xa_call_millis => '120000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_max_xa_call_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_notes<a name='wls_domain_jta_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_parallel_xa_enabled<a name='wls_domain_jta_parallel_xa_enabled'>

Indicates that XA calls are executed in parallel if there are available threads.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_parallel_xa_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_parallel_xa_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_recovery_site_name<a name='wls_domain_jta_recovery_site_name'>

The name of the site whose transactions this site/domain will recover in the event that intra-cluster transaction service migration is not successful or efficient.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_recovery_site_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_recovery_site_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_security_interop_mode<a name='wls_domain_jta_security_interop_mode'>

Specifies the security mode of the communication channel used for XA calls between servers that participate in a global transaction. All server instances in a domain must have the same security mode setting.  Security Interoperability Mode options: <ul> <li>default  The transaction coordinator makes calls using the kernel identity over an admin channel if it is enabled, and <code>anonymous</code> otherwise. Man-in-the-middle attacks are possible if the admin channel is not enabled.</li>  <li>performance  The transaction coordinator makes calls using <code>anonymous</code> at all times. This implies a security risk since a malicious third party could then try to affect the outcome of transactions using a man-in-the-middle attack.</li>  <li>compatibility  The transaction coordinator makes calls as the kernel identity over an insecure channel. This is a high security risk because a successful man-in-the-middle attack would allow the attacker to gain administrative control over both domains. This setting should only be used when strong network security is in place. </li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_security_interop_mode => 'default'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_security_interop_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_serialize_enlistments_gc_interval_millis<a name='wls_domain_jta_serialize_enlistments_gc_interval_millis'>

The time interval, in milliseconds, at which internal objects used to serialize resource enlistment are cleaned up.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_serialize_enlistments_gc_interval_millis => '30000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_serialize_enlistments_gc_interval_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_shutdown_grace_period<a name='wls_domain_jta_shutdown_grace_period'>

Indicates how long the server should wait for active transactions to complete before allowing shutdown.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_shutdown_grace_period => '180'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_shutdown_grace_period']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_tags<a name='wls_domain_jta_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_tightly_coupled_transactions_enabled<a name='wls_domain_jta_tightly_coupled_transactions_enabled'>

Indicates tight coupling of transaction branches that span different transaction manager systems.  When enabled, WebLogic uses the transaction identifier of a transaction imported by the InterposedTransactionManager for XA calls rather than an internally mapped Xid. This applies to inter-domain WebLogic transactions and transactions imported from Tuxedo. This allows for tight coupling of transaction branches for transactions that span across different transaction manager systems.  If a transaction between WebLogic and Tuxedo resources uses a GridLink Data Source with GridLink Affinity enabled, the XA Affinity context is automatically used for the transaction.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_tightly_coupled_transactions_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_tightly_coupled_transactions_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_timeout_seconds<a name='wls_domain_jta_timeout_seconds'>

Specifies the maximum amount of time, in seconds, an active transaction is allowed to be in the first phase of a two-phase commit transaction. If the specified amount of time expires, the transaction is automatically rolled back.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_timeout_seconds => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_tlog_write_when_determiner_exists_enabled<a name='wls_domain_jta_tlog_write_when_determiner_exists_enabled'>

Indicates two-phase transaction recovery logs are written even if one or more determiners are configured.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_tlog_write_when_determiner_exists_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_tlog_write_when_determiner_exists_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_transaction_timeout<a name='wls_domain_jta_transaction_timeout'>

The JTA transaction timeout value.



[Back to overview of wls_domain](#attributes)

### jta_two_phase_enabled<a name='wls_domain_jta_two_phase_enabled'>

Indicates that the two-phase commit protocol is used to coordinate transactions across two or more resource managers.  If not selected: <ul> <li> Two-phase commit is disabled and any attempt to use two-phase commit results in a RollbackException being thrown.</li> <li> All transaction logging is disabled, including checkpoint records.</li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_two_phase_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_two_phase_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_unregister_resource_grace_period<a name='wls_domain_jta_unregister_resource_grace_period'>

The amount of time, in seconds, a  transaction manager waits for transactions involving the resource to complete before unregistering a resource. This grace period helps minimize the risk of abandoned transactions because of an unregistered resource, such as a JDBC data source module packaged with an application.  During the specified grace period, the <code>unregisterResource</code> call blocks until the call returns and no new transactions are started for the associated resource. If the number of outstanding transactions for the resource goes to <code>0</code>, the <code>unregisterResource</code> call returns immediately.  At the end of the grace period, if outstanding transactions are associated with the resource, the <code>unregisterResource</code> call returns and a log message is written to the server on which the resource was previously registered.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_unregister_resource_grace_period => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_unregister_resource_grace_period']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### jta_wsat_issued_token_enabled<a name='wls_domain_jta_wsat_issued_token_enabled'>

Specifies whether to use <code>issuedtoken</code> to enable authentication between the WS-AT coordinator and participant.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_wsat_issued_token_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_wsat_issued_token_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### jta_wsat_transport_security_mode<a name='wls_domain_jta_wsat_transport_security_mode'>

 Specifies transport security mode required by WebService Transaction endpoints. Transport Security options: <ul> <li>SSLNotRequired All WebService Transaction protocol messages are exchanged over the HTTP channel.</li>  <li>SSLRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS.</li>  <li>ClientCertRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS, and WLS enforces the presence of client certificate </li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       jta_wsat_transport_security_mode => 'SSLNotRequired'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:jta_wsat_transport_security_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_buffer_size_kb<a name='wls_domain_log_buffer_size_kb'>

Gets the underlying log buffer size in kilobytes

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_buffer_size_kb => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_buffer_size_kb']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_date_format_pattern<a name='wls_domain_log_date_format_pattern'>

The date format pattern used for rendering dates in the  log. The DateFormatPattern string conforms to the specification of the <code>java.text.SimpleDateFormat</code> class.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_date_format_pattern => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_date_format_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_date_pattern<a name='wls_domain_log_date_pattern'>

The date format pattern used for rendering dates in the log.
The DateFormatPattern string conforms to the specification of the java.text.SimpleDateFormat class.



[Back to overview of wls_domain](#attributes)

### log_domain_log_broadcast_filter<a name='wls_domain_log_domain_log_broadcast_filter'>

The filter configuration for log events being sent to the domain log.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_domain_log_broadcast_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_domain_log_broadcast_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_domain_log_broadcast_severity<a name='wls_domain_log_domain_log_broadcast_severity'>

The minimum severity of log messages going to the domain log from this server's log broadcaster. Messages with a lower severity than the specified value will not be published to the domain log.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_domain_log_broadcast_severity => 'Notice'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_domain_log_broadcast_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_domain_log_broadcaster_buffer_size<a name='wls_domain_log_domain_log_broadcaster_buffer_size'>

Broadcasts log messages to the domain log in batch mode.  The size of the buffer for log messages that are sent to the domain log. The buffer is maintained on the Managed Server and is broadcasted to the domain log when it is full.  If you notice performance issues due to a high rate of log messages being generated, set this value higher. This will cause the buffer to be broadcasted less frequently from the Managed Server to the domain log. In production environments, it is not recommended to set the buffer size lower than the production default of 10.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_domain_log_broadcaster_buffer_size => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_domain_log_broadcaster_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_count<a name='wls_domain_log_file_count'>

The maximum number of log files that the server creates when it rotates the log. This number does not include the file that the server uses to store current messages. (Requires that you enable Number of Files Limited.)

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_count => '7'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_filter<a name='wls_domain_log_file_filter'>

The filter configuration for the server log file.  A filter configuration defines simple filtering rules to limit the volume of log messages written to the log file.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_min_size<a name='wls_domain_log_file_min_size'>

The log file min size of a domain or server.



[Back to overview of wls_domain](#attributes)

### log_file_name<a name='wls_domain_log_file_name'>

The name of the file that stores current log messages. Usually it is a computed value based on the name of the parent of this MBean. For example, for a server log, it is <code>SERVER_NAME.log</code>.  However, if the name of the parent cannot be obtained, the file name is <code>weblogic.log</code>. If you specify a relative pathname, it is interpreted as relative to the server's root directory.  To include a time and date stamp in the file name when the log file is rotated, add <code>java.text.SimpleDateFormat</code> variables to the file name. Surround each variable with percentage (<code>%</code>) characters.  For example, if the file name is defined to be <code>myserver_%yyyy%_%MM%_%dd%_%hh%_%mm%.log</code>, the log file will be named <code>myserver_yyyy_mm_dd_hh_mm.log</code>.  When the log file is rotated, the rotated file name contains the date stamp. For example, if the log file is rotated for the first time on 2 April, 2003 at 10:05 AM, the log file that contains the old messages will be named <code>myserver_2003_04_02_10_05.log00001</code>.  If you do not include a time and date stamp, the rotated log files are numbered in order of creation. For example, <code>myserver.log00007</code>.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_rotation_dir<a name='wls_domain_log_file_rotation_dir'>

The directory where the rotated log files will be stored. By default the rotated files are stored in the same directory where the log file is stored.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_rotation_dir => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_rotation_dir']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_severity<a name='wls_domain_log_file_severity'>

The minimum severity of log messages going to the server log file. By default all messages go to the log file.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_severity => 'Trace'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_file_time_span<a name='wls_domain_log_file_time_span'>

The interval (in hours) at which the server saves old log messages to another file. (Requires that you specify a file rotation type of <code>TIME</code>.)

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_file_time_span => '24'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_file_time_span']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_filecount<a name='wls_domain_log_filecount'>

The log file count of a domain or server.



[Back to overview of wls_domain](#attributes)

### log_filename<a name='wls_domain_log_filename'>

The domain log filename.



[Back to overview of wls_domain](#attributes)

### log_format_compatibility_enabled<a name='wls_domain_log_format_compatibility_enabled'>

Configures whether log messages will be logged in legacy format without supplemental attributes.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_format_compatibility_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_format_compatibility_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_log4j_logging_enabled<a name='wls_domain_log_log4j_logging_enabled'>

Specifies whether the server logging is based on a Log4j implementation. By default, WebLogic logging uses an implementation based on the Java Logging APIs which are part of the JDK.  Applications that use the WebLogic Message Catalog framework or the NonCatalogLogger will not be affected by the underlying Logging implementation.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_log4j_logging_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_log4j_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_logger_severity<a name='wls_domain_log_logger_severity'>

The minimum severity of log messages going to all log destinations. By default all messages are published.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_logger_severity => 'Info'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_logger_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_logger_severity_properties<a name='wls_domain_log_logger_severity_properties'>

The configuration of the different logger severities keyed by name. The values are one of the predefined Severity strings namely Emergency, Alert, Critical, Error, Warning, Notice, Info, Debug, Trace.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_logger_severity_properties => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_logger_severity_properties']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_memory_buffer_filter<a name='wls_domain_log_memory_buffer_filter'>

The filter configuration for messages that are stored in the log memory buffer. By default, all log messages are cached.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_memory_buffer_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_memory_buffer_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_memory_buffer_severity<a name='wls_domain_log_memory_buffer_severity'>

The minimum severity of log messages going to the memory buffer of recent log events. Messages with a lower severity than the specified value will not be cached in the buffer.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_memory_buffer_severity => 'Trace'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_memory_buffer_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_memory_buffer_size<a name='wls_domain_log_memory_buffer_size'>

The size of the memory buffer that holds the last n log records. This is used to support viewing the most recent log record entries (tail viewing) from the WebLogic Administration Console.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_memory_buffer_size => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_memory_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_monitoring_enabled<a name='wls_domain_log_monitoring_enabled'>

Enable or disable log monitoring.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_monitoring_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_monitoring_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_monitoring_interval_secs<a name='wls_domain_log_monitoring_interval_secs'>

Timer interval in seconds to check the counts of messages logged during the interval.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_monitoring_interval_secs => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_monitoring_interval_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_monitoring_throttle_message_length<a name='wls_domain_log_monitoring_throttle_message_length'>

Cut-off length of the log message for evaluation during throttle period. The log message length is truncated to this length for evaluation of repeated logging events.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_monitoring_throttle_message_length => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_monitoring_throttle_message_length']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_monitoring_throttle_threshold<a name='wls_domain_log_monitoring_throttle_threshold'>

The threshold number of messages logged during the evaluation period which enables or disables the throttling.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_monitoring_throttle_threshold => '1500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_monitoring_throttle_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_notes<a name='wls_domain_log_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_number_of_files_limited<a name='wls_domain_log_number_of_files_limited'>

Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of SIZE or TIME.)

After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.

If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_platform_logger_levels<a name='wls_domain_log_platform_logger_levels'>

Specifies the platform logger and the associated level names set through the WebLogic Server configuration.  Note the following behavior: <ul> <li>The configuration is applicable for <code>java.util.logging.Logger</code> instances in the JDK's default global LogManager.</li> <li>WebLogic Server loggers are configured in terms of <code>weblogic.logging.Severities</code> through the <code>LoggerSeverities</code> attribute. These loggers are not available in the JDK's default global LogManager.</li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_platform_logger_levels => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_platform_logger_levels']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_redirect_stderr_to_server_log_enabled<a name='wls_domain_log_redirect_stderr_to_server_log_enabled'>

Specifies whether the stderr of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic Logging system. When this attribute is enabled, the stderr content is published to all the registered log destinations, such as the server terminal console and log file.  Note that JVM messages are redirected asynchronously. In the event of an overload situation, these messages may be dropped. As a best practice, Oracle recommends using one of the supported logging APIs instead.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_redirect_stderr_to_server_log_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_redirect_stderr_to_server_log_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_redirect_stdout_to_server_log_enabled<a name='wls_domain_log_redirect_stdout_to_server_log_enabled'>

Specifies whether the stdout of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic logging system. When this attribute is enabled, the stdout content is published to all the registered log destinations, such as the server terminal console and log file.  Note that JVM messages are redirected asynchronously. In the event of an overload situation, these messages may be dropped. As a best practice, Oracle recommends using one of the supported logging APIs instead.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_redirect_stdout_to_server_log_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_redirect_stdout_to_server_log_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_rotate_log_on_startup<a name='wls_domain_log_rotate_log_on_startup'>

Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_rotate_log_on_startup => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_rotate_log_on_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_rotate_logon_startup<a name='wls_domain_log_rotate_logon_startup'>

log rotate Logon at startup of a domain or server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_rotation_time<a name='wls_domain_log_rotation_time'>

Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_rotation_time => '00:00'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_rotation_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_rotation_type<a name='wls_domain_log_rotation_type'>

Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_rotation_type => 'bySize'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_rotation_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_rotationtype<a name='wls_domain_log_rotationtype'>

log rotation type of a domain or server.

Valid values are `absent`, `bySize`, `byTime`, `none`. 

[Back to overview of wls_domain](#attributes)

### log_server_logging_bridge_use_parent_loggers_enabled<a name='wls_domain_log_server_logging_bridge_use_parent_loggers_enabled'>

Specifies whether application log messages are propagated to the parent node in the Logger tree or to the WebLogic Server log by means of the Logging Bridge. By default, this attribute is disabled, which results in application log messages being propagated to the WebLogic Server log.  Note the following behavior: <ul> <li>If WebLogic Server is configured to be based upon the the Java Logging API (the default), the Logging Bridge is made available as a <code>java.util.logging.Handler</code> object.</li> <li>If  WebLogic Server is configured to be based upon a Log4j implementation, the Logging Bridge is made available as a <code>org.apache.log4j.Appender</code> object.</li> <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is disabled, applications that use either the Java Logging API or Log4j have their log messages redirected by the Logging Bridge to the WebLogic Server log. <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is enabled, applications that use the Java Logging API have their log messages propagated to the parent node in the global Java Logging Logger tree.</li> <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is enabled, applications that use Log4j have their log messages propagated to the parent node in the Log4j Logger tree.</li> </ul>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_server_logging_bridge_use_parent_loggers_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_server_logging_bridge_use_parent_loggers_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_stdout_filter<a name='wls_domain_log_stdout_filter'>

The filter configuration for log events being sent to the standard out.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_stdout_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_stdout_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_stdout_format<a name='wls_domain_log_stdout_format'>

The output format to use when logging to the console.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_stdout_format => 'standard'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_stdout_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_stdout_log_stack<a name='wls_domain_log_stdout_log_stack'>

Specifies whether to dump stack traces to the console when included in logged message.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_stdout_log_stack => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_stdout_log_stack']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### log_stdout_severity<a name='wls_domain_log_stdout_severity'>

The minimum severity of log messages going to the standard out. Messages with a lower severity than the specified value will not be published to standard out.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_stdout_severity => 'Notice'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_stdout_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### log_tags<a name='wls_domain_log_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       log_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:log_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### max_concurrent_long_running_requests<a name='wls_domain_max_concurrent_long_running_requests'>

The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the global/domain partition on the current server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       max_concurrent_long_running_requests => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:max_concurrent_long_running_requests']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### max_concurrent_new_threads<a name='wls_domain_max_concurrent_new_threads'>

The maximum number of running threads that can be created by all the Managed Thread Factories in the global/domain partition on the current server.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       max_concurrent_new_threads => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:max_concurrent_new_threads']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### name<a name='wls_domain_name'>

The name.



[Back to overview of wls_domain](#attributes)

### notes<a name='wls_domain_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### parallel_deploy_application_modules<a name='wls_domain_parallel_deploy_application_modules'>

Determines if the modules of applications will be deployed in parallel.  This setting can be overridden at the per-partition or per-application levels. See {@link AppDeploymentMBean#isParallelDeployModules()}

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       parallel_deploy_application_modules => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:parallel_deploy_application_modules']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### parallel_deploy_applications<a name='wls_domain_parallel_deploy_applications'>

Determines if applications will be deployed in parallel.  This setting can be overridden at the per-partition level.  See {@link PartitionMBean#isParallelDeployApplications()}

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       parallel_deploy_applications => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:parallel_deploy_applications']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### production_mode_enabled<a name='wls_domain_production_mode_enabled'>

Specifies whether all servers in this domain run in production mode. You can configure servers in your domain to start in one of two modes, development or production. You use development mode while you are developing your applications. Development mode uses a relaxed security configuration and enables you to auto-deploy applications. You use production mode when your application is running in its final form. A production domain uses full security and may use clusters or other advanced features.  The runtime mode is a domain-wide setting. As each Managed Server starts, it refers to the mode of the Administration Server to determine its runtime mode. If you configure the domain to run in production mode, the Administration Server saves this setting to the domain's configuration document.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       production_mode_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:production_mode_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### provider<a name='wls_domain_provider'>

The specific backend to use for this `wls_domain`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage all the WebLogic domain options via regular WLST



[Back to overview of wls_domain](#attributes)

### root_directory<a name='wls_domain_root_directory'>

Return the root directory for the domain. In other words for a server process [ServerMBean.getRootDirectory] or [ServerMBean.getDomainDirectory]

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       root_directory => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:root_directory']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_administrative_identity_domain<a name='wls_domain_security_administrative_identity_domain'>

Domain's administrative identity domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_administrative_identity_domain => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_administrative_identity_domain']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_anonymous_admin_lookup_enabled<a name='wls_domain_security_anonymous_admin_lookup_enabled'>

Returns true if anonymous JNDI access for Admin MBean home is permitted. This is overridden by the Java property <code>-Dweblogic.management.anonymousAdminLookupEnabled</code>.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_anonymous_admin_lookup_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_anonymous_admin_lookup_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_clear_text_credential_access_enabled<a name='wls_domain_security_clear_text_credential_access_enabled'>

Returns true if allow access to credential in clear text. This can be overridden by the system property <code>-Dweblogic.management.clearTextCredentialAccessEnabled</code>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_clear_text_credential_access_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_clear_text_credential_access_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_compatibility_connection_filters_enabled<a name='wls_domain_security_compatibility_connection_filters_enabled'>

Specifies whether this WebLogic Server domain enables compatiblity with previous connection filters.  This attribute changes the protocols names used when filtering needs to be performed.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_compatibility_connection_filters_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_compatibility_connection_filters_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_connection_filter<a name='wls_domain_security_connection_filter'>

The name of the Java class that implements a connection filter (that is, the <tt>weblogic.security.net.ConnectionFilter</tt> interface). If no class name is specified, no connection filter will be used.   This attribute replaces the deprecated ConnectionFilter attribute on the SecurityMBean.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_connection_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_connection_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_connection_filter_rules<a name='wls_domain_security_connection_filter_rules'>

The rules used by any connection filter that implements the <tt>ConnectionFilterRulesListener</tt> interface. When using the default implementation and when no rules are specified, all connections are accepted. The default implementation rules are in the format: <tt>target localAddress localPort action protocols</tt>.   This attribute replaces the deprecated ConnectionFilterRules attribute on the SecurityMBean.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_connection_filter_rules => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_connection_filter_rules']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_connection_logger_enabled<a name='wls_domain_security_connection_logger_enabled'>

Specifies whether this WebLogic Server domain should log accepted connections.  This attribute can be used by a system administrator to dynamically check the incoming connections in the log file to determine if filtering needs to be performed.   This attribute replaces the deprecated ConnectionLoggerEnabled attribute on the SecurityMBean.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_connection_logger_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_connection_logger_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_console_full_delegation_enabled<a name='wls_domain_security_console_full_delegation_enabled'>

Indicates whether the console is enabled for fully delegate authorization.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_console_full_delegation_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_console_full_delegation_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_credential<a name='wls_domain_security_credential'>

The password for the domain. In WebLogic Server version 6.0, this attribute was the password of the system user. In WebLogic Server version 7.0, this attribute can be any string. For the two domains to interoperate, the string must be the same for both domains.  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>UserPasswordEncrypted</code> attribute to the encrypted value.</li> </ol>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_credential => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_credential']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_cross_domain_security_enabled<a name='wls_domain_security_cross_domain_security_enabled'>

 Indicates whether or not cross-domain security is enabled

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_cross_domain_security_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_cross_domain_security_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_crossdomain<a name='wls_domain_security_crossdomain'>

The cross domain enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_downgrade_untrusted_principals<a name='wls_domain_security_downgrade_untrusted_principals'>

Whether or not to downgrade to anonymous principals that cannot be verified. This is useful for server-server communication between untrusted domains.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_downgrade_untrusted_principals => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_downgrade_untrusted_principals']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_enforce_strict_url_pattern<a name='wls_domain_security_enforce_strict_url_pattern'>

Whether or not the system should enforce strict URL pattern or not.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_enforce_strict_url_pattern => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_enforce_strict_url_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_enforce_valid_basic_auth_credentials<a name='wls_domain_security_enforce_valid_basic_auth_credentials'>

Whether or not the system should allow requests with invalid Basic Authentication credentials to access unsecure resources.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_enforce_valid_basic_auth_credentials => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_enforce_valid_basic_auth_credentials']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_excluded_domain_names<a name='wls_domain_security_excluded_domain_names'>

 Specifies a list of remote domains for which cross-domain check should not be applied.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_excluded_domain_names => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_excluded_domain_names']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_identity_domain_aware_providers_required<a name='wls_domain_security_identity_domain_aware_providers_required'>

Returns true if all role mapping, authorization, credential mapping, and audit providers configured in the domain must support the IdentityDomainAwareProviderMBean interface's administrative identity domain.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_identity_domain_aware_providers_required => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_identity_domain_aware_providers_required']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_node_manager_password<a name='wls_domain_security_node_manager_password'>

The password that the Administration Server uses to communicate with Node Manager when starting, stopping, or restarting Managed Servers.   When you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>NodeManagerPasswordEncrypted</code> attribute. <li>Decrypts the value and returns the unencrypted password as a String. </ol>  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>NodeManagerPasswordEncrypted</code> attribute to the encrypted value.</li> </ol> Using this attribute (<code>NodeManagerPassword</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, you should use <code>NodeManagerPasswordEncrypted</code>.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_node_manager_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_node_manager_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_node_manager_username<a name='wls_domain_security_node_manager_username'>

The user name that the Administration Server uses to communicate with Node Manager when starting, stopping, or restarting Managed Servers.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_node_manager_username => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_node_manager_username']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_nonce_timeout_seconds<a name='wls_domain_security_nonce_timeout_seconds'>

Returns the value of the nonce timeout in seconds.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_nonce_timeout_seconds => '120'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_nonce_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_notes<a name='wls_domain_security_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_principal_equals_case_insensitive<a name='wls_domain_security_principal_equals_case_insensitive'>

Specifies whether the WebLogic Server principal name is compared using a case insensitive match when the equals method for the principal object is performed.  If this attribute is enabled, matches are case insensitive.  Note: Note that principal comparison is not used by the WebLogic Security Service to determine access to protected resources. This attribute is intended for use with JAAS authorization, which may require case insensitive principal matching behavior.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_principal_equals_case_insensitive => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_principal_equals_case_insensitive']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_principal_equals_compare_dn_and_guid<a name='wls_domain_security_principal_equals_compare_dn_and_guid'>

Specifies whether the GUID and DN data in a WebLogic Server principal object are used when the equals method of that object is invoked.   If enabled, the GUID and DN data (if included among the attributes in a WebLogic Server principal object) and the principal name are compared when this method is invoked.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_principal_equals_compare_dn_and_guid => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_principal_equals_compare_dn_and_guid']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_tags<a name='wls_domain_security_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### security_use_kss_for_demo<a name='wls_domain_security_use_kss_for_demo'>

Determines whether the Demo Identity and Demo Trust key stores should be obtained from the Oracle Key Store Service (KSS).  If enabled, Weblogic Server will request the Demo Identity and Domain Trust key stores from KSS. Subsequent to installation however, the KSS Demo key stores may have been manipulated such that appropriate Demo certificates or keys are not available.  Please verify the following KSS Demo Identity keystore has an X.509 private key and corresponding public identity certificate signed by the Demo Certificate Authority (CA): <dl> <dt>KSS Stripe <dd>system <dt>KSS Key Store <dd>demoidentity <dt>KSS Private Key Alias <dd>DemoIdentity </dl>  Please verify the following KSS Domain Trust keystore has a trusted Demo Certificate Authority X.509 certificate: <dl> <dt>KSS Stripe <dd>system <dt>KSS Key Store <dd>trust </dl>

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_use_kss_for_demo => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_use_kss_for_demo']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### security_web_app_files_case_insensitive<a name='wls_domain_security_web_app_files_case_insensitive'>

This property defines the case sensitive URL-pattern matching behavior for security constraints, servlets, filters, virtual-hosts, and so on, in the Web application container and external security policies.  Note: This is a Windows-only flag that is provided for backward compatibility when upgrading from pre-9.0 versions of WebLogic Server. On Unix platforms, setting this value to <code>true</code> causes undesired behavior and is not supported.  When the value is set to <code>os</code>, the pattern matching will be case- sensitive on all platforms except the Windows file system.  Note that on non-Windows file systems, WebLogic Server does not enforce case sensitivity and relies on the file system for optimization. As a result, if you have a Windows Samba mount from Unix or Mac OS that has been installed in case-insensitive mode, there is a chance of a security risk. If so, specify case-insensitive lookups by setting this attribute to <code>true</code>.  Note also that this property is used to preserve backward compatibility on Windows file systems only. In prior releases, WebLogic Server was case- insensitive on Windows. As of WebLogic Server 9.0, URL-pattern matching is strictly enforced.  During the upgrade of older domains, the value of this parameter is explicitly set to <code>os</code> by the upgrade plug-in to preserve backward compatibility.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       security_web_app_files_case_insensitive => 'false'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:security_web_app_files_case_insensitive']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### server_migration_history_size<a name='wls_domain_server_migration_history_size'>

Gets the history size of server migrations.  A value of -1 indicates that the history size is unlimited.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       server_migration_history_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:server_migration_history_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### service_migration_history_size<a name='wls_domain_service_migration_history_size'>

Gets the history size of service migrations.  A value of -1 indicates that the history size is unlimited.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       service_migration_history_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:service_migration_history_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### setarchiveconfigurationcount<a name='wls_domain_setarchiveconfigurationcount'>

The amount of archived backups of the domain configuration file retained.



[Back to overview of wls_domain](#attributes)

### setconfigbackupenabled<a name='wls_domain_setconfigbackupenabled'>

Enable or disable configuration backup for the domain.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### setconfigurationaudittype<a name='wls_domain_setconfigurationaudittype'>

The configuration audit type.

Valid values are `absent`, `none`, `log`, `audit`, `logaudit`. 

[Back to overview of wls_domain](#attributes)

### setinternalappdeploymentondemandenable<a name='wls_domain_setinternalappdeploymentondemandenable'>

Enable or disabled internal app deployment.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)

### site_name<a name='wls_domain_site_name'>

The name of the site this domain is associated with.

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       site_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:site_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### tags<a name='wls_domain_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain {a_wls_domain :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_domain](#attributes)

### timeout<a name='wls_domain_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_domain](#attributes)

### web_app_container_show_archived_real_path_enabled<a name='wls_domain_web_app_container_show_archived_real_path_enabled'>

Archived real path enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_domain](#attributes)
