---
title: wls foreign jndi provider
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a foreign jndi provider in an WebLogic domain.

Here is an example on how you should use this:

    wls_foreign_jndi_provider { 'DomainA':
      ensure                  => 'present',
      initial_context_factory => 'weblogic.jndi.WLInitialContextFactory',
      provider_properties     => ['bbb=aaaa', 'xxx=123'],
      provider_url            => 't3://10.10.10.100:7001',
      target                  => ['WebCluster'],
      targettype              => ['Cluster'],
      user                    => 'weblogic',
      password                => 'weblogic1',
    }

In this example you are managing a foreign jndi provider in the default domain. When you want to
manage a foreign jndi provider in a specific domain, you can use:


    wls_foreign_jndi_provider { 'my_domain/LDAP':
      ensure                  => 'present',
      initial_context_factory => 'com.sun.jndi.ldap.LdapCtxFactory',
      provider_properties     => ['referral=follow'],
      provider_url            => 'ldap://:10.10.10.100:389',
      target                  => ['AdminServer'],
      targettype              => ['Server'],
      user                    => 'cn=orcladmin',
      password                => 'weblogic1',
    }

## Attributes



Attribute Name                                                                    | Short Description                                                                         |
--------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[deployment_order](#wls_foreign_jndi_provider_deployment_order)                   | A priority that the server uses to determine when it deploys an item.                     |
[disable_corrective_change](#wls_foreign_jndi_provider_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_foreign_jndi_provider_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_foreign_jndi_provider_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_foreign_jndi_provider_ensure)                                       | The basic property that the resource should be in.                                        |
[initial_context_factory](#wls_foreign_jndi_provider_initial_context_factory)     | The initial context factory
                                                              |
[name](#wls_foreign_jndi_provider_name)                                           | The name.                                                                                 |
[notes](#wls_foreign_jndi_provider_notes)                                         | Optional information that you can include to describe this configuration.                 |
[password](#wls_foreign_jndi_provider_password)                                   | The weblogic artifacts password.                                                          |
[provider](#wls_foreign_jndi_provider_provider)                                   | resource.                                                                                 |
[provider_name](#wls_foreign_jndi_provider_provider_name)                         | The provider name
                                                                        |
[provider_properties](#wls_foreign_jndi_provider_provider_properties)             | The properties for the Foreign JNDI provider
                                             |
[provider_url](#wls_foreign_jndi_provider_provider_url)                           | The URL to use for the Foreign JNDI provider
                                             |
[tags](#wls_foreign_jndi_provider_tags)                                           | Return all tags on this Configuration MBean
                                              |
[target](#wls_foreign_jndi_provider_target)                                       | An array of target names.                                                                 |
[targettype](#wls_foreign_jndi_provider_targettype)                               | An array of target types.                                                                 |
[user](#wls_foreign_jndi_provider_user)                                           | The user to use for the Foreign JNDI provider
                                            |




### deployment_order<a name='wls_foreign_jndi_provider_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_foreign_jndi_provider {a_wls_foreign_jndi_provider :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_jndi_provider:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### disable_corrective_change<a name='wls_foreign_jndi_provider_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_foreign_jndi_provider](#attributes)

### disable_corrective_ensure<a name='wls_foreign_jndi_provider_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_foreign_jndi_provider](#attributes)

### domain<a name='wls_foreign_jndi_provider_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### ensure<a name='wls_foreign_jndi_provider_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_foreign_jndi_provider](#attributes)

### initial_context_factory<a name='wls_foreign_jndi_provider_initial_context_factory'>

The initial context factory



[Back to overview of wls_foreign_jndi_provider](#attributes)

### name<a name='wls_foreign_jndi_provider_name'>

The name.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### notes<a name='wls_foreign_jndi_provider_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_foreign_jndi_provider {a_wls_foreign_jndi_provider :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_jndi_provider:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### password<a name='wls_foreign_jndi_provider_password'>

The weblogic artifacts password.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### provider<a name='wls_foreign_jndi_provider_provider'>

The specific backend to use for this `wls_foreign_jndi_provider`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage foreign JNDI providers



[Back to overview of wls_foreign_jndi_provider](#attributes)

### provider_name<a name='wls_foreign_jndi_provider_provider_name'>

The provider name



[Back to overview of wls_foreign_jndi_provider](#attributes)

### provider_properties<a name='wls_foreign_jndi_provider_provider_properties'>

The properties for the Foreign JNDI provider



[Back to overview of wls_foreign_jndi_provider](#attributes)

### provider_url<a name='wls_foreign_jndi_provider_provider_url'>

The URL to use for the Foreign JNDI provider



[Back to overview of wls_foreign_jndi_provider](#attributes)

### tags<a name='wls_foreign_jndi_provider_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_foreign_jndi_provider {a_wls_foreign_jndi_provider :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_jndi_provider:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_jndi_provider](#attributes)

### target<a name='wls_foreign_jndi_provider_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_foreign_jndi_provider](#attributes)

### targettype<a name='wls_foreign_jndi_provider_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_foreign_jndi_provider](#attributes)

### user<a name='wls_foreign_jndi_provider_user'>

The user to use for the Foreign JNDI provider



[Back to overview of wls_foreign_jndi_provider](#attributes)
