---
title: wls foreign server
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage foreign servers in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_foreign_server { 'jmsClusterModule:AQForeignServer':
      ensure                => 'present',
      defaulttargeting      => 1,
      extraproperties       => 'datasource=jdbc/hrDS',
      initialcontextfactory => ['oracle.jms.AQjmsInitialContextFactory'],
    }

In this example you are managing a foreign server in the default domain. When you want to
manage a foreign server in a specific domain, you can use:

    wls_foreign_server { 'my_domain/jmsClusterModule:Jboss':
      ensure                => 'present',
      connectionurl         => 'remote://10.10.10.10:4447',
      defaulttargeting      => '0',
      extraproperties       => ['java.naming.security.principal=jmsuser'],
      initialcontextfactory => 'org.jboss.naming.remote.client.InitialContextFactory',
      subdeployment         => 'wlsServers',
    }

## Attributes



Attribute Name                                                               | Short Description                                                                                                                    |
---------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------ |
[connection_url](#wls_foreign_server_connection_url)                         | The URL that WebLogic Server will use to contact the JNDI provider.                                                                  |
[connectionurl](#wls_foreign_server_connectionurl)                           | The connectionurl.                                                                                                                   |
[default_targeting_enabled](#wls_foreign_server_default_targeting_enabled)   | Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.         |
[defaulttargeting](#wls_foreign_server_defaulttargeting)                     | default targeting enabled.                                                                                                           |
[disable_corrective_change](#wls_foreign_server_disable_corrective_change)   | Disable the modification of a resource when Puppet decides it is a corrective change.                                                |
[disable_corrective_ensure](#wls_foreign_server_disable_corrective_ensure)   | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                            |
[domain](#wls_foreign_server_domain)                                         | With this parameter, you identify the domain, where your objects is in.                                                              |
[ensure](#wls_foreign_server_ensure)                                         | The basic property that the resource should be in.                                                                                   |
[extraproperties](#wls_foreign_server_extraproperties)                       | The extra properties.                                                                                                                |
[foreign_server_name](#wls_foreign_server_foreign_server_name)               | Foreign Server name
                                                                                                                 |
[initial_context_factory](#wls_foreign_server_initial_context_factory)       | The name of the class that must be instantiated to access the JNDI provider.                                                         |
[initialcontextfactory](#wls_foreign_server_initialcontextfactory)           | The initial contextfactory.                                                                                                          |
[jmsmodule](#wls_foreign_server_jmsmodule)                                   | The JMS module name.                                                                                                                 |
[jndi_properties_credential](#wls_foreign_server_jndi_properties_credential) | Any Credentials that must be set for the JNDI provider.                                                                              |
[name](#wls_foreign_server_name)                                             | The name.                                                                                                                            |
[notes](#wls_foreign_server_notes)                                           | Optional information that you can include to describe this named JMS descriptor bean.                                                |
[password](#wls_foreign_server_password)                                     | The foreign server password.                                                                                                         |
[provider](#wls_foreign_server_provider)                                     | resource.                                                                                                                            |
[sub_deployment_name](#wls_foreign_server_sub_deployment_name)               | Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name. |
[subdeployment](#wls_foreign_server_subdeployment)                           | The subdeployment name.                                                                                                              |
[timeout](#wls_foreign_server_timeout)                                       | Timeout for applying a resource.                                                                                                     |




### connection_url<a name='wls_foreign_server_connection_url'>

The URL that WebLogic Server will use to contact the JNDI provider. The syntax of this URL depends on which JNDI provider is being used. For WebLogic JMS, leave this field blank if you are referencing WebLogic JMS objects within the same cluster.  This value corresponds to the standard JNDI property, <code>java.naming.provider.url</code>.  Note: If this value is not specified, look-ups will be performed on the JNDI server within the WebLogic Server instance where this connection factory is deployed.

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       connection_url => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:connection_url']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_server](#attributes)

### connectionurl<a name='wls_foreign_server_connectionurl'>

The connectionurl.



[Back to overview of wls_foreign_server](#attributes)

### default_targeting_enabled<a name='wls_foreign_server_default_targeting_enabled'>

Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.  When set to true, this resource implicitly inherits the targeting of its parent module. When set to false, this resource gets targeted based its subdeployment's targets, if one is specified.

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       default_targeting_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:default_targeting_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_foreign_server](#attributes)

### defaulttargeting<a name='wls_foreign_server_defaulttargeting'>

default targeting enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_foreign_server](#attributes)

### disable_corrective_change<a name='wls_foreign_server_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_foreign_server](#attributes)

### disable_corrective_ensure<a name='wls_foreign_server_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_foreign_server](#attributes)

### domain<a name='wls_foreign_server_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_foreign_server](#attributes)

### ensure<a name='wls_foreign_server_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_foreign_server](#attributes)

### extraproperties<a name='wls_foreign_server_extraproperties'>

The extra properties.



[Back to overview of wls_foreign_server](#attributes)

### foreign_server_name<a name='wls_foreign_server_foreign_server_name'>

Foreign Server name



[Back to overview of wls_foreign_server](#attributes)

### initial_context_factory<a name='wls_foreign_server_initial_context_factory'>

The name of the class that must be instantiated to access the JNDI provider. This class name depends on the JNDI provider and the vendor that are being used.  This value corresponds to the standard JNDI property, <code>java.naming.factory.initial</code>.  Note: This value defaults to <code>weblogic.jndi.WLInitialContextFactory</code>, which is the correct value for WebLogic Server.

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       initial_context_factory => 'weblogic.jndi.WLInitialContextFactory'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:initial_context_factory']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_server](#attributes)

### initialcontextfactory<a name='wls_foreign_server_initialcontextfactory'>

The initial contextfactory.



[Back to overview of wls_foreign_server](#attributes)

### jmsmodule<a name='wls_foreign_server_jmsmodule'>

The JMS module name.



[Back to overview of wls_foreign_server](#attributes)

### jndi_properties_credential<a name='wls_foreign_server_jndi_properties_credential'>

Any Credentials that must be set for the JNDI provider. These Credentials will be part of the properties will be passed directly to the constructor for the JNDI provider's InitialContext class.  Some foreign providers require other properties to be set while obtaining an initial naming context. These properties can be set with a property bean

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       jndi_properties_credential => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:jndi_properties_credential']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_server](#attributes)

### name<a name='wls_foreign_server_name'>

The name.



[Back to overview of wls_foreign_server](#attributes)

### notes<a name='wls_foreign_server_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_server](#attributes)

### password<a name='wls_foreign_server_password'>

The foreign server password.

Usage :

    wls_foreign_server { ....:
      ...
      password => 'clear_text_password',
      ...
    }

The password string is passed to WebLogic for encryption and then stored in the domain.



[Back to overview of wls_foreign_server](#attributes)

### provider<a name='wls_foreign_server_provider'>

The specific backend to use for this `wls_foreign_server`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Foreign Server in a JMS module of an WebLogic domain via regular WLST



[Back to overview of wls_foreign_server](#attributes)

### sub_deployment_name<a name='wls_foreign_server_sub_deployment_name'>

Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.  The targets of the sub-deployment will be the targets of this entity.

An example on how to use this:

    wls_foreign_server {a_wls_foreign_server :
       ...
       sub_deployment_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server:sub_deployment_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_foreign_server](#attributes)

### subdeployment<a name='wls_foreign_server_subdeployment'>

The subdeployment name.



[Back to overview of wls_foreign_server](#attributes)

### timeout<a name='wls_foreign_server_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_foreign_server](#attributes)
