---
title: wls identity asserter
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage Identity Asserters in an WebLogic domain.

Here is an example on how you should use this:

    wls_authentication_provider { 'DefaultIdentityAsserter':
      ensure            => 'present',
      providerclassname => 'weblogic.security.providers.authentication.DefaultIdentityAsserter',
      attributes:       => 'DigestReplayDetectionEnabled;UseDefaultUserNameMapper',
      attributesvalues  => '1;1;',
      activetypes       => 'AuthenticatedUser::X.509',
      defaultmappertype => 'CN',
    }


In this example you are managing a identity asserter in the default domain. When you want to
manage a identity asserter in a specific domain, you can use:

    wls_authentication_provider { 'my_domain/DefaultIdentityAsserter':
      ensure            => 'present',
      providerclassname => 'weblogic.security.providers.authentication.DefaultIdentityAsserter',
      attributes:       => 'DigestReplayDetectionEnabled;UseDefaultUserNameMapper',
      attributesvalues  => '1;1;',
      activetypes       => 'AuthenticatedUser::X.509',
      defaultmappertype => 'CN',
    }

## Attributes



Attribute Name                                                                      | Short Description                                                                         |
----------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[activetypes](#wls_identity_asserter_activetypes)                                   | :: seperated list of active types
                                                        |
[attributes](#wls_identity_asserter_attributes)                                     | The extra authentication provider properties
                                             |
[attributesvalues](#wls_identity_asserter_attributesvalues)                         | The extra authentication provider property values
                                        |
[authentication_provider_name](#wls_identity_asserter_authentication_provider_name) | The authentication provider name
                                                         |
[defaultmappertype](#wls_identity_asserter_defaultmappertype)                       | the default mapper type
                                                                  |
[disable_corrective_change](#wls_identity_asserter_disable_corrective_change)       | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_identity_asserter_disable_corrective_ensure)       | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_identity_asserter_domain)                                             | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_identity_asserter_ensure)                                             | The basic property that the resource should be in.                                        |
[name](#wls_identity_asserter_name)                                                 | The name.                                                                                 |
[order](#wls_identity_asserter_order)                                               | The order of the Authentication Provider (0 is highest).                                  |
[provider](#wls_identity_asserter_provider)                                         | resource.                                                                                 |
[providerclassname](#wls_identity_asserter_providerclassname)                       | The provider classname
                                                                   |
[timeout](#wls_identity_asserter_timeout)                                           | Timeout for applying a resource.                                                          |




### activetypes<a name='wls_identity_asserter_activetypes'>

:: seperated list of active types



[Back to overview of wls_identity_asserter](#attributes)

### attributes<a name='wls_identity_asserter_attributes'>

The extra authentication provider properties



[Back to overview of wls_identity_asserter](#attributes)

### attributesvalues<a name='wls_identity_asserter_attributesvalues'>

The extra authentication provider property values



[Back to overview of wls_identity_asserter](#attributes)

### authentication_provider_name<a name='wls_identity_asserter_authentication_provider_name'>

The authentication provider name



[Back to overview of wls_identity_asserter](#attributes)

### defaultmappertype<a name='wls_identity_asserter_defaultmappertype'>

the default mapper type



[Back to overview of wls_identity_asserter](#attributes)

### disable_corrective_change<a name='wls_identity_asserter_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_identity_asserter](#attributes)

### disable_corrective_ensure<a name='wls_identity_asserter_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_identity_asserter](#attributes)

### domain<a name='wls_identity_asserter_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_identity_asserter](#attributes)

### ensure<a name='wls_identity_asserter_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_identity_asserter](#attributes)

### name<a name='wls_identity_asserter_name'>

The name.



[Back to overview of wls_identity_asserter](#attributes)

### order<a name='wls_identity_asserter_order'>

The order of the Authentication Provider (0 is highest).

Optionally, the provider can be ordered by specifying a value to the order paramater,
which is a zero-based list. When configuring ordering order, it may be necessary to create
the resources with Puppet ordering (if not using Hiera) or by structuring Hiera
in matching order. Otherwise ordering may fail if not all authentication providers are created
yet (by default the provider will be ordered last if it is greater than the number of providers
currently configured).



[Back to overview of wls_identity_asserter](#attributes)

### provider<a name='wls_identity_asserter_provider'>

The specific backend to use for this `wls_identity_asserter`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage identity asserters in an WebLogic domain via regular WLST



[Back to overview of wls_identity_asserter](#attributes)

### providerclassname<a name='wls_identity_asserter_providerclassname'>

The provider classname



[Back to overview of wls_identity_asserter](#attributes)

### timeout<a name='wls_identity_asserter_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_identity_asserter](#attributes)
