---
title: wls jms security policy
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage security authorization policies in an WebLogic Security Realm.

## Attributes



Attribute Name                                                                  | Short Description                                                                         |
------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[action](#wls_jms_security_policy_action)                                       | action to apply authorization policy on for a queue or topic
                             |
[authorizationprovider](#wls_jms_security_policy_authorizationprovider)         | The security authorization providers of the domain
                                       |
[destinationtype](#wls_jms_security_policy_destinationtype)                     | The destination type of a jms resource (queue or topic)
                                  |
[disable_corrective_change](#wls_jms_security_policy_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_jms_security_policy_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_jms_security_policy_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_jms_security_policy_ensure)                                       | The basic property that the resource should be in.                                        |
[jmsmodule](#wls_jms_security_policy_jmsmodule)                                 | The JMS module name.                                                                      |
[name](#wls_jms_security_policy_name)                                           | The name.                                                                                 |
[policyexpression](#wls_jms_security_policy_policyexpression)                   | A string representation of an security authorization policy
                              |
[provider](#wls_jms_security_policy_provider)                                   | resource.                                                                                 |
[resourcename](#wls_jms_security_policy_resourcename)                           | The name of the jms resource
                                                             |
[timeout](#wls_jms_security_policy_timeout)                                     | Timeout for applying a resource.                                                          |




### action<a name='wls_jms_security_policy_action'>

action to apply authorization policy on for a queue or topic

Valid values are `send`, `receive`, `browse`, `all`. 

[Back to overview of wls_jms_security_policy](#attributes)

### authorizationprovider<a name='wls_jms_security_policy_authorizationprovider'>

The security authorization providers of the domain



[Back to overview of wls_jms_security_policy](#attributes)

### destinationtype<a name='wls_jms_security_policy_destinationtype'>

The destination type of a jms resource (queue or topic)

Valid values are `queue`, `topic`. 

[Back to overview of wls_jms_security_policy](#attributes)

### disable_corrective_change<a name='wls_jms_security_policy_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_jms_security_policy](#attributes)

### disable_corrective_ensure<a name='wls_jms_security_policy_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_jms_security_policy](#attributes)

### domain<a name='wls_jms_security_policy_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_jms_security_policy](#attributes)

### ensure<a name='wls_jms_security_policy_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_jms_security_policy](#attributes)

### jmsmodule<a name='wls_jms_security_policy_jmsmodule'>

The JMS module name.



[Back to overview of wls_jms_security_policy](#attributes)

### name<a name='wls_jms_security_policy_name'>

The name.



[Back to overview of wls_jms_security_policy](#attributes)

### policyexpression<a name='wls_jms_security_policy_policyexpression'>

A string representation of an security authorization policy



[Back to overview of wls_jms_security_policy](#attributes)

### provider<a name='wls_jms_security_policy_provider'>

The specific backend to use for this `wls_jms_security_policy`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: 



[Back to overview of wls_jms_security_policy](#attributes)

### resourcename<a name='wls_jms_security_policy_resourcename'>

The name of the jms resource



[Back to overview of wls_jms_security_policy](#attributes)

### timeout<a name='wls_jms_security_policy_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_jms_security_policy](#attributes)
