---
title: wls jms topic
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a Tpoic in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_topic { 'jmsClusterModule:Topic1':
      ensure            => 'present',
      balancingpolicy   => 'Round-Robin',
      defaulttargeting  => '0',
      deliverymode      => 'No-Delivery',
      destination_keys  => ['JMSPriority', 'JmsMessageId'],
      distributed       => 1,
      expirationpolicy  => 'Discard',
      forwardingpolicy  => 'Replicated',
      jndiname          => 'jms/Topic1',
      redeliverydelay   => '2000',
      redeliverylimit   => '2',
      subdeployment     => 'jmsServers',
      timetodeliver     => '-1',
      timetolive        => '300000',
      consumptionpaused => '0',
      insertionpaused   => '0',
      productionpaused  => '0',
    }

**WARNING** When you want to `absent` a topic. you must ensure that
the `distributed` parameter is specified.

    wls_jms_topic { 'jmsClusterModule:ErrorTopic':
      ensure      => 'absent',
      distributed => 1,
    }

Failure to specify the correct value for `distributed`, will result
in an error on removal of the topic.

## Attributes



Attribute Name                                                                          | Short Description                                                                                                                                                                                                                          |
--------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[attach_sender](#wls_jms_topic_attach_sender)                                           | Specifies whether messages landing on this destination should attach the credential of the sending user.                                                                                                                                   |
[balancingpolicy](#wls_jms_topic_balancingpolicy)                                       | balancingpolicy of the distributed topic
                                                                                                                                                                                                  |
[consumption_paused_at_startup](#wls_jms_topic_consumption_paused_at_startup)           | Specifies whether consumption is paused on a destination at startup.                                                                                                                                                                       |
[consumptionpaused](#wls_jms_topic_consumptionpaused)                                   | 
                                                                                                                                                                                                                                          |
[default_targeting_enabled](#wls_jms_topic_default_targeting_enabled)                   | Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.                                                                                                               |
[default_unit_of_order](#wls_jms_topic_default_unit_of_order)                           | Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name.                                                                                                     |
[defaulttargeting](#wls_jms_topic_defaulttargeting)                                     | default targeting enabled.                                                                                                                                                                                                                 |
[delivery_error_destination](#wls_jms_topic_delivery_error_destination)                 | The name of the target error destination for messages that have expired or reached their redelivery limit.                                                                                                                                 |
[delivery_expiration_logging_policy](#wls_jms_topic_delivery_expiration_logging_policy) | The policy that defines what information about the message is logged when the Expiration Policy is set to Log.                                                                                                                             |
[delivery_expiration_policy](#wls_jms_topic_delivery_expiration_policy)                 | The message Expiration Policy to use when an expired message is encountered on a destination.                                                                                                                                              |
[delivery_redelivery_limit](#wls_jms_topic_delivery_redelivery_limit)                   | The number of redelivery tries a message can have before it is moved to the error destination.                                                                                                                                             |
[delivery_template_bean](#wls_jms_topic_delivery_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[deliverymode](#wls_jms_topic_deliverymode)                                             | deliverymode of the topic
                                                                                                                                                                                                                 |
[destination_keys](#wls_jms_topic_destination_keys)                                     | The destination keys of  topic.                                                                                                                                                                                                            |
[disable_corrective_change](#wls_jms_topic_disable_corrective_change)                   | Disable the modification of a resource when Puppet decides it is a corrective change.                                                                                                                                                      |
[disable_corrective_ensure](#wls_jms_topic_disable_corrective_ensure)                   | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                                                                                                                                  |
[distributed](#wls_jms_topic_distributed)                                               | Distributed Topic
                                                                                                                                                                                                                         |
[domain](#wls_jms_topic_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                    |
[ensure](#wls_jms_topic_ensure)                                                         | The basic property that the resource should be in.                                                                                                                                                                                         |
[errordestination](#wls_jms_topic_errordestination)                                     | errordestination of the topic.                                                                                                                                                                                                             |
[errordestinationtype](#wls_jms_topic_errordestinationtype)                             | error destination jms type of the topic
                                                                                                                                                                                                   |
[expirationloggingpolicy](#wls_jms_topic_expirationloggingpolicy)                       | expirationloggingpolicy of the topic
                                                                                                                                                                                                      |
[expirationpolicy](#wls_jms_topic_expirationpolicy)                                     | expirationpolicy of the topic
                                                                                                                                                                                                             |
[forwarding_policy](#wls_jms_topic_forwarding_policy)                                   |  The uniform distributed topic message Forwarding Policy specifies whether a sent message is forwarded to all members.                                                                                                                     |
[forwardingpolicy](#wls_jms_topic_forwardingpolicy)                                     | forwardingpolicy of the topic, can only be set if the topic is distributed
                                                                                                                                                                |
[incomplete_work_expiration_time](#wls_jms_topic_incomplete_work_expiration_time)       | Specifies the maximum length of time, in milliseconds, before undelivered messages in an incomplete UOW are expired.                                                                                                                       |
[insertion_paused_at_startup](#wls_jms_topic_insertion_paused_at_startup)               | Specifies whether new message insertion is paused on a destination at startup.                                                                                                                                                             |
[insertionpaused](#wls_jms_topic_insertionpaused)                                       | Insertion is paused at startup.                                                                                                                                                                                                            |
[jms_create_destination_identifier](#wls_jms_topic_jms_create_destination_identifier)   | A reference name for a destination or a member of a distributed destination that provides a way to lookup that destination without JNDI using <code>javax.jms.Session createQueue </code> or <code>createTopic</code>.                     |
[jmsmodule](#wls_jms_topic_jmsmodule)                                                   | The JMS module name.                                                                                                                                                                                                                       |
[jndi_name](#wls_jms_topic_jndi_name)                                                   | The global JNDI name used to look up the destination within the JNDI namespace.                                                                                                                                                            |
[jndiname](#wls_jms_topic_jndiname)                                                     | The jndi name.                                                                                                                                                                                                                             |
[load_balancing_policy](#wls_jms_topic_load_balancing_policy)                           | Determines how messages are distributed to the members of this destination.                                                                                                                                                                |
[local_jndi_name](#wls_jms_topic_local_jndi_name)                                       | The local JNDI name used to look up the destination within the JNDI namespace of the server where the destination resource is targeted.                                                                                                    |
[log_message_logging_enabled](#wls_jms_topic_log_message_logging_enabled)               | Specifies whether the module logs information about the message life cycle.                                                                                                                                                                |
[log_message_logging_format](#wls_jms_topic_log_message_logging_format)                 | Defines which information about the message is logged.                                                                                                                                                                                     |
[log_template_bean](#wls_jms_topic_log_template_bean)                                   | Finds the template bean for this destination.                                                                                                                                                                                              |
[maximum_message_size](#wls_jms_topic_maximum_message_size)                             | The maximum size of a message that is accepted from producers on this destination.                                                                                                                                                         |
[messagelogging](#wls_jms_topic_messagelogging)                                         | Message logging for JMS
                                                                                                                                                                                                                   |
[messages_limit_override](#wls_jms_topic_messages_limit_override)                       | The maximum number of messages that can be stored in a topic subscription.                                                                                                                                                                 |
[messaging_performance_preference](#wls_jms_topic_messaging_performance_preference)     | Controls how long destinations are willing to wait to create full batches of available messages (if at all) for delivery to consumers.                                                                                                     |
[multicast_address](#wls_jms_topic_multicast_address)                                   | The IP address that this topic uses to transmit messages to multicast consumers.                                                                                                                                                           |
[multicast_port](#wls_jms_topic_multicast_port)                                         | The IP port that this topic uses to transmit messages to multicast consumers.                                                                                                                                                              |
[multicast_template_bean](#wls_jms_topic_multicast_template_bean)                       | Finds the template bean for this destination.                                                                                                                                                                                              |
[multicast_time_to_live](#wls_jms_topic_multicast_time_to_live)                         | The number of routers that a message traverses en route to a consumer.                                                                                                                                                                     |
[name](#wls_jms_topic_name)                                                             | The name.                                                                                                                                                                                                                                  |
[notes](#wls_jms_topic_notes)                                                           | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                                                                      |
[override_delivery_mode](#wls_jms_topic_override_delivery_mode)                         | The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.                                                                                                |
[override_priority](#wls_jms_topic_override_priority)                                   | The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer.                                                                                                       |
[override_redelivery_delay](#wls_jms_topic_override_redelivery_delay)                   | The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory.                                                               |
[override_template_bean](#wls_jms_topic_override_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[override_time_to_deliver](#wls_jms_topic_override_time_to_deliver)                     | The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. |
[override_time_to_live](#wls_jms_topic_override_time_to_live)                           | The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer.                                                                                           |
[production_paused_at_startup](#wls_jms_topic_production_paused_at_startup)             | Specifies whether new message production is paused on a destination at startup.                                                                                                                                                            |
[productionpaused](#wls_jms_topic_productionpaused)                                     | 
                                                                                                                                                                                                                                          |
[provider](#wls_jms_topic_provider)                                                     | resource.                                                                                                                                                                                                                                  |
[quota](#wls_jms_topic_quota)                                                           | Ths name of the quota for the jms object.                                                                                                                                                                                                  |
[redeliverydelay](#wls_jms_topic_redeliverydelay)                                       | redeliverydelay of the topic
                                                                                                                                                                                                              |
[redeliverylimit](#wls_jms_topic_redeliverylimit)                                       | redeliverylimit of the topic
                                                                                                                                                                                                              |
[saf_export_policy](#wls_jms_topic_saf_export_policy)                                   | Specifies whether a user can send messages to a destination using Store-and-Forward.                                                                                                                                                       |
[sub_deployment_name](#wls_jms_topic_sub_deployment_name)                               | Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.                                                                                                       |
[subdeployment](#wls_jms_topic_subdeployment)                                           | The subdeployment name.                                                                                                                                                                                                                    |
[template](#wls_jms_topic_template)                                                     | The JMS template from which the destination is derived.                                                                                                                                                                                    |
[templatename](#wls_jms_topic_templatename)                                             | The template name
                                                                                                                                                                                                                         |
[thresholds_bytes_high](#wls_jms_topic_thresholds_bytes_high)                           | The upper threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_bytes_low](#wls_jms_topic_thresholds_bytes_low)                             | The lower threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_messages_high](#wls_jms_topic_thresholds_messages_high)                     | The upper threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_messages_low](#wls_jms_topic_thresholds_messages_low)                       | The lower threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_template_bean](#wls_jms_topic_thresholds_template_bean)                     | Finds the template bean for this destination.                                                                                                                                                                                              |
[timeout](#wls_jms_topic_timeout)                                                       | Timeout for applying a resource.                                                                                                                                                                                                           |
[timetodeliver](#wls_jms_topic_timetodeliver)                                           | timetodeliver of the topic
                                                                                                                                                                                                                |
[timetolive](#wls_jms_topic_timetolive)                                                 | timetolive of the topic
                                                                                                                                                                                                                   |
[topic_name](#wls_jms_topic_topic_name)                                                 | The topic name
                                                                                                                                                                                                                            |
[unit_of_order_routing](#wls_jms_topic_unit_of_order_routing)                           | Determines how a distributed destination member is selected as the destination for a message that is part of a unit-of-order.                                                                                                              |
[unit_of_work_handling_policy](#wls_jms_topic_unit_of_work_handling_policy)             | Specifies whether the Unit-of-Work (UOW) feature is enabled for this destination.                                                                                                                                                          |




### attach_sender<a name='wls_jms_topic_attach_sender'>

Specifies whether messages landing on this destination should attach the credential of the sending user. You should consult the JMSXUserID documentation in Programming WebLogic JMS before using this feature.  <ul> <li>Supports The JMSXUserID property is set with the security principal of the sending user if requested. The sender can request its identity to be attached to its messages by using a connection factory with the AttachJMSXUserID security property enabled.</li>  <li>Never The JMSXUserID property is never set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li>  <li>Always The JMSXUserID property is always set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li> </ul>  This attribute is dynamically configurable. A dynamic change of this attribute will affect only messages received after the update has been made.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       attach_sender => 'supports'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:attach_sender']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### balancingpolicy<a name='wls_jms_topic_balancingpolicy'>

balancingpolicy of the distributed topic

Valid values are `absent`, `Round-Robin`, `Random`. 

[Back to overview of wls_jms_topic](#attributes)

### consumption_paused_at_startup<a name='wls_jms_topic_consumption_paused_at_startup'>

Specifies whether consumption is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Consumption Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Consumption Paused is explicitly disabled for this destination. </li>  <li>true Consumption Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       consumption_paused_at_startup => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:consumption_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### consumptionpaused<a name='wls_jms_topic_consumptionpaused'>



Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### default_targeting_enabled<a name='wls_jms_topic_default_targeting_enabled'>

Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.  When set to true, this resource implicitly inherits the targeting of its parent module. When set to false, this resource gets targeted based its subdeployment's targets, if one is specified.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       default_targeting_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:default_targeting_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### default_unit_of_order<a name='wls_jms_topic_default_unit_of_order'>

Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name. Any message arriving at this destination that does not already belong to a unit-of-order is assigned this default name.  This field is recommended for advanced use. Generally, it is  recommended to set a message unit-of-order using application calls or connection factory configuration. When relying on a destination default unit order to enforce ordering with a distributed destination, the application must be aware that unit-of-order routing doesn't apply. Instead the application must specifically ensure that any particular set of messages that must be processed in order are all sent to the same specific member destination even in the event of process failures or service migration.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       default_unit_of_order => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:default_unit_of_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### defaulttargeting<a name='wls_jms_topic_defaulttargeting'>

default targeting enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### delivery_error_destination<a name='wls_jms_topic_delivery_error_destination'>

The name of the target error destination for messages that have expired or reached their redelivery limit. If no error destination is configured, then such messages are simply dropped. If a message has expired or reached its redelivery limit, and the Expiration Policy is set to Redirect, then the message is moved to the specified Error Destination.  For standalone destinations, an error destination must be another standalone destination that is targeted to the same JMS server as the destinations for which the error destination is defined. For uniform distributed destinations (UDDs), the error destination must be another UDD that shares the same subdeployment (i.e., targets) as the current UDD.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       delivery_error_destination => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:delivery_error_destination']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### delivery_expiration_logging_policy<a name='wls_jms_topic_delivery_expiration_logging_policy'>

The policy that defines what information about the message is logged when the Expiration Policy is set to Log. The valid logging policy values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>  When specifying multiple values, enter them as a comma-separated list. The <code>%header%</code> and <code>%properties% </code> values are not case sensitive. For example, you could use <code>"%header%,%properties%"</code> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <code>"%header, name, address, city, state, zip"</code>.  Note: The <code>JMSMessageID</code> field is always logged and cannot be turned off. Therefore, if the Expiration Logging Policy is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <code>JMSMessageID</code> of the message.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       delivery_expiration_logging_policy => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:delivery_expiration_logging_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### delivery_expiration_policy<a name='wls_jms_topic_delivery_expiration_policy'>

The message Expiration Policy to use when an expired message is encountered on a destination. The valid expiration policies are:  None - Same as the Discard policy; expired messages are simply removed from the destination.  Discard - Removes expired messages from the messaging system. The removal is not logged and the message is not redirected to another location. If no value is defined for a given destination (i.e., None), then expired messages are discarded.  Log - Removes expired messages from the system and writes an entry to the server log file indicating that the messages have been removed from the system. The actual information that is logged is defined by the Expiration Logging Policy.  Redirect - Moves expired messages from their current location to the Error Destination defined for the destination. The message retains its body, and all of its properties. The message also retains all of its header fields, but with the following exceptions: <ul> <li> The destination for the message becomes the error destination. <li> All property overrides associated with the error destination are applied to the redirected message. <li> If there is no Time-To-Live Override value for the error destination, then the message receives a new Expiration Time of zero (indicating that it will not expire again). </ul>  It is illegal to use the Redirect policy when there is no valid error destination defined for the destination. Similarly, it is illegal to remove the error destination for a destination that is using the Redirect policy.  Note: The Maximum Message quota is only enforced for sending new messages. It is ignored when moving messages because of the Redirect policy.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       delivery_expiration_policy => 'Discard'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:delivery_expiration_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### delivery_redelivery_limit<a name='wls_jms_topic_delivery_redelivery_limit'>

The number of redelivery tries a message can have before it is moved to the error destination. This setting overrides any redelivery limit set by the message sender. If the redelivery limit is configured, but no error destination is configured, then persistent and non-persistent messages are simply dropped (deleted) when they reach their redelivery limit.  The default value (-1) specifies that the destination will not override the message sender's redelivery limit setting.   Note: WebLogic Server supports the JMSXDeliveryCount message property, which specifies the number of message delivery attempts, where the first attempt is 1, the next attempt is 2, and so on. WebLogic Server makes a best effort to persist the delivery count, so that the delivery count does not reset back to 1 after a server reboot.  This attribute is dynamically configurable, but only incoming messages are impacted; previously sent messages continue to use their original redelivery limit.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       delivery_redelivery_limit => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:delivery_redelivery_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### delivery_template_bean<a name='wls_jms_topic_delivery_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       delivery_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:delivery_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### deliverymode<a name='wls_jms_topic_deliverymode'>

deliverymode of the topic

Valid values are `absent`, `No-Delivery`, `Persistent`, `Non-Persistent`. 

[Back to overview of wls_jms_topic](#attributes)

### destination_keys<a name='wls_jms_topic_destination_keys'>

The destination keys of  topic.



[Back to overview of wls_jms_topic](#attributes)

### disable_corrective_change<a name='wls_jms_topic_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_jms_topic](#attributes)

### disable_corrective_ensure<a name='wls_jms_topic_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_jms_topic](#attributes)

### distributed<a name='wls_jms_topic_distributed'>

Distributed Topic

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### domain<a name='wls_jms_topic_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_jms_topic](#attributes)

### ensure<a name='wls_jms_topic_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_jms_topic](#attributes)

### errordestination<a name='wls_jms_topic_errordestination'>

errordestination of the topic.



[Back to overview of wls_jms_topic](#attributes)

### errordestinationtype<a name='wls_jms_topic_errordestinationtype'>

error destination jms type of the topic

Valid values are `Queues`, `Topics`. 

[Back to overview of wls_jms_topic](#attributes)

### expirationloggingpolicy<a name='wls_jms_topic_expirationloggingpolicy'>

expirationloggingpolicy of the topic



[Back to overview of wls_jms_topic](#attributes)

### expirationpolicy<a name='wls_jms_topic_expirationpolicy'>

expirationpolicy of the topic

Valid values are `absent`, `Discard`, `Log`, `Redirect`. 

[Back to overview of wls_jms_topic](#attributes)

### forwarding_policy<a name='wls_jms_topic_forwarding_policy'>

 The uniform distributed topic message Forwarding Policy specifies whether a sent message is forwarded to all members.   The valid values are: <ul> <li>Replicated - The default. All physical topic members receive each sent message. If a message arrives at one of the physical topic members, a copy of this message is forwarded to the other members of that uniform distributed topic. A subscription on any one particular member will get a copy of any message sent to the uniform distributed topic logical name or to any particular uniform distributed topic member.</li>  <li>Partitioned - The physical member receiving the message is the only member of the uniform distributed topic that is aware of the message. When a message is published to the logical name of a Partitioned uniform distributed topic, it will only arrive on one particular physical topic member. Once a message arrives on a physical topic member, the message is not forwarded to the rest of the members of the uniform distributed destination, and subscribers on other physical topic members do not get a copy of that message. The Partitioned capability was added in WebLogic 10.3.4 (11gR1PS3).</li> </ul> A publisher that uses a logical JNDI name of a Replicated distributed topic is created on one member and every send call  publishes messages to the same member regardless the value of the <code>Load Balancing Enabled</code> attribute. This is behavior is backward compatible with previous WebLogic Server releases when using a uniform distributed topic. Under the same conditions, a Partitioned distributed topic publishes to the same member only when the value of the <code>Load Balancing Enabled</code> attribute is set to false. If the value of the <code>Load Balancing Enabled</code> attribute is to true, a publisher to a Partitioned distributed topic publishes messages that are load balanced accross all the members of the uniform distributed topic.   Most new applications will use the new Partitioned forwarding policy in combination with a logical subscription topology on a uniform distributed topic that consists of: (1) a same named physical subscription created directly on each physical member, (2) a Client ID Policy of Unrestricted, and (3) a Subscription Sharing Policy of <code>Sharable</code>. WL 10.3.4 Message Driven Beans (MDBs) provides a Topic Messages Distribution Mode option to automatically setup this kind of topology.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       forwarding_policy => 'Replicated'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:forwarding_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### forwardingpolicy<a name='wls_jms_topic_forwardingpolicy'>

forwardingpolicy of the topic, can only be set if the topic is distributed

Valid values are `absent`, `Partitioned`, `Replicated`. 

[Back to overview of wls_jms_topic](#attributes)

### incomplete_work_expiration_time<a name='wls_jms_topic_incomplete_work_expiration_time'>

Specifies the maximum length of time, in milliseconds, before undelivered messages in an incomplete UOW are expired. Such messages will then follow the expiration policy defined for undeliverable messages.  Note: An error destination for UOW messages cannot be configured with a Unit-of-Work Handling Policy of Single Message Delivery value.  This attribute is effective only if the Unit-of-Work Handling Policy is set to Single Message Delivery value. A value of -1 means that UOW messages will never expire.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       incomplete_work_expiration_time => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:incomplete_work_expiration_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### insertion_paused_at_startup<a name='wls_jms_topic_insertion_paused_at_startup'>

Specifies whether new message insertion is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Insertion Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Insertion Paused is explicitly disabled for this destination.</li>  <li>true Insertion Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       insertion_paused_at_startup => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:insertion_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### insertionpaused<a name='wls_jms_topic_insertionpaused'>

Insertion is paused at startup.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### jms_create_destination_identifier<a name='wls_jms_topic_jms_create_destination_identifier'>

A reference name for a destination or a member of a distributed destination that provides a way to lookup that destination without JNDI using <code>javax.jms.Session createQueue </code> or <code>createTopic</code>. See "How to Lookup a Destination" in  Programming JMS for more information on how to use this attribute.  This name must be unique within the scope of the JMS server to which this destination is targeted. However, it does not need to be unique within the scope of an entire JMS module or WebLogic Cluster. For example, two queues can have the same destination name as long as those queues are targeted to different JMS servers.  Note: Since this name must be unique within the scope of a JMS server, verify whether other JMS modules may contain destination names that conflict with this name. It is the responsibility of the deployer to resolve the destination names targeted to JMS servers.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       jms_create_destination_identifier => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:jms_create_destination_identifier']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### jmsmodule<a name='wls_jms_topic_jmsmodule'>

The JMS module name.



[Back to overview of wls_jms_topic](#attributes)

### jndi_name<a name='wls_jms_topic_jndi_name'>

The global JNDI name used to look up the destination within the JNDI namespace.  In a clustered environment, this name is propagated to the entire cluster. If you want the JNDI name to be bound only on the local server, and not propagated to the rest of the cluster, then use the <code>Local JNDI Name</code> parameter.  If not specified, the destination name will not be advertised through the global JNDI namespace.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### jndiname<a name='wls_jms_topic_jndiname'>

The jndi name.



[Back to overview of wls_jms_topic](#attributes)

### load_balancing_policy<a name='wls_jms_topic_load_balancing_policy'>

Determines how messages are distributed to the members of this destination.  Choose from the following distribution techniques: <ul> <li>Round-Robin The system maintains an ordering of physical topic members within the set by distributing the messaging load across the topic members one at a time in the order that they are defined in the configuration file. Each WebLogic Server instance maintains an identical ordering, but may be at a different point within the ordering. If weights are assigned to any of the topic members in the set, then those members appear multiple times in the ordering.  <li>Random The weight assigned to the topic members is used to compute a weighted distribution for the members of the set. The messaging load is distributed across the topic members by pseudo-randomly accessing the distribution. In the short run, the load will not be directly proportional to the weight. In the long run, the distribution will approach the limit of the distribution. A pure random distribution can be achieved by setting all the weights to the same value, which is typically set to 1. </ul>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       load_balancing_policy => 'Round-Robin'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:load_balancing_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### local_jndi_name<a name='wls_jms_topic_local_jndi_name'>

The local JNDI name used to look up the destination within the JNDI namespace of the server where the destination resource is targeted. In a clustered environment, this name is bound only on the local server instance and is not propagated to the rest of the cluster.  A destination can have both a local JNDI name and a (global) JNDI name.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       local_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:local_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### log_message_logging_enabled<a name='wls_jms_topic_log_message_logging_enabled'>

Specifies whether the module logs information about the message life cycle.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       log_message_logging_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:log_message_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### log_message_logging_format<a name='wls_jms_topic_log_message_logging_format'>

Defines which information about the message is logged. Valid values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>   When specifying multiple values, enter them as a comma-separated list. The <tt>%header%</tt> and <tt>%properies% </tt> values are not case sensitive. For example, you could use <tt>"%header%,%properties%"</tt> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <tt>"%header, name, address, city, state, zip"</tt> .   Note: The <tt>JMSMessageID</tt> field is always logged and cannot be turned off. Therefore, if the Message Logging Format is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <tt>JMSMessageID</tt> of the message. Gets the "message-logging-format" element

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       log_message_logging_format => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:log_message_logging_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### log_template_bean<a name='wls_jms_topic_log_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       log_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:log_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### maximum_message_size<a name='wls_jms_topic_maximum_message_size'>

The maximum size of a message that is accepted from producers on this destination.  The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <tt>JMSCorrelationID</tt> and <tt>JMSType</tt> . Producers sending messages that exceed the configured maximum message size for the destination receive a <tt>ResourceAllocationException</tt> .  The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       maximum_message_size => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:maximum_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### messagelogging<a name='wls_jms_topic_messagelogging'>

Message logging for JMS

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### messages_limit_override<a name='wls_jms_topic_messages_limit_override'>

The maximum number of messages that can be stored in a topic subscription.  If a new message arrives on subscriptions that have reached the specified limit, then the first-most available messages on these subscriptions will be deleted to make room for the new message. Subscription messages are immune from this deletion if they're participating in a pending transaction, have already been passed to a consumer and are awaiting acknowledgement, or if they are part of a Unit-of-Work that is still waiting to accumulate all of its messages. Note that if all messages are immune from deletion, then a new message can cause a subscription size to exceed its limit.  A value of -1 means no limit override.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       messages_limit_override => -1,
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### messaging_performance_preference<a name='wls_jms_topic_messaging_performance_preference'>

Controls how long destinations are willing to wait to create full batches of available messages (if at all) for delivery to consumers. At the minimum value, batching is disabled; at the default value, less-than-full batches will not wait and are delivered immediately with currently available messages; tuning higher than the default value controls the maximum wait time for additional messages before less-than-full batches are delivered to consumers.  The maximum message count of a full batch is controlled by the JMS connection factory's Messages Maximum setting.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       messaging_performance_preference => '25'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:messaging_performance_preference']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### multicast_address<a name='wls_jms_topic_multicast_address'>

The IP address that this topic uses to transmit messages to multicast consumers.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       multicast_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:multicast_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### multicast_port<a name='wls_jms_topic_multicast_port'>

The IP port that this topic uses to transmit messages to multicast consumers.   <!-- Gets the "port" element -->

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       multicast_port => '6001'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:multicast_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### multicast_template_bean<a name='wls_jms_topic_multicast_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       multicast_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:multicast_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### multicast_time_to_live<a name='wls_jms_topic_multicast_time_to_live'>

The number of routers that a message traverses en route to a consumer. A value of 1 limits the message to one subnet (which prevents it from traversing any routers).  This value is independent of the JMSExpirationTime value.   <!-- Gets the "time-to-live" element -->

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       multicast_time_to_live => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:multicast_time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### name<a name='wls_jms_topic_name'>

The name.



[Back to overview of wls_jms_topic](#attributes)

### notes<a name='wls_jms_topic_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_delivery_mode<a name='wls_jms_topic_override_delivery_mode'>

The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.  A value of <tt>No-Delivery</tt> specifies that the DeliveryMode will not be overridden.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_delivery_mode => 'No-Delivery'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_delivery_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_priority<a name='wls_jms_topic_override_priority'>

The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer. The default value (-1) specifies that the destination will not override the Priority set by the message producer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_priority => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_priority']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_redelivery_delay<a name='wls_jms_topic_override_redelivery_delay'>

The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory. Redelivered queue messages are put back into their originating destination; redelivered topic messages are put back into their originating subscription. The default value (-1) specifies that the destination will not override the RedeliveryDelay setting specified by the consumer and/or connection factory.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.  Note: Changing the RedeliveryDelay override only affects future rollbacks and recovers, it does not affect rollbacks and recovers that have already occurred.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_redelivery_delay => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_redelivery_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_template_bean<a name='wls_jms_topic_override_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_time_to_deliver<a name='wls_jms_topic_override_time_to_deliver'>

The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. The default value (<tt>-1</tt>) specifies that the destination will not override the TimeToDeliver setting specified by the producer and/or connection factory. The TimeToDeliver override can be specified either as a long or as a schedule.  Note: Changing the TimeToDeliver override only affects future message delivery, it does not affect message delivery of already produced messages.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_time_to_deliver => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_time_to_deliver']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### override_time_to_live<a name='wls_jms_topic_override_time_to_live'>

The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer. The default value (<tt>-1</tt>) specifies that this setting will not override the TimeToLive setting specified by the message producer.  Range of Values: Between 0 and a positive 64-bit integer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       override_time_to_live => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:override_time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### production_paused_at_startup<a name='wls_jms_topic_production_paused_at_startup'>

Specifies whether new message production is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Production Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Production Paused is explicitly disabled for this destination.</li>  <li>true Production Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       production_paused_at_startup => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:production_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### productionpaused<a name='wls_jms_topic_productionpaused'>



Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_topic](#attributes)

### provider<a name='wls_jms_topic_provider'>

The specific backend to use for this `wls_jms_topic`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a topic in a JMS module of an WebLogic domain via regular WLST



[Back to overview of wls_jms_topic](#attributes)

### quota<a name='wls_jms_topic_quota'>

Ths name of the quota for the jms object.



[Back to overview of wls_jms_topic](#attributes)

### redeliverydelay<a name='wls_jms_topic_redeliverydelay'>

redeliverydelay of the topic



[Back to overview of wls_jms_topic](#attributes)

### redeliverylimit<a name='wls_jms_topic_redeliverylimit'>

redeliverylimit of the topic



[Back to overview of wls_jms_topic](#attributes)

### saf_export_policy<a name='wls_jms_topic_saf_export_policy'>

Specifies whether a user can send messages to a destination using Store-and-Forward.  <ul> <li>All All users can send messages to this destination using Store-and-Forward.</li>  <li>None Remote users can not send messages to a destination using Store-and-Forward.</li> </ul>  This attribute is dynamically configurable. A dynamic change of this attribute will affect only messages sent after the update has been made.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       saf_export_policy => 'All'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:saf_export_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### sub_deployment_name<a name='wls_jms_topic_sub_deployment_name'>

Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.  The targets of the sub-deployment will be the targets of this entity.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       sub_deployment_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:sub_deployment_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### subdeployment<a name='wls_jms_topic_subdeployment'>

The subdeployment name.



[Back to overview of wls_jms_topic](#attributes)

### template<a name='wls_jms_topic_template'>

The JMS template from which the destination is derived. A template provides an efficient means of defining multiple destinations with similar configuration values.  If a JMS template is specified, destination parameters that are set to their default values will instead inherit their values from the JMS template at run-time. However, if a JMS template is not defined, then the configuration values for the destination must be specified as part of the destination.  Although you can dynamically modify the configuration of a JMS template, the configuration values on a destination are static.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       template => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:template']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### templatename<a name='wls_jms_topic_templatename'>

The template name



[Back to overview of wls_jms_topic](#attributes)

### thresholds_bytes_high<a name='wls_jms_topic_thresholds_bytes_high'>

The upper threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;BytesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       thresholds_bytes_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:thresholds_bytes_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### thresholds_bytes_low<a name='wls_jms_topic_thresholds_bytes_low'>

The lower threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; BytesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected. <!--Gets the "bytes-low" element-->

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       thresholds_bytes_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:thresholds_bytes_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### thresholds_messages_high<a name='wls_jms_topic_thresholds_messages_high'>

The upper threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= MessagesMaximum; &gt;MessagesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       thresholds_messages_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:thresholds_messages_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### thresholds_messages_low<a name='wls_jms_topic_thresholds_messages_low'>

The lower threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; MessagesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       thresholds_messages_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:thresholds_messages_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### thresholds_template_bean<a name='wls_jms_topic_thresholds_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       thresholds_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:thresholds_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### timeout<a name='wls_jms_topic_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_jms_topic](#attributes)

### timetodeliver<a name='wls_jms_topic_timetodeliver'>

timetodeliver of the topic



[Back to overview of wls_jms_topic](#attributes)

### timetolive<a name='wls_jms_topic_timetolive'>

timetolive of the topic



[Back to overview of wls_jms_topic](#attributes)

### topic_name<a name='wls_jms_topic_topic_name'>

The topic name



[Back to overview of wls_jms_topic](#attributes)

### unit_of_order_routing<a name='wls_jms_topic_unit_of_order_routing'>

Determines how a distributed destination member is selected as the destination for a message that is part of a unit-of-order. Hash, indicates that a message producer computes the member destination from the <code>hashCode</code> of the unit-of-order. PathService indicates that the configured Path Service determines the member destination.  Unit-of-Order Routing can be set programmatically with WLProducer, or administratively on the connection factory or destination.   Unit of Order Routing is not dynamically configurable.

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       unit_of_order_routing => 'Hash'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:unit_of_order_routing']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)

### unit_of_work_handling_policy<a name='wls_jms_topic_unit_of_work_handling_policy'>

Specifies whether the Unit-of-Work (UOW) feature is enabled for this destination. A UOW is a set of messages that are processed as a single unit. <ul> <li> Pass-Through By default, this destination does not treat messages as part of a UOW.</li> <li> Single Message Delivery This value should only be selected if UOW consumers are receiving messages on this destination. When selected, UOW messages are formed into a list and are consumed as an <code>ObjectMessage</code> containing the list.</li> </ul>

An example on how to use this:

    wls_jms_topic {a_wls_jms_topic :
       ...
       unit_of_work_handling_policy => 'PassThrough'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_topic:unit_of_work_handling_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_topic](#attributes)
