---
title: wls jndi security policy
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage jndi security authorization policies in an WebLogic Security Realm.

Here is an example on how you should use this:

    wls_jndi_security_policy { 'domain/managed_server:javax.jms.TopicConnectionFactory:modify':
      ensure           => 'present',
      policyexpression => 'Role(Admin) | Role(Deployer)',
    }

This puppet snippit set's the security policy for `modify` operation of the the JNDI object
`javax.jms.TopicConnectionFactory` on server `managed_server` in the domain `domain`
to: `Role(Admin) | Role(Deployer)`.

## Attributes



Attribute Name                                                                   | Short Description                                                                         |
-------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[action](#wls_jndi_security_policy_action)                                       | The kind of action you want to manage with this security policy.                          |
[authorizationprovider](#wls_jndi_security_policy_authorizationprovider)         | The security authorization providers of the domain
                                       |
[disable_corrective_change](#wls_jndi_security_policy_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_jndi_security_policy_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_jndi_security_policy_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_jndi_security_policy_ensure)                                       | The basic property that the resource should be in.                                        |
[jndi_name](#wls_jndi_security_policy_jndi_name)                                 | The JNDI name of the resource
                                                            |
[name](#wls_jndi_security_policy_name)                                           | The name.                                                                                 |
[policyexpression](#wls_jndi_security_policy_policyexpression)                   | A string representation of an security authorization policy
                              |
[provider](#wls_jndi_security_policy_provider)                                   | resource.                                                                                 |
[server_name](#wls_jndi_security_policy_server_name)                             | The server name where the JNDI tree is hosted
                                            |
[timeout](#wls_jndi_security_policy_timeout)                                     | Timeout for applying a resource.                                                          |




### action<a name='wls_jndi_security_policy_action'>

The kind of action you want to manage with this security policy.

This is the last part of the title of the resource. Here is an example:

    wls_jndi_security_policy{'domain/server:javax.erb.com:lookup'
      ...
    }

In this example `lookup` is the action. So this is a policy that says something
about the rights you need to do do a jndi lookup on `javax.erb.com`.

Valid values are `all`, `lookup`, `modify`, `list`. 

[Back to overview of wls_jndi_security_policy](#attributes)

### authorizationprovider<a name='wls_jndi_security_policy_authorizationprovider'>

The security authorization providers of the domain



[Back to overview of wls_jndi_security_policy](#attributes)

### disable_corrective_change<a name='wls_jndi_security_policy_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_jndi_security_policy](#attributes)

### disable_corrective_ensure<a name='wls_jndi_security_policy_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_jndi_security_policy](#attributes)

### domain<a name='wls_jndi_security_policy_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_jndi_security_policy](#attributes)

### ensure<a name='wls_jndi_security_policy_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_jndi_security_policy](#attributes)

### jndi_name<a name='wls_jndi_security_policy_jndi_name'>

The JNDI name of the resource



[Back to overview of wls_jndi_security_policy](#attributes)

### name<a name='wls_jndi_security_policy_name'>

The name.



[Back to overview of wls_jndi_security_policy](#attributes)

### policyexpression<a name='wls_jndi_security_policy_policyexpression'>

A string representation of an security authorization policy



[Back to overview of wls_jndi_security_policy](#attributes)

### provider<a name='wls_jndi_security_policy_provider'>

The specific backend to use for this `wls_jndi_security_policy`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: 



[Back to overview of wls_jndi_security_policy](#attributes)

### server_name<a name='wls_jndi_security_policy_server_name'>

The server name where the JNDI tree is hosted



[Back to overview of wls_jndi_security_policy](#attributes)

### timeout<a name='wls_jndi_security_policy_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_jndi_security_policy](#attributes)
