---
title: wls path service
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage path servers

Here is an example on how you should use this:

    wls_path_service { 'jmy_service':
      ensure              => 'present',
      target              => ['MyCluster'],
      targettype          => ['Cluster'],
      persistentstore     => 'mystore',
      persistentstoretype => 'JDBCStore',
    }

## Attributes



Attribute Name                                                           | Short Description                                                                         |
------------------------------------------------------------------------ | ----------------------------------------------------------------------------------------- |
[disable_corrective_change](#wls_path_service_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_path_service_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_path_service_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_path_service_ensure)                                       | The basic property that the resource should be in.                                        |
[name](#wls_path_service_name)                                           | The name.                                                                                 |
[path_service_name](#wls_path_service_path_service_name)                 | The name of the path service.                                                             |
[persistentstore](#wls_path_service_persistentstore)                     | The persistentstore name.                                                                 |
[persistentstoretype](#wls_path_service_persistentstoretype)             | The persistentstore type
                                                                 |
[provider](#wls_path_service_provider)                                   | resource.                                                                                 |
[target](#wls_path_service_target)                                       | An array of target names.                                                                 |
[targettype](#wls_path_service_targettype)                               | An array of target types.                                                                 |




### disable_corrective_change<a name='wls_path_service_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_path_service](#attributes)

### disable_corrective_ensure<a name='wls_path_service_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_path_service](#attributes)

### domain<a name='wls_path_service_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_path_service](#attributes)

### ensure<a name='wls_path_service_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_path_service](#attributes)

### name<a name='wls_path_service_name'>

The name.



[Back to overview of wls_path_service](#attributes)

### path_service_name<a name='wls_path_service_path_service_name'>

The name of the path service.



[Back to overview of wls_path_service](#attributes)

### persistentstore<a name='wls_path_service_persistentstore'>

The persistentstore name.



[Back to overview of wls_path_service](#attributes)

### persistentstoretype<a name='wls_path_service_persistentstoretype'>

The persistentstore type

Valid values are `FileStore`, `JDBCStore`. 

[Back to overview of wls_path_service](#attributes)

### provider<a name='wls_path_service_provider'>

The specific backend to use for this `wls_path_service`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a Path Service in an WebLogic domain via regular WLST



[Back to overview of wls_path_service](#attributes)

### target<a name='wls_path_service_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_path_service](#attributes)

### targettype<a name='wls_path_service_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_path_service](#attributes)
