---
title: wls resource group template
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage resource group template in an WebLogic 12.2.1 domain.

## Attributes



Attribute Name                                                                            | Short Description                                                                                                            |
----------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------- |
[disable_corrective_change](#wls_resource_group_template_disable_corrective_change)       | Disable the modification of a resource when Puppet decides it is a corrective change.                                        |
[disable_corrective_ensure](#wls_resource_group_template_disable_corrective_ensure)       | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                    |
[domain](#wls_resource_group_template_domain)                                             | With this parameter, you identify the domain, where your objects is in.                                                      |
[ensure](#wls_resource_group_template_ensure)                                             | The basic property that the resource should be in.                                                                           |
[name](#wls_resource_group_template_name)                                                 | The name.                                                                                                                    |
[notes](#wls_resource_group_template_notes)                                               | Optional information that you can include to describe this configuration.                                                    |
[provider](#wls_resource_group_template_provider)                                         | resource.                                                                                                                    |
[resource_group_template_name](#wls_resource_group_template_resource_group_template_name) | The resource group template name.                                                                                            |
[tags](#wls_resource_group_template_tags)                                                 | Return all tags on this Configuration MBean
                                                                                 |
[timeout](#wls_resource_group_template_timeout)                                           | Timeout for applying a resource.                                                                                             |
[upload_directory_name](#wls_resource_group_template_upload_directory_name)               | The directory path on the Administration Server where the uploaded applications for this resource group template are placed. |




### disable_corrective_change<a name='wls_resource_group_template_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_resource_group_template](#attributes)

### disable_corrective_ensure<a name='wls_resource_group_template_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_resource_group_template](#attributes)

### domain<a name='wls_resource_group_template_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_resource_group_template](#attributes)

### ensure<a name='wls_resource_group_template_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_resource_group_template](#attributes)

### name<a name='wls_resource_group_template_name'>

The name.



[Back to overview of wls_resource_group_template](#attributes)

### notes<a name='wls_resource_group_template_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_resource_group_template {a_wls_resource_group_template :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_resource_group_template:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_resource_group_template](#attributes)

### provider<a name='wls_resource_group_template_provider'>

The specific backend to use for this `wls_resource_group_template`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: 



[Back to overview of wls_resource_group_template](#attributes)

### resource_group_template_name<a name='wls_resource_group_template_resource_group_template_name'>

The resource group template name.



[Back to overview of wls_resource_group_template](#attributes)

### tags<a name='wls_resource_group_template_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_resource_group_template {a_wls_resource_group_template :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_resource_group_template:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_resource_group_template](#attributes)

### timeout<a name='wls_resource_group_template_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_resource_group_template](#attributes)

### upload_directory_name<a name='wls_resource_group_template_upload_directory_name'>

The directory path on the Administration Server where the uploaded applications for this resource group template are placed.

An example on how to use this:

    wls_resource_group_template {a_wls_resource_group_template :
       ...
       upload_directory_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_resource_group_template:upload_directory_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_resource_group_template](#attributes)
