---
title: wls saf error handler
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a SAF Error Handler in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_saf_error_handler { 'jmsClusterModule:ErrorHandling-0':
      ensure => 'present',
      policy => 'Discard',
    }

In this example you are managing a SAF error handler in the default domain. When you want to
manage a SAF error handler in a specific domain, you can use:

    wls_saf_error_handler { 'my_domain/jmsClusterModule:ErrorHandling-1':
      ensure    => 'present',
      logformat => '%header%%properties%',
      policy    => 'Log',
    }

## Attributes



Attribute Name                                                                | Short Description                                                                         |
----------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[disable_corrective_change](#wls_saf_error_handler_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_saf_error_handler_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_saf_error_handler_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_saf_error_handler_ensure)                                       | The basic property that the resource should be in.                                        |
[error_handler_name](#wls_saf_error_handler_error_handler_name)               | SAF error handler name
                                                                   |
[jmsmodule](#wls_saf_error_handler_jmsmodule)                                 | The JMS module name.                                                                      |
[log_format](#wls_saf_error_handler_log_format)                               | Specifies how information is logged when <code>Policy</code> is set to <code>Log</code>.  |
[logformat](#wls_saf_error_handler_logformat)                                 | logformat of the SAF imported destination
                                                |
[name](#wls_saf_error_handler_name)                                           | The name.                                                                                 |
[notes](#wls_saf_error_handler_notes)                                         | Optional information that you can include to describe this named JMS descriptor bean.     |
[policy](#wls_saf_error_handler_policy)                                       | policy of the SAF imported destination
                                                   |
[provider](#wls_saf_error_handler_provider)                                   | resource.                                                                                 |
[saf_error_destination](#wls_saf_error_handler_saf_error_destination)         | Specifies the error destination when <code>Policy</code> is set to <code>Redirect</code>. |
[timeout](#wls_saf_error_handler_timeout)                                     | Timeout for applying a resource.                                                          |




### disable_corrective_change<a name='wls_saf_error_handler_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_saf_error_handler](#attributes)

### disable_corrective_ensure<a name='wls_saf_error_handler_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_saf_error_handler](#attributes)

### domain<a name='wls_saf_error_handler_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_saf_error_handler](#attributes)

### ensure<a name='wls_saf_error_handler_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_saf_error_handler](#attributes)

### error_handler_name<a name='wls_saf_error_handler_error_handler_name'>

SAF error handler name



[Back to overview of wls_saf_error_handler](#attributes)

### jmsmodule<a name='wls_saf_error_handler_jmsmodule'>

The JMS module name.



[Back to overview of wls_saf_error_handler](#attributes)

### log_format<a name='wls_saf_error_handler_log_format'>

Specifies how information is logged when <code>Policy</code> is set to <code>Log</code>.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_error_handler {a_wls_saf_error_handler :
       ...
       log_format => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_error_handler:log_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_error_handler](#attributes)

### logformat<a name='wls_saf_error_handler_logformat'>

logformat of the SAF imported destination



[Back to overview of wls_saf_error_handler](#attributes)

### name<a name='wls_saf_error_handler_name'>

The name.



[Back to overview of wls_saf_error_handler](#attributes)

### notes<a name='wls_saf_error_handler_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_saf_error_handler {a_wls_saf_error_handler :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_error_handler:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_error_handler](#attributes)

### policy<a name='wls_saf_error_handler_policy'>

policy of the SAF imported destination

Valid values are `absent`, `Discard`, `Log`, `Redirect`, `Always-Forward`. 

[Back to overview of wls_saf_error_handler](#attributes)

### provider<a name='wls_saf_error_handler_provider'>

The specific backend to use for this `wls_saf_error_handler`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: saf error handler in a JMS module of an WebLogic domain via regular WLST



[Back to overview of wls_saf_error_handler](#attributes)

### saf_error_destination<a name='wls_saf_error_handler_saf_error_destination'>

Specifies the error destination when <code>Policy</code> is set to <code>Redirect</code>.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_error_handler {a_wls_saf_error_handler :
       ...
       saf_error_destination => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_error_handler:saf_error_destination']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_error_handler](#attributes)

### timeout<a name='wls_saf_error_handler_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_saf_error_handler](#attributes)
