---
title: wls security realm
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage an existing security realm.

Here is an example on how you can do this:
    wls_security_realm { 'my_domain/myrealm':
      ensure                                      => 'absent',
      auto_restart_on_non_dynamic_changes         => 0,
      combined_role_mapping_enabled               => 1,
      delegate_mbean_authorization                => 1,
      deployable_provider_synchronization_enabled => 0,
      deployable_provider_synchronization_timeout => 60000,
      fully_delegate_authorization                => 0,
      retire_timeout_seconds                      => 60,
      security_dd_model                           => 'DDOnly',
    }

At this point in type Puppet doesn't support creating a new security realm or
removing an existing realm.

## Attributes



Attribute Name                                                                                                 | Short Description                                                                                                                                                                                            |
-------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[adjudicator_types](#wls_security_realm_adjudicator_types)                                                     | Returns the types of Adjudication providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultAdjudicator</code>.                              |
[auditor_types](#wls_security_realm_auditor_types)                                                             | Returns the types of Auditing providers that may be created in this security realm, for example, <code>weblogic.security.providers.audit.DefaultAuditor</code>.                                              |
[auth_methods](#wls_security_realm_auth_methods)                                                               | Returns a comma separated string of authentication methods that should be used when the Web application specifies "REALM" as its auth-method.                                                                |
[authentication_provider_types](#wls_security_realm_authentication_provider_types)                             | Returns the types of Authentication providers that may be created in this security realm, for example, <code>weblogic.security.providers.authentication.DefaultAuthenticator</code>.                         |
[authorizer_types](#wls_security_realm_authorizer_types)                                                       | Returns the types of Authorization providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultAuthorizer</code>.                              |
[auto_restart_on_non_dynamic_changes](#wls_security_realm_auto_restart_on_non_dynamic_changes)                 | Specifies whether the Realm will be auto-restarted if non-dynamic changes are made to the realm or providers within the realm.                                                                               |
[cert_path_provider_types](#wls_security_realm_cert_path_provider_types)                                       | Returns the types of Certification Path providers that may be created in this security realm, for example, <code>weblogic.security.providers.pk.WebLogicCertPathProvider</code>.                             |
[combined_role_mapping_enabled](#wls_security_realm_combined_role_mapping_enabled)                             | Determines how the role mappings in the Enterprise Application, Web application, and EJB containers interact.                                                                                                |
[credential_mapper_types](#wls_security_realm_credential_mapper_types)                                         | Returns the types of Credential Mapping providers that may be created in this security realm, for example, <code>weblogic.security.providers.credentials.DefaultCredentialMapper</code>.                     |
[default_realm](#wls_security_realm_default_realm)                                                             | Returns whether this security realm is the Default realm for the WebLogic domain.                                                                                                                            |
[delegate_mbean_authorization](#wls_security_realm_delegate_mbean_authorization)                               | Configures the WebLogic Server MBean servers to use the security realm's Authorization providers to determine whether a JMX client has permission to access an MBean attribute or invoke an MBean operation. |
[deploy_credential_mapping_ignored](#wls_security_realm_deploy_credential_mapping_ignored)                     | Returns whether credential mapping deployment calls on the security system are ignored or passed to the configured Credential Mapping providers.                                                             |
[deploy_policy_ignored](#wls_security_realm_deploy_policy_ignored)                                             | Returns whether policy deployment calls on the security system are ignored or passed to the configured Authorization providers.                                                                              |
[deploy_role_ignored](#wls_security_realm_deploy_role_ignored)                                                 | Returns whether role deployment calls on the security system are ignored or passed to the configured Role Mapping providers.                                                                                 |
[deployable_provider_synchronization_enabled](#wls_security_realm_deployable_provider_synchronization_enabled) | Specifies whether synchronization for deployable Authorization and Role Mapping providers is enabled.                                                                                                        |
[deployable_provider_synchronization_timeout](#wls_security_realm_deployable_provider_synchronization_timeout) | Returns the timeout value, in milliseconds, for the deployable security provider synchronization operation.                                                                                                  |
[disable_corrective_change](#wls_security_realm_disable_corrective_change)                                     | Disable the modification of a resource when Puppet decides it is a corrective change.                                                                                                                        |
[disable_corrective_ensure](#wls_security_realm_disable_corrective_ensure)                                     | Disable the creation or removal of a resource when Puppet decides is a corrective change.                                                                                                                    |
[domain](#wls_security_realm_domain)                                                                           | With this parameter, you identify the domain, where your objects is in.                                                                                                                                      |
[enable_web_logic_principal_validator_cache](#wls_security_realm_enable_web_logic_principal_validator_cache)   | Returns whether the WebLogic Principal Validator caching is enabled.                                                                                                                                         |
[ensure](#wls_security_realm_ensure)                                                                           | The basic property that the resource should be in.                                                                                                                                                           |
[fully_delegate_authorization](#wls_security_realm_fully_delegate_authorization)                               | Returns whether the Web and EJB containers should call the security framework on every access.                                                                                                               |
[identity_assertion_header_name_precedence](#wls_security_realm_identity_assertion_header_name_precedence)     | Obtain an ordered list of token type names used for Identity Assertion with HTTP request headers.                                                                                                            |
[management_identity_domain](#wls_security_realm_management_identity_domain)                                   | Sets the Management Identity Domain value for the realm.                                                                                                                                                     |
[max_web_logic_principals_in_cache](#wls_security_realm_max_web_logic_principals_in_cache)                     | Returns the maximum size of the LRU cache for holding WebLogic Principal signatures.                                                                                                                         |
[name](#wls_security_realm_name)                                                                               | The name.                                                                                                                                                                                                    |
[password_validator_types](#wls_security_realm_password_validator_types)                                       | Returns the types of Password Validator providers that may be created in this security realm, for example, <code>com.bea.security.providers.authentication.passwordvalidator.SystemPasswordValidator</code>. |
[provider](#wls_security_realm_provider)                                                                       | resource.                                                                                                                                                                                                    |
[rdbms_security_store](#wls_security_realm_rdbms_security_store)                                               | Returns RDBMSSecurityStoreMBean for this realm, which is a singleton MBean describing RDBMS security store configuration.                                                                                    |
[realm_name](#wls_security_realm_realm_name)                                                                   | The realm name
                                                                                                                                                                                              |
[retire_timeout_seconds](#wls_security_realm_retire_timeout_seconds)                                           | Specifies the retire timeout for a realm that is restarted.                                                                                                                                                  |
[role_mapper_types](#wls_security_realm_role_mapper_types)                                                     | Returns the types of Role Mapping providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultRoleMapper</code>.                               |
[security_dd_model](#wls_security_realm_security_dd_model)                                                     | Specifies the default security model for Web applications or EJBs that are secured by this security realm.                                                                                                   |
[timeout](#wls_security_realm_timeout)                                                                         | Timeout for applying a resource.                                                                                                                                                                             |
[validate_dd_security_data](#wls_security_realm_validate_dd_security_data)                                     | Not used in this release.                                                                                                                                                                                    |




### adjudicator_types<a name='wls_security_realm_adjudicator_types'>

Returns the types of Adjudication providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultAdjudicator</code>. Use this method to find the available types to pass to <code>createAdjudicator</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       adjudicator_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:adjudicator_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### auditor_types<a name='wls_security_realm_auditor_types'>

Returns the types of Auditing providers that may be created in this security realm, for example, <code>weblogic.security.providers.audit.DefaultAuditor</code>. Use this method to find the available types to pass to <code>createAuditor</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       auditor_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:auditor_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### auth_methods<a name='wls_security_realm_auth_methods'>

Returns a comma separated string of authentication methods that should be used when the Web application specifies "REALM" as its auth-method. The authentication methods will be applied in order in which they appear in the list.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       auth_methods => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:auth_methods']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### authentication_provider_types<a name='wls_security_realm_authentication_provider_types'>

Returns the types of Authentication providers that may be created in this security realm, for example, <code>weblogic.security.providers.authentication.DefaultAuthenticator</code>. Use this method to find the available types to pass to <code>createAuthenticationProvider</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       authentication_provider_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:authentication_provider_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### authorizer_types<a name='wls_security_realm_authorizer_types'>

Returns the types of Authorization providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultAuthorizer</code>. Use this method to find the available types to pass to <code>createAuthorizer</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       authorizer_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:authorizer_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### auto_restart_on_non_dynamic_changes<a name='wls_security_realm_auto_restart_on_non_dynamic_changes'>

Specifies whether the Realm will be auto-restarted if non-dynamic changes are made to the realm or providers within the realm.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       auto_restart_on_non_dynamic_changes => 1
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### cert_path_provider_types<a name='wls_security_realm_cert_path_provider_types'>

Returns the types of Certification Path providers that may be created in this security realm, for example, <code>weblogic.security.providers.pk.WebLogicCertPathProvider</code>. Use this method to find the available types to pass to <code>createCertPathProvider</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       cert_path_provider_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:cert_path_provider_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### combined_role_mapping_enabled<a name='wls_security_realm_combined_role_mapping_enabled'>

Determines how the role mappings in the Enterprise Application, Web application, and EJB containers interact. This setting is valid only for Web applications and EJBs that use the Advanced security model and that initialize roles from deployment descriptors. When enabled:  <ul> <li>Application role mappings are combined with EJB and Web application mappings so that all principal mappings are included. The Security Service combines the role mappings with a logical <code>OR</code> operator.</li>  <li>If one or more policies in the <code>web.xml</code> file specify a role for which no mapping exists in the <code>weblogic.xml</code> file, the Web application container creates an empty map for the undefined role (that is, the role is explicitly defined as containing no principal). Therefore, no one can access URL patterns that are secured by such policies.</li>  <li>If one or more policies in the <code>ejb-jar.xml</code> file specify a role for which no mapping exists in the <code>weblogic-ejb-jar.xml</code> file, the EJB container creates an empty map for the undefined role (that is, the role is explicitly defined as containing no principal). Therefore, no one can access methods that are secured by such policies.</li> </ul>  When disabled:  <ul> <li>Role mappings for each container are exclusive to other containers unless defined by the <code>&lt;externally-defined&gt;</code> descriptor element.</li>  <li>If one or more policies in the <code>web.xml</code> file specify a role for which no role mapping exists in the <code>weblogic.xml</code> file, the Web application container assumes that the undefined role is the name of a principal. It therefore maps the assumed principal to the role name. For example, if the <code>web.xml</code> file contains the following stanza in one of its policies:  <code>&lt;auth-constraint&gt;<br> &lt;role-name&gt;PrivilegedUser&lt;/role-name&gt;<br> &lt;/auth-constraint&gt;</code>  but, if the <code>weblogic.xml</code> file has no role mapping for <code>PrivilegedUser</code>, then the Web application container creates an in-memory mapping that is equivalent to the following stanza:  <code>&lt;security-role-assignment&gt;<br> &lt;role-name&gt;PrivilegedUser&lt;/role-name&gt;<br> &lt;principal-name&gt;PrivilegedUser&lt;/principal-name&gt;<br> &lt;/security-role-assignment&gt;</code> </li>  <li>Role mappings for EJB methods must be defined in the <code>weblogic-ejb-jar.xml</code> file. Role mappings defined in the other containers are not used unless defined by the <code>&lt;externally-defined&gt;</code> descriptor element.</li> </ul>  <dl> <dt>Note:</dt>  <dd>For all applications previously deployed in version 8.1 and upgraded to version 9.x, the combining role mapping is disabled by default.</dd> </dl>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       combined_role_mapping_enabled => '1'
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### credential_mapper_types<a name='wls_security_realm_credential_mapper_types'>

Returns the types of Credential Mapping providers that may be created in this security realm, for example, <code>weblogic.security.providers.credentials.DefaultCredentialMapper</code>. Use this method to find the available types to pass to <code>createCredentialMapper</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       credential_mapper_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:credential_mapper_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### default_realm<a name='wls_security_realm_default_realm'>

Returns whether this security realm is the Default realm for the WebLogic domain. Deprecated in this release of WebLogic Server and replaced by <code>weblogic.management.configuration.SecurityConfigurationMBean.getDefaultRealm</code>.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       default_realm => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:default_realm']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### delegate_mbean_authorization<a name='wls_security_realm_delegate_mbean_authorization'>

Configures the WebLogic Server MBean servers to use the security realm's Authorization providers to determine whether a JMX client has permission to access an MBean attribute or invoke an MBean operation. You can continue to use WebLogic Server's default security settings or modify the defaults to suit your needs. If you do not delegate authorization to the realm's Authorization providers, the WebLogic MBean servers allow access only to the four default security roles (Admin, Deployer, Operator, and Monitor) and only as specified by WebLogic Server's default security settings.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       delegate_mbean_authorization => 1,
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### deploy_credential_mapping_ignored<a name='wls_security_realm_deploy_credential_mapping_ignored'>

Returns whether credential mapping deployment calls on the security system are ignored or passed to the configured Credential Mapping providers.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       deploy_credential_mapping_ignored => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:deploy_credential_mapping_ignored']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### deploy_policy_ignored<a name='wls_security_realm_deploy_policy_ignored'>

Returns whether policy deployment calls on the security system are ignored or passed to the configured Authorization providers.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       deploy_policy_ignored => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:deploy_policy_ignored']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### deploy_role_ignored<a name='wls_security_realm_deploy_role_ignored'>

Returns whether role deployment calls on the security system are ignored or passed to the configured Role Mapping providers.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       deploy_role_ignored => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:deploy_role_ignored']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### deployable_provider_synchronization_enabled<a name='wls_security_realm_deployable_provider_synchronization_enabled'>

Specifies whether synchronization for deployable Authorization and Role Mapping providers is enabled.  The Authorization and Role Mapping providers may or may not support parallel security policy and role modification, respectively, in the security provider database. If the security providers do not support parallel modification, the WebLogic Security Framework enforces a synchronization mechanism that results in each application and module being placed in a queue and deployed sequentially.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       deployable_provider_synchronization_enabled => 1,
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### deployable_provider_synchronization_timeout<a name='wls_security_realm_deployable_provider_synchronization_timeout'>

Returns the timeout value, in milliseconds, for the deployable security provider synchronization operation. This value is only used if <code>DeployableProviderSynchronizationEnabled</code> is set to <code>true</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       deployable_provider_synchronization_timeout => 60000,
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### disable_corrective_change<a name='wls_security_realm_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_security_realm](#attributes)

### disable_corrective_ensure<a name='wls_security_realm_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_security_realm](#attributes)

### domain<a name='wls_security_realm_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_security_realm](#attributes)

### enable_web_logic_principal_validator_cache<a name='wls_security_realm_enable_web_logic_principal_validator_cache'>

Returns whether the WebLogic Principal Validator caching is enabled.  The Principal Validator is used by Oracle supplied authentication providers and may be used by custom authentication providers. If enabled, the default principal validator will cache WebLogic Principal signatures.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       enable_web_logic_principal_validator_cache => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:enable_web_logic_principal_validator_cache']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### ensure<a name='wls_security_realm_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_security_realm](#attributes)

### fully_delegate_authorization<a name='wls_security_realm_fully_delegate_authorization'>

Returns whether the Web and EJB containers should call the security framework on every access.  If false the containers are free to only call the security framework when security is set in the deployment descriptors.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       fully_delegate_authorization => 1,
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)

### identity_assertion_header_name_precedence<a name='wls_security_realm_identity_assertion_header_name_precedence'>

Obtain an ordered list of token type names used for Identity Assertion with HTTP request headers.  The list determines the precedence order when multiple HTTP headers are present in an HTTP request based on the list of active token types maintained on the configured Authentication providers.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       identity_assertion_header_name_precedence => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:identity_assertion_header_name_precedence']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### management_identity_domain<a name='wls_security_realm_management_identity_domain'>

Sets the Management Identity Domain value for the realm.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       management_identity_domain => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### max_web_logic_principals_in_cache<a name='wls_security_realm_max_web_logic_principals_in_cache'>

Returns the maximum size of the LRU cache for holding WebLogic Principal signatures. This value is only used if <code>EnableWebLogicPrincipalValidatorCache</code> is set to <code>true</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       max_web_logic_principals_in_cache => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:max_web_logic_principals_in_cache']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### name<a name='wls_security_realm_name'>

The name.



[Back to overview of wls_security_realm](#attributes)

### password_validator_types<a name='wls_security_realm_password_validator_types'>

Returns the types of Password Validator providers that may be created in this security realm, for example, <code>com.bea.security.providers.authentication.passwordvalidator.SystemPasswordValidator</code>. Use this method to find the available types to pass to <code>createPasswordValidator</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       password_validator_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:password_validator_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### provider<a name='wls_security_realm_provider'>

The specific backend to use for this `wls_security_realm`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage security Realms in an WebLogic domain via regular WLST



[Back to overview of wls_security_realm](#attributes)

### rdbms_security_store<a name='wls_security_realm_rdbms_security_store'>

Returns RDBMSSecurityStoreMBean for this realm, which is a singleton MBean describing RDBMS security store configuration.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       rdbms_security_store => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:rdbms_security_store']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### realm_name<a name='wls_security_realm_realm_name'>

The realm name



[Back to overview of wls_security_realm](#attributes)

### retire_timeout_seconds<a name='wls_security_realm_retire_timeout_seconds'>

Specifies the retire timeout for a realm that is restarted. The old realm will be shutdown after the specified timeout period has elapsed.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       retire_timeout_seconds => 60,
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### role_mapper_types<a name='wls_security_realm_role_mapper_types'>

Returns the types of Role Mapping providers that may be created in this security realm, for example, <code>weblogic.security.providers.authorization.DefaultRoleMapper</code>. Use this method to find the available types to pass to <code>createRoleMapper</code>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       role_mapper_types => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:role_mapper_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_security_realm](#attributes)

### security_dd_model<a name='wls_security_realm_security_dd_model'>

Specifies the default security model for Web applications or EJBs that are secured by this security realm. You can override this default during deployment.  Note: If you deploy a module by modifying the domain's <code>config.xml</code> file and restarting the server, and if you do not specify a security model value for the module in <code>config.xml</code>, the module is secured with the default value of the <code>AppDeploymentMBean SecurityDDModel</code>  attribute (see {@link weblogic.management.configuration.AppDeploymentMBean#getSecurityDDModel() getSecurityDDModel}).  Choose one of these security models: <ul> <li><code>Deployment Descriptors Only (DDOnly)</code> <ul> <li>For EJBs and URL patterns, this model uses only the roles and policies in the J2EE deployment descriptors (DD); the Administration Console allows only read access for this data. With this model, EJBs and URL patterns are not protected by roles and policies of a broader scope (such as a policy scoped to an entire Web application). If an EJB or URL pattern is not protected by a role or policy in the DD, then it is unprotected: anyone can access it. </li>  <li>For application-scoped roles in an EAR, this model uses only the roles defined in the WebLogic Server DD; the Administration Console allows only read access for this data. If the WebLogic Server DD does not define roles, then there will be no such scoped roles defined for this EAR.</li>  <li>For all other types of resources, you can use the Administration Console to create roles or policies. For example, with this model, you can use the Administration Console to create application-scoped policies for an EAR.</li>   <li>Applies for the life of the deployment. If you want to use a different model, you must delete the deployment and reinstall it.</li> </ul> </li>  <li><code>Customize Roles Only (CustomRoles)</code> <ul> <li>For EJBs and URL patterns, this model uses only the policies in the J2EE deployment descriptors (DD). EJBs and URL patterns are not protected by policies of a broader scope (such as a policy scoped to an entire Web application). This model ignores any roles defined in the DDs; an administrator completes the role mappings using the Administration Console.</li>  <li>For all other types of resources, you can use the Administration Console to create roles or policies. For example, with this model, you can use the Administration Console to create application-scoped policies or roles for an EAR.</li>  <li>Applies for the life of the deployment. If you want to use a different model, you must delete the deployment and reinstall it.</li> </ul> </li>  <li><code>Customize Roles and Policies (CustomRolesAndPolicies)</code> <ul> <li>Ignores any roles and policies defined in deployment descriptors. An administrator uses the Administration Console to secure the resources.</li>  <li>Performs security checks for all URLs or EJB methods in the module.</li>  <li>Applies for the life of the deployment. If you want to use a different model, you must delete the deployment and reinstall it.</li> </ul> </li>  <li><code>Advanced (Advanced)</code> You configure how this model behaves by setting values for the following options: <ul> <li><code>When Deploying Web Applications or EJBs</code> Note: When using the WebLogic Scripting Tool or JMX APIs, there is no single MBean attribute for this setting. Instead, you must set the values for the <code>DeployPolicyIgnored</code> and <code>DeployRoleIgnored</code> attributes of <code>RealmMBean</code>. </li>  <li><code>Check Roles and Policies (FullyDelegateAuthorization)</code></li>  <li><code>Combined Role Mapping Enabled (CombinedRoleMappingEnabled)</code></li> </ul> You can change the configuration of this model. Any changes immediately apply to all modules that use the Advanced model. For example, you can specify that all modules using this model will copy roles and policies from their deployment descriptors into the appropriate provider databases upon deployment. After you deploy all of your modules, you can change this behavior to ignore roles and policies in deployment descriptors so that when you redeploy modules they will not re-copy roles and policies.  Note: Prior to WebLogic Server version 9.0 the Advanced model was the only security model available. Use this model if you want to continue to secure EJBs and Web Applications as in releases prior to 9.0. </li> </ul>

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       security_dd_model => 'DDOnly'
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `DDOnly`, `CustomRoles`, `CustomRolesAndPolicies`, `Advanced`. 

[Back to overview of wls_security_realm](#attributes)

### timeout<a name='wls_security_realm_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_security_realm](#attributes)

### validate_dd_security_data<a name='wls_security_realm_validate_dd_security_data'>

Not used in this release.

An example on how to use this:

    wls_security_realm {a_wls_security_realm :
       ...
       validate_dd_security_data => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_security_realm:validate_dd_security_data']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_security_realm](#attributes)
