---
title: wls setting
keywords: documentation
layout: documentation
sidebar: _sidebar
toc: false
---
## Overview

This resource allows you to set the defaults for all other wls types.


All wls types needs a `wls_setting` definition. This is a pointer to an WebLogic AdminServer and
you need to create one for every WebLogic domain. When you don't provide a `wls_setting` identifier
in the title of the weblogic type then it will use `default` as identifier.

Here is an example on how to create the `default` settings:

    wls_setting { 'default':
      user               => 'oracle',
      weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
      connect_url        => "t3://localhost:7001",
      weblogic_user      => 'weblogic',
      weblogic_password  => 'weblogic1',
    }

When you want to create an other domain, like for instance `domain2`. You use `wls_setting like this:

    wls_setting { 'domain2':
      user               => 'oracle',
      weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
      connect_url        => "t3://localhost:7011",
      weblogic_user      => 'weblogic',
      weblogic_password  => 'weblogic1',
      post_classpath     => '/opt/oracle/wlsdomains/domains/Wls1036/lib/aa.jar',
      extra_properties   => ['wls_server:.*'],
    }

## Attributes



Attribute Name                                                      | Short Description                                                                         |
------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[archive_path](#wls_setting_archive_path)                           | the archive path for WLST scripts we want to keep
                                        |
[connect_url](#wls_setting_connect_url)                             | The url to connect to
                                                                    |
[custom_trust](#wls_setting_custom_trust)                           | The custom trust enabled
                                                                 |
[debug_module](#wls_setting_debug_module)                           | Toggles retaining of WLST Python scripts
                                                 |
[disable_corrective_change](#wls_setting_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_setting_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[extra_properties](#wls_setting_extra_properties)                   | The extra properties to use.                                                              |
[name](#wls_setting_name)                                           | The name of the setting
                                                                  |
[post_classpath](#wls_setting_post_classpath)                       | the post classpath
                                                                       |
[provider](#wls_setting_provider)                                   | resource.                                                                                 |
[trust_keystore_file](#wls_setting_trust_keystore_file)             | The trust keystore file
                                                                  |
[trust_keystore_passphrase](#wls_setting_trust_keystore_passphrase) | The trust keystore passphrase
                                                            |
[user](#wls_setting_user)                                           | Operating System user
                                                                    |
[weblogic_home_dir](#wls_setting_weblogic_home_dir)                 | The WLS homedir
                                                                          |
[weblogic_password](#wls_setting_weblogic_password)                 | weblogic password
                                                                        |
[weblogic_user](#wls_setting_weblogic_user)                         | the weblogic user account
                                                                |




### archive_path<a name='wls_setting_archive_path'>

the archive path for WLST scripts we want to keep



[Back to overview of wls_setting](#attributes)

### connect_url<a name='wls_setting_connect_url'>

The url to connect to



[Back to overview of wls_setting](#attributes)

### custom_trust<a name='wls_setting_custom_trust'>

The custom trust enabled

Valid values are `true`, `false`. 

[Back to overview of wls_setting](#attributes)

### debug_module<a name='wls_setting_debug_module'>

Toggles retaining of WLST Python scripts

Valid values are `true`, `false`. 

[Back to overview of wls_setting](#attributes)

### disable_corrective_change<a name='wls_setting_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_setting](#attributes)

### disable_corrective_ensure<a name='wls_setting_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_setting](#attributes)

### extra_properties<a name='wls_setting_extra_properties'>

The extra properties to use.

Besides all the properties of the WebLogic types that are always loaded, you can use a set of extra properties.
To enable these extra properties, you'll have to enabled them in de settings for this domain. You can do this
useing the `extra_properties` property of `wls_setting`.

This is an array of elements. Each element is a regular expression specifying one or more
types with attributes. An example:

  wls_setting {'default':
    ...
    extra_properties => [
      'wls_server:.*',      # Include all extra properties from wls_server
      'wls_domain:.*ssl.*', # include all extra properties containg the string ssl for type wls_domain
    ]
    ...
  }



[Back to overview of wls_setting](#attributes)

### name<a name='wls_setting_name'>

The name of the setting



[Back to overview of wls_setting](#attributes)

### post_classpath<a name='wls_setting_post_classpath'>

the post classpath



[Back to overview of wls_setting](#attributes)

### provider<a name='wls_setting_provider'>

The specific backend to use for this `wls_setting`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

yaml
: Manage wls settings through yaml file



[Back to overview of wls_setting](#attributes)

### trust_keystore_file<a name='wls_setting_trust_keystore_file'>

The trust keystore file



[Back to overview of wls_setting](#attributes)

### trust_keystore_passphrase<a name='wls_setting_trust_keystore_passphrase'>

The trust keystore passphrase



[Back to overview of wls_setting](#attributes)

### user<a name='wls_setting_user'>

Operating System user



[Back to overview of wls_setting](#attributes)

### weblogic_home_dir<a name='wls_setting_weblogic_home_dir'>

The WLS homedir



[Back to overview of wls_setting](#attributes)

### weblogic_password<a name='wls_setting_weblogic_password'>

weblogic password



[Back to overview of wls_setting](#attributes)

### weblogic_user<a name='wls_setting_weblogic_user'>

the weblogic user account



[Back to overview of wls_setting](#attributes)
