---
title: wls user
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage user in an WebLogic Security Realm.

Here is an example on how you should use this:

    wls_user { 'OracleSystemUser':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'Oracle application software system user.',
      realm                  => 'myrealm',
    }

In this example you are managing a user in the default domain. When you want to
manage a user in a specific domain, you can use:

    # this will use default as wls_setting identifier
    wls_user { 'my_domain/testuser1':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'testuser1',
      realm                  => 'myrealm',
    }

## Attributes



Attribute Name                                                   | Short Description                                                                         |
---------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[authenticationprovider](#wls_user_authenticationprovider)       | The security authentication providers of the domain.                                      |
[description](#wls_user_description)                             | The user description
                                                                     |
[disable_corrective_change](#wls_user_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_user_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_user_domain)                                       | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_user_ensure)                                       | The basic property that the resource should be in.                                        |
[name](#wls_user_name)                                           | The name.                                                                                 |
[password](#wls_user_password)                                   | The weblogic artifacts password.                                                          |
[provider](#wls_user_provider)                                   | resource.                                                                                 |
[realm](#wls_user_realm)                                         | The security realm of the domain
                                                         |
[timeout](#wls_user_timeout)                                     | Timeout for applying a resource.                                                          |
[user_name](#wls_user_user_name)                                 | The user name.                                                                            |




### authenticationprovider<a name='wls_user_authenticationprovider'>

The security authentication providers of the domain.



[Back to overview of wls_user](#attributes)

### description<a name='wls_user_description'>

The user description



[Back to overview of wls_user](#attributes)

### disable_corrective_change<a name='wls_user_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_user](#attributes)

### disable_corrective_ensure<a name='wls_user_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_user](#attributes)

### domain<a name='wls_user_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_user](#attributes)

### ensure<a name='wls_user_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_user](#attributes)

### name<a name='wls_user_name'>

The name.



[Back to overview of wls_user](#attributes)

### password<a name='wls_user_password'>

The weblogic artifacts password.



[Back to overview of wls_user](#attributes)

### provider<a name='wls_user_provider'>

The specific backend to use for this `wls_user`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage users of a WebLogic Security REALM



[Back to overview of wls_user](#attributes)

### realm<a name='wls_user_realm'>

The security realm of the domain



[Back to overview of wls_user](#attributes)

### timeout<a name='wls_user_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_user](#attributes)

### user_name<a name='wls_user_user_name'>

The user name.



[Back to overview of wls_user](#attributes)
