---
title: wls workmanager constraint
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage work manager constraints in an WebLogic domain.

Here is an example on how you should use this:

    wls_workmanager_constraint { 'CapacityConstraint':
      ensure          => 'present',
      constrainttype  => 'Capacity',
      constraintvalue => '20',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

In this example you are managing a work manager contraint in the default domain. When you want to
manage a work manager contraint in a specific domain, you can use:

    wls_workmanager_constraint { 'my_domain/MaxThreadsConstraint':
      ensure          => 'present',
      constrainttype  => 'MaxThreadsConstraint',
      constraintvalue => '5',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

Here are some more examples:

    wls_workmanager_constraint { 'MinThreadsConstraint':
      ensure          => 'present',
      constrainttype  => 'MinThreadsConstraint',
      constraintvalue => '2',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }
    wls_workmanager_constraint { 'FairShareReqClass':
      ensure          => 'present',
      constrainttype  => 'FairShareRequestClasses',
      constraintvalue => '50',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

## Attributes



Attribute Name                                                                         | Short Description                                                                         |
-------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[constrainttype](#wls_workmanager_constraint_constrainttype)                           | Workmanager constraint name
                                                              |
[constraintvalue](#wls_workmanager_constraint_constraintvalue)                         | The value of a workmanager constraint
                                                    |
[disable_corrective_change](#wls_workmanager_constraint_disable_corrective_change)     | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_workmanager_constraint_disable_corrective_ensure)     | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[domain](#wls_workmanager_constraint_domain)                                           | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_workmanager_constraint_ensure)                                           | The basic property that the resource should be in.                                        |
[name](#wls_workmanager_constraint_name)                                               | The name.                                                                                 |
[provider](#wls_workmanager_constraint_provider)                                       | resource.                                                                                 |
[target](#wls_workmanager_constraint_target)                                           | An array of target names.                                                                 |
[targettype](#wls_workmanager_constraint_targettype)                                   | An array of target types.                                                                 |
[timeout](#wls_workmanager_constraint_timeout)                                         | Timeout for applying a resource.                                                          |
[workmanager_constraint_name](#wls_workmanager_constraint_workmanager_constraint_name) | The workmanager constraint name
                                                          |




### constrainttype<a name='wls_workmanager_constraint_constrainttype'>

Workmanager constraint name

Valid values are `absent`, `MaxThreadsConstraint`, `MinThreadsConstraint`, `Capacity`, `FairShareRequestClass`, `ResponseTimeRequestClass`. 

[Back to overview of wls_workmanager_constraint](#attributes)

### constraintvalue<a name='wls_workmanager_constraint_constraintvalue'>

The value of a workmanager constraint



[Back to overview of wls_workmanager_constraint](#attributes)

### disable_corrective_change<a name='wls_workmanager_constraint_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_workmanager_constraint](#attributes)

### disable_corrective_ensure<a name='wls_workmanager_constraint_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_workmanager_constraint](#attributes)

### domain<a name='wls_workmanager_constraint_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_workmanager_constraint](#attributes)

### ensure<a name='wls_workmanager_constraint_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_workmanager_constraint](#attributes)

### name<a name='wls_workmanager_constraint_name'>

The name.



[Back to overview of wls_workmanager_constraint](#attributes)

### provider<a name='wls_workmanager_constraint_provider'>

The specific backend to use for this `wls_workmanager_constraint`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage workmanager constraint of a WebLogic domain



[Back to overview of wls_workmanager_constraint](#attributes)

### target<a name='wls_workmanager_constraint_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_workmanager_constraint](#attributes)

### targettype<a name='wls_workmanager_constraint_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_workmanager_constraint](#attributes)

### timeout<a name='wls_workmanager_constraint_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_workmanager_constraint](#attributes)

### workmanager_constraint_name<a name='wls_workmanager_constraint_workmanager_constraint_name'>

The workmanager constraint name



[Back to overview of wls_workmanager_constraint](#attributes)
