#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:domain_version, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Defines the common version of all servers in a domain. In a domain containing servers that are not all at the same release version, this attribute is used to determine the feature level that servers will assume.  The value must be less than or equal to the version of any managed server in the domain.  If this value is not equal to the version of the release version of the admin server, then the admin server will not be allowed to make modifications to the configuration. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         domain_version => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:domain_version']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DomainVersion')
end
