#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_managed_server_notifications_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies whether the WebLogic Server Domain Runtime MBean Server will support notifications from the federated Runtime MBean Servers on the managed and administration servers. Supporting notifications requires a significant amount of memory resources. A list of ObjectNames is maintained for each MBean from the Runtime MBean Servers. If notifications are not required for this domain, then disabling them will save on CPU and memory resources. This is particularly critical if there are large numbers of runtime MBeans and/or large numbers of servers. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_managed_server_notifications_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_managed_server_notifications_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JMX/%{domain_name}/ManagedServerNotificationsEnabled')
end
