#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_file_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The maximum file size, in bytes.

  - The <code>MaxFileSize</code> value affects the number of files needed to accommodate a store of a particular size (number of files = store size/MaxFileSize rounded up).
  - A file store automatically reuses space freed by deleted records and automatically expands individual files up to <code>MaxFileSize</code> if there is not enough space for a new record. If there is no space left in exiting files for a new record, a store creates an additional file.
  - A small number of larger files is normally preferred over a large number of smaller files as each file allocates Window Buffer and file handles.
  - If <code>MaxFileSize</code> is larger than 2^24 * <code>BlockSize</code>, then <code>MaxFileSize</code> is ignored, and the value becomes 2^24 * <code>BlockSize</code>. The default <code>BlockSize</code> is 512, and 2^24 * 512 is 8 GB.
  - See <a href='#getInitialSize'>Initial Size. </a>

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         max_file_size => '1342177280'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:max_file_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MaxFileSize')
end
