#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_window_buffer_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The maximum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per primary store file. Applies to synchronous write policies <code>Direct-Write-With-Cache</code> and <code>Disabled</code> but only when the native <code>wlfileio</code> library is loaded.  A window buffer does not consume Java heap memory, but does consume off-heap (native) memory. If the store is unable to allocate the requested buffer size, it allocates smaller and smaller buffers until it reaches <code>MinWindowBufferSize</code>, and then fails if cannot honor <code>MinWindowBufferSize</code>.  Oracle recommends setting the max window buffer size to more than double the size of the largest write (multiple concurrently updated records may be combined into a single write), and greater than or equal to the file size, unless there are other constraints. 32-bit JVMs may impose a total limit of between 2 and 4GB for combined Java heap plus off-heap (native) memory usage.  <ul>

  - See store attribute <code>AllocatedWindowBufferBytes</code> to find out the actual allocated Window Buffer Size.
  - See <a href='#getMaxFileSize'>Maximum File Size</a> and <a href='#getMinWindowBufferSize'>Minimum Window Buffer Size.</a>

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         max_window_buffer_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:max_window_buffer_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MaxWindowBufferSize')
end
