#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_foreign_jndi_provider) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a foreign jndi provider in an WebLogic domain.

    Here is an example on how you should use this:

        wls_foreign_jndi_provider { 'DomainA':
          ensure                  => 'present',
          initial_context_factory => 'weblogic.jndi.WLInitialContextFactory',
          provider_properties     => ['bbb=aaaa', 'xxx=123'],
          provider_url            => 't3://10.10.10.100:7001',
          target                  => ['WebCluster'],
          targettype              => ['Cluster'],
          user                    => 'weblogic',
          password                => 'weblogic1',
        }

    In this example you are managing a foreign jndi provider in the default domain. When you want to
    manage a foreign jndi provider in a specific domain, you can use:


        wls_foreign_jndi_provider { 'my_domain/LDAP':
          ensure                  => 'present',
          initial_context_factory => 'com.sun.jndi.ldap.LdapCtxFactory',
          provider_properties     => ['referral=follow'],
          provider_url            => 'ldap://:10.10.10.100:389',
          target                  => ['AdminServer'],
          targettype              => ['Server'],
          user                    => 'cn=orcladmin',
          password                => 'weblogic1',
        }


    EOD

    ensurable

    bean_type('ForeignJNDIProvider')

    parameter :domain
    parameter :name
    parameter :provider_name

    property :target
    property :targettype
    property :initial_context_factory
    property :user
    property :provider_properties
    property :provider_url
    property :password
    extraproperties do
      property :deployment_order
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
    end

    add_title_attributes(:provider_name)
  end
end
