#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:flow_one_way_send_mode, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether message producers created using this connection factory are allowed to do one-way message sends to improve typical non-persistent, non-transactional messaging performance. When enabled, the associated queue senders and/or topic publishers can send messages without internally waiting for a response from the target destination's host JMS server.  One-way sends are supported only when the connection factory hosting the producer and the JMS server hosting the target destination are targeted to the same WebLogic Server instance. In addition, one-way sends are not supported for higher quality-of-service (QOS) features, such as XA, transacted sessions, persistent messaging, unit-of-order, unit-of-work, distributed destinations, and client-side store-and-forward. If the producer and target destination are in separate domains, or if any of these higher QOS features are detected, then the one-way mode setting will be ignored and standard two-way sends will be used instead.  <ul> <li>Disabled One-way send is disabled.</li>  <li>Enabled One-way send is permitted for queue senders or topic publishers.  <li>Topic Only Only topic publishers are permitted to do one-way sends. </ul>  Notes: <ul> <li>One-way message sends are disabled if your connection factory is configured with <code>XA Connection Factory Enabled</code>. This setting disables one-way sends whether or not the sender actually uses transactions.  <li>To benefit from one-way performance, the default <code>One-Way Send Window Size</code> value must also be configured higher. After every <code>OneWaySendWindowSize - 1</code> number of messages, a two-way is used instead of a one-way, so all messages are actually two-way when the <code>OneWaySendWindowSize = 1</code>. </ul> 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         flow_one_way_send_mode => 'disabled'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:flow_one_way_send_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('FlowControlParams/%{connection_factory_name}/OneWaySendMode')
end
