#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:transaction_xa_connection_factory_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Indicates whether a XA queue or XA topic connection factory is returned, instead of a queue or topic connection factory. An XA connection factory can be used to create an <code>XAConnection</code>, which in turn may be used to create an <code>XASession</code>, which in turn may be used to obtain an <code>XAResource</code> for use inside a transaction manager.   In addition, this attribute indicates whether or not a connection factory creates sessions that are JTA aware. If true, the associated message producers and message consumers look into the running thread for a transaction context. Otherwise, the current JTA transaction will be ignored.   Note: Transacted sessions ignore the current threads transaction context in favor of their own internal transaction, regardless of the setting. This setting only affects non-transacted sessions.  

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         transaction_xa_connection_factory_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:transaction_xa_connection_factory_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('TransactionParams/%{connection_factory_name}/XAConnectionFactoryEnabled')
end
