#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:forwarding_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-EOD
   The uniform distributed topic message Forwarding Policy specifies whether a sent message is forwarded to all members.   The valid values are: <ul> <li>Replicated - The default. All physical topic members receive each sent message. If a message arrives at one of the physical topic members, a copy of this message is forwarded to the other members of that uniform distributed topic. A subscription on any one particular member will get a copy of any message sent to the uniform distributed topic logical name or to any particular uniform distributed topic member.</li>  <li>Partitioned - The physical member receiving the message is the only member of the uniform distributed topic that is aware of the message. When a message is published to the logical name of a Partitioned uniform distributed topic, it will only arrive on one particular physical topic member. Once a message arrives on a physical topic member, the message is not forwarded to the rest of the members of the uniform distributed destination, and subscribers on other physical topic members do not get a copy of that message. The Partitioned capability was added in WebLogic 10.3.4 (11gR1PS3).</li> </ul> A publisher that uses a logical JNDI name of a Replicated distributed topic is created on one member and every send call  publishes messages to the same member regardless the value of the <code>Load Balancing Enabled</code> attribute. This is behavior is backward compatible with previous WebLogic Server releases when using a uniform distributed topic. Under the same conditions, a Partitioned distributed topic publishes to the same member only when the value of the <code>Load Balancing Enabled</code> attribute is set to false. If the value of the <code>Load Balancing Enabled</code> attribute is to true, a publisher to a Partitioned distributed topic publishes messages that are load balanced accross all the members of the uniform distributed topic.   Most new applications will use the new Partitioned forwarding policy in combination with a logical subscription topology on a uniform distributed topic that consists of: (1) a same named physical subscription created directly on each physical member, (2) a Client ID Policy of Unrestricted, and (3) a Subscription Sharing Policy of <code>Sharable</code>. WL 10.3.4 Message Driven Beans (MDBs) provides a Topic Messages Distribution Mode option to automatically setup this kind of topology.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         forwarding_policy => 'Replicated'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:forwarding_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ForwardingPolicy')
end
