#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:paging_max_file_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The paging maximum file size, in bytes. <ul> <li>The <code>PagingMaxFileSize</code> value affects the number of files needed to accommodate a paging store of a particular size (number of files = paging store size/MaxFileSize rounded up).</li>  <li>A paging store automatically reuses space freed by deleted records and automatically expands individual files up to <code>PagingMaxFileSize</code> if there is not enough space for a new record. If there is no space left in exiting files for a new record, a paging store creates an additional file.</li>  <li> A small number of larger files is normally preferred over a large number of smaller files as each file allocates Window Buffer and file handles. </li>  <li> If <code>PagingMaxFileSize</code> is larger than 2^24 * <code>PagingBlockSize</code>, then <code>MaxFileSize</code> is ignored, and the value becomes 2^24 * <code>PagingBlockSize</code>. The default <code>PagingBlockSize</code> is 512, and 2^24 * 512 is 8 GB. </li> </ul> Oracle recommends not setting the Paging Max File Size above the default value of 1,342,177,280.   

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         paging_max_file_size => '1342177280'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:paging_max_file_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('PagingMaxFileSize')
end
