#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_init_sql, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  SQL statement to execute that will initialize newly created physical database connections. Start the statement with SQL followed by a space.  If the Init SQL value begins with <code>"SQL "</code>, then the rest of the string following that leading token will be taken as a literal SQL statement that will be used to initialize database connections. If the Init SQL value does not begin with "SQL ", the value will be treated as the name of a table and the following SQL statement will be used to initialize connections: <code><br clear="none" /> "select count(*) from InitSQL"</code>  The table <code>InitSQL</code> must exist and be accessible to the database user for the connection. Most database servers optimize this SQL to avoid a table scan, but it is still a good idea to set <code>InitSQL</code> to the name of a table that is known to have few rows, or even no rows. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_init_sql => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_init_sql']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/InitSql')
end
