newproperty(:combined_role_mapping_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Determines how the role mappings in the Enterprise Application, Web application, and EJB containers interact. This setting is valid only for Web applications and EJBs that use the Advanced security model and that initialize roles from deployment descriptors. When enabled:  <ul> <li>Application role mappings are combined with EJB and Web application mappings so that all principal mappings are included. The Security Service combines the role mappings with a logical <code>OR</code> operator.</li>  <li>If one or more policies in the <code>web.xml</code> file specify a role for which no mapping exists in the <code>weblogic.xml</code> file, the Web application container creates an empty map for the undefined role (that is, the role is explicitly defined as containing no principal). Therefore, no one can access URL patterns that are secured by such policies.</li>  <li>If one or more policies in the <code>ejb-jar.xml</code> file specify a role for which no mapping exists in the <code>weblogic-ejb-jar.xml</code> file, the EJB container creates an empty map for the undefined role (that is, the role is explicitly defined as containing no principal). Therefore, no one can access methods that are secured by such policies.</li> </ul>  When disabled:  <ul> <li>Role mappings for each container are exclusive to other containers unless defined by the <code>&lt;externally-defined&gt;</code> descriptor element.</li>  <li>If one or more policies in the <code>web.xml</code> file specify a role for which no role mapping exists in the <code>weblogic.xml</code> file, the Web application container assumes that the undefined role is the name of a principal. It therefore maps the assumed principal to the role name. For example, if the <code>web.xml</code> file contains the following stanza in one of its policies:  <code>&lt;auth-constraint&gt;<br> &lt;role-name&gt;PrivilegedUser&lt;/role-name&gt;<br> &lt;/auth-constraint&gt;</code>  but, if the <code>weblogic.xml</code> file has no role mapping for <code>PrivilegedUser</code>, then the Web application container creates an in-memory mapping that is equivalent to the following stanza:  <code>&lt;security-role-assignment&gt;<br> &lt;role-name&gt;PrivilegedUser&lt;/role-name&gt;<br> &lt;principal-name&gt;PrivilegedUser&lt;/principal-name&gt;<br> &lt;/security-role-assignment&gt;</code> </li>  <li>Role mappings for EJB methods must be defined in the <code>weblogic-ejb-jar.xml</code> file. Role mappings defined in the other containers are not used unless defined by the <code>&lt;externally-defined&gt;</code> descriptor element.</li> </ul>  <dl> <dt>Note:</dt>  <dd>For all applications previously deployed in version 8.1 and upgraded to version 9.x, the combining role mapping is disabled by default.</dd> </dl> 

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         combined_role_mapping_enabled => '1'
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('CombinedRoleMappingEnabled')
end
