#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:weblogic_plugin_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether this server uses the proprietary <tt>WL-Proxy-Client-IP</tt> header, which is recommended if the server instance will receive requests from a proxy plug-in.  If the server instance is a member of a cluster that will receive proxied requests, enable the WebLogic plugin at the cluster level. For servers that are members of a cluster, the setting at the cluster level overrides the server's setting.  When the WebLogic plugin is enabled, a call to <code>getRemoteAddr</code> will return the address of the browser client from the proprietary <code>WL-Proxy-Client-IP</code> header instead of the web server. 

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         weblogic_plugin_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:weblogic_plugin_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('WeblogicPluginEnabled')
end
